@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      Microsoft SQL Server 7.x                     */
-/* Created on:     8/12/2004 4:03:50 p.m.                       */
+/* Created on:     3/03/2005 12:09:03 p.m.                      */
 /*==============================================================*/
 
 
@@ -239,6 +239,14 @@ if exists (select 1
 go
 
 
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_control')
+            and   type = 'U')
+   drop table ax_control
+go
+
+
 if exists (select 1
             from  sysobjects
            where  id = object_id('ax_element_set_enc')
@@ -335,6 +343,14 @@ if exists (select 1
 go
 
 
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_layout_set_group')
+            and   type = 'U')
+   drop table ax_layout_set_group
+go
+
+
 if exists (select 1
             from  sysobjects
            where  id = object_id('ax_menu')
@@ -375,6 +391,54 @@ if exists (select 1
 go
 
 
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite')
+            and   type = 'U')
+   drop table ax_microsite
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite_media')
+            and   type = 'U')
+   drop table ax_microsite_media
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite_page')
+            and   type = 'U')
+   drop table ax_microsite_page
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite_page_plugin')
+            and   type = 'U')
+   drop table ax_microsite_page_plugin
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite_story')
+            and   type = 'U')
+   drop table ax_microsite_story
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_microsite_template')
+            and   type = 'U')
+   drop table ax_microsite_template
+go
+
+
 if exists (select 1
             from  sysobjects
            where  id = object_id('ax_organisation')
@@ -383,6 +447,22 @@ if exists (select 1
 go
 
 
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_plugin_area')
+            and   type = 'U')
+   drop table ax_plugin_area
+go
+
+
+if exists (select 1
+            from  sysobjects
+           where  id = object_id('ax_plugin_content')
+            and   type = 'U')
+   drop table ax_plugin_content
+go
+
+
 if exists (select 1
             from  sysobjects
            where  id = object_id('ax_query_resource')
@@ -772,6 +852,17 @@ create table ax_content_location (
 go
 
 
+/*==============================================================*/
+/* Table: ax_control                                            */
+/*==============================================================*/
+create table ax_control (
+   app_prefix           varchar(64)          null,
+   site_axyl_version    varchar(64)          null,
+   site_docroot         varchar(64)          null
+)
+go
+
+
 /*==============================================================*/
 /* Table: ax_element_set_enc                                    */
 /*==============================================================*/
@@ -1054,6 +1145,19 @@ page_id
 go
 
 
+/*==============================================================*/
+/* Table: ax_layout_set_group                                   */
+/*==============================================================*/
+create table ax_layout_set_group (
+   layout_name          varchar(64)          not null,
+   cm_privilege         varchar(16)          not null
+      constraint CKC_CM_PRIVILEGE_AX_LAYOU check (cm_privilege in ('editor','author','entry')),
+   group_id             int                  not null,
+   constraint PK_AX_LAYOUT_SET_GROUP primary key  (layout_name, cm_privilege, group_id)
+)
+go
+
+
 /*==============================================================*/
 /* Table: ax_menu                                               */
 /*==============================================================*/
@@ -1106,10 +1210,11 @@ create table ax_menuoption (
    sitepage_parms       varchar(64)          null,
    auth_code            smallint             not null default false,
    active               smallint             not null,
-   last_modified        datetime             not null,
    width                int                  not null default 80,
    height               int                  not null default 20,
    is_parent            smallint             not null,
+   target               varchar(64)          null,
+   last_modified        datetime             not null,
    constraint ax_menuoption_pkey primary key  (menuoption_id)
 )
 go
@@ -1127,11 +1232,11 @@ execute sp_bindefault D_Bool_InitTrue, 'ax_menuoption.active'
 go
 
 
-execute sp_bindefault D_TimeStampNow, 'ax_menuoption.last_modified'
+execute sp_bindefault D_Bool_InitFalse, 'ax_menuoption.is_parent'
 go
 
 
-execute sp_bindefault D_Bool_InitFalse, 'ax_menuoption.is_parent'
+execute sp_bindefault D_TimeStampNow, 'ax_menuoption.last_modified'
 go
 
 
@@ -1204,6 +1309,132 @@ create table ax_meta_schema (
 go
 
 
+/*==============================================================*/
+/* Table: ax_microsite                                          */
+/*==============================================================*/
+create table ax_microsite (
+   microsite_name       varchar(64)          not null,
+   menu_id              int                  null,
+   microsite_desc       varchar(64)          null,
+   microsite_domain     varchar(64)          null,
+   css                  varchar(64)          null,
+   css_ie               varchar(64)          null,
+   css_ns               varchar(64)          null,
+   req_microsite_publish smallint             not null,
+   req_microsite_remove smallint             not null,
+   currently_installed  smallint             not null,
+   last_installed       datetime             null,
+   last_modified        datetime             not null,
+   constraint PK_AX_MICROSITE primary key  (microsite_name)
+)
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_microsite.req_microsite_publish'
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_microsite.req_microsite_remove'
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_microsite.currently_installed'
+go
+
+
+execute sp_bindefault D_TimeStampNow, 'ax_microsite.last_modified'
+go
+
+
+/*==============================================================*/
+/* Table: ax_microsite_media                                    */
+/*==============================================================*/
+create table ax_microsite_media (
+   microsite_name       varchar(64)          not null,
+   cat_id               int                  not null,
+   constraint PK_AX_MICROSITE_MEDIA primary key  (microsite_name, cat_id)
+)
+go
+
+
+/*==============================================================*/
+/* Table: ax_microsite_page                                     */
+/*==============================================================*/
+create table ax_microsite_page (
+   microsite_page_id    int                  not null,
+   microsite_name       varchar(64)          not null,
+   page_id              int                  null,
+   microsite_template_id int                  null,
+   menuoption_id        int                  null,
+   page_title           varchar(64)          not null,
+   corepage             smallint             not null,
+   microsite_homepage   smallint             not null,
+   menuoption_label     varchar(64)          not null,
+   display_order        int                  not null,
+   cache_seconds        int                  not null,
+   enabled              smallint             not null,
+   constraint PK_AX_MICROSITE_PAGE primary key  (microsite_page_id)
+)
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_microsite_page.corepage'
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_microsite_page.microsite_homepage'
+go
+
+
+execute sp_bindefault D_Integer, 'ax_microsite_page.display_order'
+go
+
+
+execute sp_bindefault D_Integer, 'ax_microsite_page.cache_seconds'
+go
+
+
+execute sp_bindefault D_EnabledFlag, 'ax_microsite_page.enabled'
+go
+
+
+/*==============================================================*/
+/* Table: ax_microsite_page_plugin                              */
+/*==============================================================*/
+create table ax_microsite_page_plugin (
+   plugin_id            int                  not null,
+   microsite_page_id    int                  not null,
+   plugin_pattern       varchar(64)          not null,
+   plugin_content       varchar(64)          not null,
+   constraint PK_AX_MICROSITE_PAGE_PLUGIN primary key  (plugin_id)
+)
+go
+
+
+/*==============================================================*/
+/* Table: ax_microsite_story                                    */
+/*==============================================================*/
+create table ax_microsite_story (
+   microsite_name       varchar(64)          not null,
+   story_id             INT4                 not null
+)
+go
+
+
+/*==============================================================*/
+/* Table: ax_microsite_template                                 */
+/*==============================================================*/
+create table ax_microsite_template (
+   microsite_template_id int                  not null,
+   microsite_name       varchar(64)          not null,
+   template_name        varchar(64)          not null,
+   template_type        varchar(64)          not null,
+   template_content     varchar(64)          null,
+   constraint PK_AX_MICROSITE_TEMPLATE primary key  (microsite_template_id)
+)
+go
+
+
 /*==============================================================*/
 /* Table: ax_organisation                                       */
 /*==============================================================*/
@@ -1232,6 +1463,40 @@ contactinfo_id
 go
 
 
+/*==============================================================*/
+/* Table: ax_plugin_area                                        */
+/*==============================================================*/
+create table ax_plugin_area (
+   plugin_pattern       varchar(64)          not null,
+   plugin_desc          varchar(64)          null,
+   constraint PK_AX_PLUGIN_AREA primary key  (plugin_pattern)
+)
+go
+
+
+/*==============================================================*/
+/* Table: ax_plugin_content                                     */
+/*==============================================================*/
+create table ax_plugin_content (
+   plugin_content       varchar(64)          not null,
+   plugin_content_desc  varchar(64)          not null,
+   generator            varchar(64)          not null,
+   generator_type       TEXT                 not null
+      constraint CKC_GENERATOR_TYPE_AX_PLUGI check (generator_type in ('cm','func','defer','lit','file')),
+   replace_content      smallint             not null,
+   constraint PK_AX_PLUGIN_CONTENT primary key  (plugin_content)
+)
+go
+
+
+execute sp_bindefault D_GeneratorType, 'ax_plugin_content.generator_type'
+go
+
+
+execute sp_bindefault D_Bool_InitFalse, 'ax_plugin_content.replace_content'
+go
+
+
 /*==============================================================*/
 /* Table: ax_query_resource                                     */
 /*==============================================================*/
@@ -1661,6 +1926,18 @@ alter table ax_layout_set
 go
 
 
+alter table ax_layout_set_group
+   add constraint fk_group_layout_set foreign key (layout_name)
+      references ax_layout_set (layout_name)
+go
+
+
+alter table ax_layout_set_group
+   add constraint fk_layout_set_group foreign key (group_id)
+      references ax_group (group_id)
+go
+
+
 alter table ax_menu
    add constraint fk_ax_menu_language foreign key (lang_id)
       references ax_language (lang_id)
@@ -1703,6 +1980,84 @@ alter table ax_meta_element_set
 go
 
 
+alter table ax_microsite
+   add constraint fk_ax_microsite_menu foreign key (menu_id)
+      references ax_menu (menu_id)
+go
+
+
+alter table ax_microsite_media
+   add constraint fk_ax_microsite_media foreign key (cat_id)
+      references ax_catalog (cat_id)
+go
+
+
+alter table ax_microsite_media
+   add constraint fk_ax_microsite_media_page foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+go
+
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_page foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+go
+
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_page_template foreign key (microsite_template_id)
+      references ax_microsite_template (microsite_template_id)
+go
+
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_sitepage foreign key (page_id)
+      references ax_sitepage (page_id)
+go
+
+
+alter table ax_microsite_page
+   add constraint fk_microsite_page_menuoption foreign key (menuoption_id)
+      references ax_menuoption (menuoption_id)
+go
+
+
+alter table ax_microsite_page_plugin
+   add constraint fk_microsite_page_plugin foreign key (microsite_page_id)
+      references ax_microsite_page (microsite_page_id)
+go
+
+
+alter table ax_microsite_page_plugin
+   add constraint fk_plugin_area foreign key (plugin_pattern)
+      references ax_plugin_area (plugin_pattern)
+go
+
+
+alter table ax_microsite_page_plugin
+   add constraint fk_plugin_content foreign key (plugin_content)
+      references ax_plugin_content (plugin_content)
+go
+
+
+alter table ax_microsite_story
+   add constraint fk_microsite_story foreign key (story_id)
+      references ax_story (story_id)
+go
+
+
+alter table ax_microsite_story
+   add constraint fk_story_microsite foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+go
+
+
+alter table ax_microsite_template
+   add constraint fk_ax_microsite_template foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+go
+
+
 alter table ax_organisation
    add constraint ax_org_contactinfo foreign key (contactinfo_id)
       references ax_contactinfo (contactinfo_id)
