@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      Microsoft SQL Server 7.x                     */
-/* Created on:     8/12/2004 4:04:26 p.m.                       */
+/* Created on:     15/02/2005 8:03:18 a.m.                      */
 /*==============================================================*/
 
 
@@ -40,6 +40,10 @@ create trigger ax_menuoption_modstamp before update on ax_menuoption
    for each row execute procedure modstamp();
 
 
+create trigger ax_microsite_modstamp before update on ax_microsite
+   for each row execute procedure modstamp();
+
+
 create trigger ax_story_modstamp before update on ax_story
    for each row execute procedure modstamp();
 
