@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      MySQL 4.0                                    */
-/* Created on:     8/12/2004 4:15:12 p.m.                       */
+/* Created on:     3/03/2005 12:07:33 p.m.                      */
 /*==============================================================*/
 
 
@@ -195,6 +195,17 @@ create table ax_content_location
 )
 comment = "Contains unique logical locations on the website for content. These are not necessarily physical pages, but can be used in your application code to present the story in the locations required.";
 
+/*==============================================================*/
+/* Table: ax_control                                            */
+/*==============================================================*/
+create table ax_control
+(
+   app_prefix                     longtext,
+   site_axyl_version              longtext,
+   site_docroot                   longtext
+)
+comment = "Details which are registered for any Axyl website, on first access, or on upgrade.";
+
 /*==============================================================*/
 /* Table: ax_element_set_enc                                    */
 /*==============================================================*/
@@ -489,6 +500,32 @@ create index ax_layout_set_sitepage_FK on ax_layout_set
    page_id
 );
 
+/*==============================================================*/
+/* Table: ax_layout_set_group                                   */
+/*==============================================================*/
+create table ax_layout_set_group
+(
+   layout_name                    varchar(64)                    not null,
+   cm_privilege                   varchar(16)                    not null,
+   group_id                       int                            not null,
+   primary key (layout_name, cm_privilege, group_id)
+);
+
+/*==============================================================*/
+/* Index: "group_layout_set_FK"                                            */
+/*==============================================================*/
+create index group_layout_set_FK on ax_layout_set_group
+(
+   layout_name
+);
+/*==============================================================*/
+/* Index: "layout_set_group_FK"                                            */
+/*==============================================================*/
+create index layout_set_group_FK on ax_layout_set_group
+(
+   group_id
+);
+
 /*==============================================================*/
 /* Table: ax_menu                                               */
 /*==============================================================*/
@@ -540,10 +577,11 @@ create table ax_menuoption
    sitepage_parms                 longtext,
    auth_code                      smallint                       not null default 0,
    active                         smallint                       not null default 1,
-   last_modified                  datetime                       not null default 'now()',
    width                          int                            not null default 80,
    height                         int                            not null default 20,
    is_parent                      smallint                       not null default 0,
+   target                         longtext,
+   last_modified                  datetime                       not null default 'now()',
    primary key (menuoption_id)
 );
 
@@ -639,6 +677,187 @@ create table ax_meta_schema
 )
 comment = "A meta schema is simply an umbrella entity which describes a metadata element set. Examples would be 'Dublin Core', 'AGLS', or 'NZGLS'.";
 
+/*==============================================================*/
+/* Table: ax_microsite                                          */
+/*==============================================================*/
+create table ax_microsite
+(
+   microsite_name                 varchar(64)                    not null,
+   menu_id                        int,
+   microsite_desc                 longtext,
+   microsite_domain               longtext,
+   css                            longtext,
+   css_ie                         longtext,
+   css_ns                         longtext,
+   req_microsite_publish          smallint                       not null default 0,
+   req_microsite_remove           smallint                       not null default 0,
+   currently_installed            smallint                       not null default 0,
+   last_installed                 datetime,
+   last_modified                  datetime                       not null default 'now()',
+   primary key (microsite_name)
+);
+
+/*==============================================================*/
+/* Index: "ax_microsite_menu_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_menu_FK on ax_microsite
+(
+   menu_id
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_media                                    */
+/*==============================================================*/
+create table ax_microsite_media
+(
+   microsite_name                 varchar(64)                    not null,
+   cat_id                         int                            not null,
+   primary key (microsite_name, cat_id)
+);
+
+/*==============================================================*/
+/* Index: "ax_microsite_media_page_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_media_page_FK on ax_microsite_media
+(
+   microsite_name
+);
+/*==============================================================*/
+/* Index: "ax_microsite_media_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_media_FK on ax_microsite_media
+(
+   cat_id
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_page                                     */
+/*==============================================================*/
+create table ax_microsite_page
+(
+   microsite_page_id              int                            not null,
+   microsite_name                 varchar(64)                    not null,
+   page_id                        int,
+   menuoption_id                  int,
+   microsite_template_id          int,
+   page_title                     longtext                       not null,
+   corepage                       smallint                       not null default 0,
+   microsite_homepage             smallint                       not null default 0,
+   menuoption_label               longtext                       not null,
+   display_order                  int                            not null default 0,
+   cache_seconds                  int                            not null default 0,
+   enabled                        smallint                       not null default 1,
+   primary key (microsite_page_id)
+);
+
+/*==============================================================*/
+/* Index: "ax_microsite_page_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_page_FK on ax_microsite_page
+(
+   microsite_name
+);
+/*==============================================================*/
+/* Index: "ax_microsite_sitepage_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_sitepage_FK on ax_microsite_page
+(
+   page_id
+);
+/*==============================================================*/
+/* Index: "microsite_page_menuoption_FK"                                            */
+/*==============================================================*/
+create index microsite_page_menuoption_FK on ax_microsite_page
+(
+   menuoption_id
+);
+/*==============================================================*/
+/* Index: "ax_microsite_page_template_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_page_template_FK on ax_microsite_page
+(
+   microsite_template_id
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_page_plugin                              */
+/*==============================================================*/
+create table ax_microsite_page_plugin
+(
+   plugin_id                      int                            not null,
+   microsite_page_id              int                            not null,
+   plugin_pattern                 longtext                       not null,
+   plugin_content                 varchar(64)                    not null,
+   primary key (plugin_id)
+);
+
+/*==============================================================*/
+/* Index: "microsite_page_plugin_FK"                                            */
+/*==============================================================*/
+create index microsite_page_plugin_FK on ax_microsite_page_plugin
+(
+   microsite_page_id
+);
+/*==============================================================*/
+/* Index: "plugin_area_FK"                                            */
+/*==============================================================*/
+create index plugin_area_FK on ax_microsite_page_plugin
+(
+   plugin_pattern
+);
+/*==============================================================*/
+/* Index: "plugin_content_FK"                                            */
+/*==============================================================*/
+create index plugin_content_FK on ax_microsite_page_plugin
+(
+   plugin_content
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_story                                    */
+/*==============================================================*/
+create table ax_microsite_story
+(
+   microsite_name                 varchar(64)                    not null,
+   story_id                       int                            not null
+);
+
+/*==============================================================*/
+/* Index: "story_microsite_FK"                                            */
+/*==============================================================*/
+create index story_microsite_FK on ax_microsite_story
+(
+   microsite_name
+);
+/*==============================================================*/
+/* Index: "microsite_story_FK"                                            */
+/*==============================================================*/
+create index microsite_story_FK on ax_microsite_story
+(
+   story_id
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_template                                 */
+/*==============================================================*/
+create table ax_microsite_template
+(
+   microsite_template_id          int                            not null,
+   microsite_name                 varchar(64)                    not null,
+   template_name                  longtext                       not null,
+   template_type                  longtext                       not null default 'html',
+   template_content               longtext,
+   primary key (microsite_template_id)
+);
+
+/*==============================================================*/
+/* Index: "ax_microsite_template_FK"                                            */
+/*==============================================================*/
+create index ax_microsite_template_FK on ax_microsite_template
+(
+   microsite_name
+);
+
 /*==============================================================*/
 /* Table: ax_organisation                                       */
 /*==============================================================*/
@@ -661,6 +880,29 @@ create index ax_org_contactinfo_FK on ax_organisation
    contactinfo_id
 );
 
+/*==============================================================*/
+/* Table: ax_plugin_area                                        */
+/*==============================================================*/
+create table ax_plugin_area
+(
+   plugin_pattern                 longtext                       not null,
+   plugin_desc                    longtext,
+   primary key (plugin_pattern)
+);
+
+/*==============================================================*/
+/* Table: ax_plugin_content                                     */
+/*==============================================================*/
+create table ax_plugin_content
+(
+   plugin_content                 varchar(64)                    not null,
+   plugin_content_desc            longtext                       not null,
+   generator                      longtext                       not null,
+   generator_type                 TEXT                           not null default 'defer',
+   replace_content                smallint                       not null default 0,
+   primary key (plugin_content)
+);
+
 /*==============================================================*/
 /* Table: ax_query_resource                                     */
 /*==============================================================*/
@@ -711,6 +953,7 @@ create table ax_sitepage
    page_id                        int                            not null,
    page_title                     longtext                       not null,
    page_path                      longtext                       not null,
+   template_name                  longtext,
    managed                        smallint                       not null default 1,
    enabled                        smallint                       not null default 1,
    primary key (page_id)
@@ -1096,6 +1339,12 @@ alter table ax_layout_metadata add constraint fk_ax_layout_meta_data foreign key
 alter table ax_layout_set add constraint ax_layout_set_sitepage foreign key (page_id)
       references ax_sitepage (page_id) on delete set null on update restrict;
 
+alter table ax_layout_set_group add constraint fk_group_layout_set foreign key (layout_name)
+      references ax_layout_set (layout_name) on delete cascade on update restrict;
+
+alter table ax_layout_set_group add constraint fk_layout_set_group foreign key (group_id)
+      references ax_group (group_id) on delete cascade on update restrict;
+
 alter table ax_menu add constraint fk_ax_menu_language foreign key (lang_id)
       references ax_language (lang_id) on delete restrict on update restrict;
 
@@ -1117,6 +1366,45 @@ alter table ax_meta_element_set add constraint fk_ax_meta_elem_set_schema foreig
 alter table ax_meta_element_set add constraint fk_ax_pref_enc_scheme foreign key (preferred_enc_scheme)
       references ax_enc_scheme (enc_scheme_id) on delete restrict on update restrict;
 
+alter table ax_microsite add constraint fk_ax_microsite_menu foreign key (menu_id)
+      references ax_menu (menu_id) on delete set null on update restrict;
+
+alter table ax_microsite_media add constraint fk_ax_microsite_media foreign key (cat_id)
+      references ax_catalog (cat_id) on delete cascade on update restrict;
+
+alter table ax_microsite_media add constraint fk_ax_microsite_media_page foreign key (microsite_name)
+      references ax_microsite (microsite_name) on delete restrict on update restrict;
+
+alter table ax_microsite_page add constraint fk_ax_microsite_page foreign key (microsite_name)
+      references ax_microsite (microsite_name) on delete restrict on update restrict;
+
+alter table ax_microsite_page add constraint fk_ax_microsite_page_template foreign key (microsite_template_id)
+      references ax_microsite_template (microsite_template_id) on delete set null on update restrict;
+
+alter table ax_microsite_page add constraint fk_ax_microsite_sitepage foreign key (page_id)
+      references ax_sitepage (page_id) on delete set null on update restrict;
+
+alter table ax_microsite_page add constraint fk_microsite_page_menuoption foreign key (menuoption_id)
+      references ax_menuoption (menuoption_id) on delete set null on update restrict;
+
+alter table ax_microsite_page_plugin add constraint fk_microsite_page_plugin foreign key (microsite_page_id)
+      references ax_microsite_page (microsite_page_id) on delete cascade on update restrict;
+
+alter table ax_microsite_page_plugin add constraint fk_plugin_area foreign key (plugin_pattern)
+      references ax_plugin_area (plugin_pattern) on delete cascade on update restrict;
+
+alter table ax_microsite_page_plugin add constraint fk_plugin_content foreign key (plugin_content)
+      references ax_plugin_content (plugin_content) on delete cascade on update restrict;
+
+alter table ax_microsite_story add constraint fk_microsite_story foreign key (story_id)
+      references ax_story (story_id) on delete cascade on update restrict;
+
+alter table ax_microsite_story add constraint fk_story_microsite foreign key (microsite_name)
+      references ax_microsite (microsite_name) on delete cascade on update restrict;
+
+alter table ax_microsite_template add constraint fk_ax_microsite_template foreign key (microsite_name)
+      references ax_microsite (microsite_name) on delete restrict on update restrict;
+
 alter table ax_organisation add constraint ax_org_contactinfo foreign key (contactinfo_id)
       references ax_contactinfo (contactinfo_id) on delete restrict on update restrict;
 
