@@ -87,6 +87,12 @@ enabled              SMALLINT                       not null default true,
 primary key (location_id)
 );
 
+create table ax_control (
+app_prefix           LONG VARCHAR,
+site_axyl_version    LONG VARCHAR,
+site_docroot         LONG VARCHAR
+);
+
 create table ax_enc_scheme (
 enc_scheme_id        INTEGER                        not null,
 enc_scheme_name      LONG VARCHAR                   not null,
@@ -159,10 +165,11 @@ sitepage             LONG VARCHAR,
 sitepage_parms       LONG VARCHAR,
 auth_code            SMALLINT                       not null default false,
 active               SMALLINT                       not null default true,
-last_modified        DATE                           not null default 'now()',
 width                INTEGER                        not null default 80,
 height               INTEGER                        not null default 20,
 is_parent            SMALLINT                       not null default 0,
+target               LONG VARCHAR,
+last_modified        DATE                           not null default 'now()',
 primary key (menuoption_id),
 foreign key (menu_id)
       references ax_menu (menu_id)
@@ -180,6 +187,45 @@ namespace_uri        LONG VARCHAR,
 primary key (schema_name)
 );
 
+create table ax_microsite (
+microsite_name       VARCHAR(64)                    not null,
+menu_id              INTEGER,
+microsite_desc       LONG VARCHAR,
+microsite_domain     LONG VARCHAR,
+css                  LONG VARCHAR,
+css_ie               LONG VARCHAR,
+css_ns               LONG VARCHAR,
+req_microsite_publish SMALLINT                       not null default 0,
+req_microsite_remove SMALLINT                       not null default 0,
+currently_installed  SMALLINT                       not null default 0,
+last_installed       DATE,
+last_modified        DATE                           not null default 'now()',
+primary key (microsite_name),
+foreign key (menu_id)
+      references ax_menu (menu_id)
+);
+
+create table ax_microsite_media (
+microsite_name       VARCHAR(64)                    not null,
+cat_id               INTEGER                        not null,
+primary key (microsite_name, cat_id),
+foreign key (microsite_name)
+      references ax_microsite (microsite_name),
+foreign key (cat_id)
+      references ax_catalog (cat_id)
+);
+
+create table ax_microsite_template (
+microsite_template_id INTEGER                        not null,
+microsite_name       VARCHAR(64)                    not null,
+template_name        LONG VARCHAR                   not null,
+template_type        LONG VARCHAR                   not null default 'html',
+template_content     LONG VARCHAR,
+primary key (microsite_template_id),
+foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+);
+
 create table ax_organisation (
 org_id               INTEGER                        not null,
 contactinfo_id       INTEGER,
@@ -196,6 +242,22 @@ create  index ax_org_contactinfo_FK on ax_organisation (
 contactinfo_id ASC
 );
 
+create table ax_plugin_area (
+plugin_pattern       LONG VARCHAR                   not null,
+plugin_desc          LONG VARCHAR,
+primary key (plugin_pattern)
+);
+
+create table ax_plugin_content (
+plugin_content       VARCHAR(64)                    not null,
+plugin_content_desc  LONG VARCHAR                   not null,
+generator            LONG VARCHAR                   not null,
+generator_type       TEXT                           not null default 'defer' 
+      check (generator_type in ('cm','func','defer','lit','file')),
+replace_content      SMALLINT                       not null default 0,
+primary key (plugin_content)
+);
+
 create table ax_query_resource (
 quid                 INTEGER                        not null,
 q_desc               LONG VARCHAR,
@@ -323,6 +385,180 @@ create  index ax_wwwsession_user_FK on ax_wwwsession (
 user_id ASC
 );
 
+create table ax_microsite_page (
+microsite_page_id    INTEGER                        not null,
+microsite_name       VARCHAR(64)                    not null,
+page_id              INTEGER,
+menuoption_id        INTEGER,
+microsite_template_id INTEGER,
+page_title           LONG VARCHAR                   not null,
+corepage             SMALLINT                       not null default 0,
+microsite_homepage   SMALLINT                       not null default 0,
+menuoption_label     LONG VARCHAR                   not null,
+display_order        INTEGER                        not null default 0,
+cache_seconds        INTEGER                        not null default 0,
+enabled              SMALLINT                       not null default 1,
+primary key (microsite_page_id),
+foreign key (microsite_name)
+      references ax_microsite (microsite_name),
+foreign key (page_id)
+      references ax_sitepage (page_id),
+foreign key (menuoption_id)
+      references ax_menuoption (menuoption_id),
+foreign key (microsite_template_id)
+      references ax_microsite_template (microsite_template_id)
+);
+
+create table ax_microsite_page_plugin (
+plugin_id            INTEGER                        not null,
+microsite_page_id    INTEGER                        not null,
+plugin_pattern       LONG VARCHAR                   not null,
+plugin_content       VARCHAR(64)                    not null,
+primary key (plugin_id),
+foreign key (plugin_pattern)
+      references ax_plugin_area (plugin_pattern),
+foreign key (plugin_content)
+      references ax_plugin_content (plugin_content),
+foreign key (microsite_page_id)
+      references ax_microsite_page (microsite_page_id)
+);
+
+create table ax_enc_qualifier (
+enc_scheme_id        INTEGER                        not null,
+qual_name            VARCHAR(64)                    not null,
+qual_label           LONG VARCHAR,
+comments             LONG VARCHAR,
+default_value        LONG VARCHAR,
+list_of_values       LONG VARCHAR,
+display_order        INTEGER                        not null default 999,
+primary key (enc_scheme_id, qual_name),
+foreign key (enc_scheme_id)
+      references ax_enc_scheme (enc_scheme_id)
+);
+
+create table ax_layout_set (
+layout_name          VARCHAR(64)                    not null,
+page_id              INTEGER,
+primary key (layout_name),
+foreign key (page_id)
+      references ax_sitepage (page_id)
+);
+
+create  index ax_layout_set_sitepage_FK on ax_layout_set (
+page_id ASC
+);
+
+create table ax_layout_set_group (
+layout_name          VARCHAR(64)                    not null,
+cm_privilege         VARCHAR(16)                    not null  
+      check (cm_privilege in ('editor','author','entry')),
+group_id             INTEGER                        not null,
+primary key (layout_name, cm_privilege, group_id),
+foreign key (layout_name)
+      references ax_layout_set (layout_name),
+foreign key (group_id)
+      references ax_group (group_id)
+);
+
+create table ax_story (
+story_id             INTEGER                        not null,
+lang_id              INTEGER                        not null default 0,
+category_id          INTEGER,
+story_author         VARCHAR(64),
+story_icon           INTEGER,
+story_icon_url       LONG VARCHAR,
+story_headline       LONG VARCHAR,
+story_precis         LONG VARCHAR,
+story_content        LONG VARCHAR,
+story_type           LONG VARCHAR,
+story_url            LONG VARCHAR,
+story_date           DATE                           not null default 'CURRENT_TIMESTAMP',
+expiry_date          DATE,
+last_modified        DATE                           not null default 'CURRENT_TIMESTAMP',
+deleted              SMALLINT                       not null default false,
+visible              SMALLINT                       not null default true,
+primary key (story_id),
+foreign key (story_icon)
+      references ax_catalog (cat_id),
+foreign key (lang_id)
+      references ax_language (lang_id),
+foreign key (story_author)
+      references ax_user (user_id),
+foreign key (category_id)
+      references ax_story_category (category_id)
+);
+
+create table ax_meta_element (
+element_id           INTEGER                        not null,
+label                LONG VARCHAR,
+tag_name             LONG VARCHAR                   not null,
+definition           LONG VARCHAR,
+parent_element       INTEGER,
+parent_schema        VARCHAR(64),
+enabled              SMALLINT                       not null default true,
+primary key (element_id),
+foreign key (parent_element)
+      references ax_meta_element (element_id),
+foreign key (parent_schema)
+      references ax_meta_schema (schema_name)
+);
+
+create table ax_story_location (
+story_id             INTEGER                        not null,
+location_id          INTEGER                        not null,
+display_order        INTEGER                        not null default 999,
+foreign key (story_id)
+      references ax_story (story_id),
+foreign key (location_id)
+      references ax_content_location (location_id)
+);
+
+create table ax_story_media (
+story_id             INTEGER                        not null,
+cat_id               INTEGER                        not null,
+caption              LONG VARCHAR,
+width                INTEGER                        not null default 0,
+height               INTEGER                        not null default 0,
+justify              VARCHAR(16)                    not null default '' 
+      check (justify in ('','left','center','right')),
+display_order        INTEGER                        not null default 999,
+primary key (story_id, cat_id),
+foreign key (story_id)
+      references ax_story (story_id),
+foreign key (cat_id)
+      references ax_catalog (cat_id)
+);
+
+create table ax_story_translation (
+story_id             INTEGER                        not null,
+translated_story_id  INTEGER                        not null,
+primary key (story_id, translated_story_id),
+foreign key (story_id)
+      references ax_story (story_id),
+foreign key (translated_story_id)
+      references ax_story (story_id)
+);
+
+create table ax_meta_element_set (
+schema_name          VARCHAR(64)                    not null,
+element_id           INTEGER                        not null,
+preferred_enc_scheme INTEGER,
+comments             LONG VARCHAR,
+obligation           VARCHAR(10)                    not null default 'o' 
+      check (obligation in ('m','c','r','o')),
+default_value        LONG VARCHAR,
+list_of_values       LONG VARCHAR,
+display_order        INTEGER                        not null default 999,
+enabled              SMALLINT                       not null default true,
+primary key (schema_name, element_id),
+foreign key (element_id)
+      references ax_meta_element (element_id),
+foreign key (schema_name)
+      references ax_meta_schema (schema_name),
+foreign key (preferred_enc_scheme)
+      references ax_enc_scheme (enc_scheme_id)
+);
+
 create table ax_forum (
 forum_id             INTEGER                        not null,
 moderator            VARCHAR(64),
@@ -382,127 +618,14 @@ create  index ax_fk_forum_msg_forum_FK on ax_forum_msg (
 forum_id ASC
 );
 
-create table ax_enc_qualifier (
-enc_scheme_id        INTEGER                        not null,
-qual_name            VARCHAR(64)                    not null,
-qual_label           LONG VARCHAR,
-comments             LONG VARCHAR,
-default_value        LONG VARCHAR,
-list_of_values       LONG VARCHAR,
-display_order        INTEGER                        not null default 999,
-primary key (enc_scheme_id, qual_name),
-foreign key (enc_scheme_id)
-      references ax_enc_scheme (enc_scheme_id)
-);
-
-create table ax_story (
-story_id             INTEGER                        not null,
-lang_id              INTEGER                        not null default 0,
-category_id          INTEGER,
-story_author         VARCHAR(64),
-story_icon           INTEGER,
-story_icon_url       LONG VARCHAR,
-story_headline       LONG VARCHAR,
-story_precis         LONG VARCHAR,
-story_content        LONG VARCHAR,
-story_type           LONG VARCHAR,
-story_url            LONG VARCHAR,
-story_date           DATE                           not null default 'CURRENT_TIMESTAMP',
-expiry_date          DATE,
-last_modified        DATE                           not null default 'CURRENT_TIMESTAMP',
-deleted              SMALLINT                       not null default false,
-visible              SMALLINT                       not null default true,
-primary key (story_id),
-foreign key (story_icon)
-      references ax_catalog (cat_id),
-foreign key (lang_id)
-      references ax_language (lang_id),
-foreign key (story_author)
-      references ax_user (user_id),
-foreign key (category_id)
-      references ax_story_category (category_id)
-);
-
-create table ax_story_location (
-story_id             INTEGER                        not null,
-location_id          INTEGER                        not null,
-display_order        INTEGER                        not null default 999,
-foreign key (story_id)
-      references ax_story (story_id),
-foreign key (location_id)
-      references ax_content_location (location_id)
-);
-
-create table ax_story_media (
-story_id             INTEGER                        not null,
-cat_id               INTEGER                        not null,
-caption              LONG VARCHAR,
-width                INTEGER                        not null default 0,
-height               INTEGER                        not null default 0,
-justify              VARCHAR(16)                    not null default '' 
-      check (justify in ('','left','center','right')),
-display_order        INTEGER                        not null default 999,
-primary key (story_id, cat_id),
-foreign key (story_id)
-      references ax_story (story_id),
-foreign key (cat_id)
-      references ax_catalog (cat_id)
-);
-
-create table ax_story_translation (
-story_id             INTEGER                        not null,
-translated_story_id  INTEGER                        not null,
-primary key (story_id, translated_story_id),
-foreign key (story_id)
-      references ax_story (story_id),
-foreign key (translated_story_id)
-      references ax_story (story_id)
-);
-
-create table ax_layout_set (
-layout_name          VARCHAR(64)                    not null,
-page_id              INTEGER,
-primary key (layout_name),
-foreign key (page_id)
-      references ax_sitepage (page_id)
-);
-
-create  index ax_layout_set_sitepage_FK on ax_layout_set (
-page_id ASC
-);
-
-create table ax_meta_element (
-element_id           INTEGER                        not null,
-label                LONG VARCHAR,
-tag_name             LONG VARCHAR                   not null,
-definition           LONG VARCHAR,
-parent_element       INTEGER,
-parent_schema        VARCHAR(64),
-enabled              SMALLINT                       not null default true,
-primary key (element_id),
-foreign key (parent_element)
-      references ax_meta_element (element_id),
-foreign key (parent_schema)
-      references ax_meta_schema (schema_name)
-);
-
-create table ax_meta_element_set (
+create table ax_element_set_enc (
 schema_name          VARCHAR(64)                    not null,
 element_id           INTEGER                        not null,
-preferred_enc_scheme INTEGER,
-comments             LONG VARCHAR,
-obligation           VARCHAR(10)                    not null default 'o' 
-      check (obligation in ('m','c','r','o')),
-default_value        LONG VARCHAR,
-list_of_values       LONG VARCHAR,
-display_order        INTEGER                        not null default 999,
-enabled              SMALLINT                       not null default true,
-primary key (schema_name, element_id),
-foreign key (element_id)
-      references ax_meta_element (element_id),
-foreign key (schema_name)
-      references ax_meta_schema (schema_name),
-foreign key (preferred_enc_scheme)
+enc_scheme_id        INTEGER                        not null,
+primary key (schema_name, element_id, enc_scheme_id),
+foreign key (schema_name, element_id)
+      references ax_meta_element_set (schema_name, element_id),
+foreign key (enc_scheme_id)
       references ax_enc_scheme (enc_scheme_id)
 );
 
@@ -524,6 +647,15 @@ foreign key (schema_name, element_id)
       references ax_meta_element_set (schema_name, element_id)
 );
 
+create table ax_microsite_story (
+story_id             INTEGER                        not null,
+microsite_name       VARCHAR(64)                    not null,
+foreign key (story_id)
+      references ax_story (story_id),
+foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+);
+
 create table ax_layout (
 layout_id            INTEGER                        not null,
 layout_name          VARCHAR(64)                    not null,
@@ -584,6 +716,23 @@ create  index ax_block_layout_FK on ax_block (
 layout_id ASC
 );
 
+create table ax_layout_metadata (
+layout_id            INTEGER                        not null,
+element_id           INTEGER                        not null,
+schema_name          VARCHAR(64)                    not null,
+meta_tag_value       LONG VARCHAR,
+enc_scheme_id        INTEGER,
+linked_uri           SMALLINT                       not null default false,
+language             LONG VARCHAR,
+primary key (layout_id, element_id, schema_name),
+foreign key (layout_id)
+      references ax_layout (layout_id),
+foreign key (element_id, schema_name)
+      references ax_site_meta_element (element_id, schema_name),
+foreign key (enc_scheme_id)
+      references ax_enc_scheme (enc_scheme_id)
+);
+
 create table ax_block_blocklet (
 blocklet_id          INTEGER                        not null,
 block_id             INTEGER                        not null,
@@ -604,31 +753,3 @@ create  index ax_block_blocklet_FK2 on ax_block_blocklet (
 block_id ASC
 );
 
-create table ax_layout_metadata (
-layout_id            INTEGER                        not null,
-element_id           INTEGER                        not null,
-schema_name          VARCHAR(64)                    not null,
-meta_tag_value       LONG VARCHAR,
-enc_scheme_id        INTEGER,
-linked_uri           SMALLINT                       not null default false,
-language             LONG VARCHAR,
-primary key (layout_id, element_id, schema_name),
-foreign key (layout_id)
-      references ax_layout (layout_id),
-foreign key (element_id, schema_name)
-      references ax_site_meta_element (element_id, schema_name),
-foreign key (enc_scheme_id)
-      references ax_enc_scheme (enc_scheme_id)
-);
-
-create table ax_element_set_enc (
-schema_name          VARCHAR(64)                    not null,
-element_id           INTEGER                        not null,
-enc_scheme_id        INTEGER                        not null,
-primary key (schema_name, element_id, enc_scheme_id),
-foreign key (schema_name, element_id)
-      references ax_meta_element_set (schema_name, element_id),
-foreign key (enc_scheme_id)
-      references ax_enc_scheme (enc_scheme_id)
-);
-
