@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      ORACLE Version 8i2 (8.1.6)                   */
-/* Created on:     8/12/2004 4:14:07 p.m.                       */
+/* Created on:     3/03/2005 12:07:59 p.m.                      */
 /*==============================================================*/
 
 
@@ -55,6 +55,8 @@ drop table "ax_contactinfo" cascade constraints;
 
 drop table "ax_content_location" cascade constraints;
 
+drop table "ax_control" cascade constraints;
+
 drop table "ax_element_set_enc" cascade constraints;
 
 drop table "ax_enc_qualifier" cascade constraints;
@@ -79,6 +81,8 @@ drop table "ax_layout_metadata" cascade constraints;
 
 drop table "ax_layout_set" cascade constraints;
 
+drop table "ax_layout_set_group" cascade constraints;
+
 drop table "ax_menu" cascade constraints;
 
 drop table "ax_menuoption" cascade constraints;
@@ -89,8 +93,22 @@ drop table "ax_meta_element_set" cascade constraints;
 
 drop table "ax_meta_schema" cascade constraints;
 
+drop table "ax_microsite" cascade constraints;
+
+drop table "ax_microsite_media" cascade constraints;
+
+drop table "ax_microsite_page" cascade constraints;
+
+drop table "ax_microsite_page_plugin" cascade constraints;
+
+drop table "ax_microsite_template" cascade constraints;
+
 drop table "ax_organisation" cascade constraints;
 
+drop table "ax_plugin_area" cascade constraints;
+
+drop table "ax_plugin_content" cascade constraints;
+
 drop table "ax_query_resource" cascade constraints;
 
 drop table "ax_site_meta_element" cascade constraints;
@@ -109,6 +127,8 @@ drop table "ax_story_location" cascade constraints;
 
 drop table "ax_story_media" cascade constraints;
 
+drop table "ax_story_microsite" cascade constraints;
+
 drop table "ax_story_translation" cascade constraints;
 
 drop table "ax_user" cascade constraints;
@@ -378,6 +398,27 @@ comment on table "ax_content_location" is
 comment on column "ax_content_location"."enabled" is
 'If true, then items in this location can be displayed in an order determined by the user, else display by default method (usually reverse date order)';
 
+/*==============================================================*/
+/* Table: "ax_control"                                          */
+/*==============================================================*/
+create table "ax_control"  (
+   "app_prefix"         VARCHAR2(64),
+   "site_axyl_version"  VARCHAR2(64),
+   "site_docroot"       VARCHAR2(64)
+);
+
+comment on table "ax_control" is
+'Details which are registered for any Axyl website, on first access, or on upgrade.';
+
+comment on column "ax_control"."app_prefix" is
+'The code name of this website - often used as a prefix for messaging etc.';
+
+comment on column "ax_control"."site_axyl_version" is
+'The version of Axyl that this website was installed under';
+
+comment on column "ax_control"."site_docroot" is
+'The full physical path to this website when installed';
+
 /*==============================================================*/
 /* Table: "ax_element_set_enc"                                  */
 /*==============================================================*/
@@ -733,6 +774,27 @@ create index "ax_layout_set_sitepage_FK" on "ax_layout_set" (
    "page_id" ASC
 );
 
+/*==============================================================*/
+/* Table: "ax_layout_set_group"                                 */
+/*==============================================================*/
+create table "ax_layout_set_group"  (
+   "layout_name"        VARCHAR2(64)                    not null,
+   "cm_privilege"       VARCHAR(16)                     not null
+      constraint CKC_CM_PRIVILEGE_AX_LAYOU check ("cm_privilege" in ('editor','author','entry')),
+   "group_id"           LONG                            not null,
+   constraint PK_AX_LAYOUT_SET_GROUP primary key ("layout_name", "cm_privilege", "group_id")
+)
+pctfree 15
+pctused 75
+storage
+(
+    initial 50K
+    next 25K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system";
+
 /*==============================================================*/
 /* Table: "ax_menu"                                             */
 /*==============================================================*/
@@ -786,10 +848,11 @@ create table "ax_menuoption"  (
    "sitepage_parms"     VARCHAR2(64),
    "auth_code"          SMALLINT                       default false not null,
    "active"             SMALLINT                       default 1 not null,
-   "last_modified"      DATE                           default SYSDATE not null,
    "width"              INTEGER                        default 80 not null,
    "height"             INTEGER                        default 20 not null,
    "is_parent"          SMALLINT                       default 0 not null,
+   "target"             VARCHAR2(64),
+   "last_modified"      DATE                           default SYSDATE not null,
    constraint "ax_menuoption_pkey" primary key ("menuoption_id")
 )
 pctfree 15
@@ -891,6 +954,145 @@ tablespace "axyl_system";
 comment on table "ax_meta_schema" is
 'A meta schema is simply an umbrella entity which describes a metadata element set. Examples would be ''Dublin Core'', ''AGLS'', or ''NZGLS''.';
 
+/*==============================================================*/
+/* Table: "ax_microsite"                                        */
+/*==============================================================*/
+create table "ax_microsite"  (
+   "microsite_name"     VARCHAR2(64)                    not null,
+   "menu_id"            LONG,
+   "microsite_desc"     VARCHAR2(64),
+   "microsite_domain"   VARCHAR2(64),
+   "css"                CLOB,
+   "css_ie"             CLOB,
+   "css_ns"             CLOB,
+   "req_microsite_publish" SMALLINT                       default 0 not null,
+   "req_microsite_remove" SMALLINT                       default 0 not null,
+   "currently_installed" SMALLINT                       default 0 not null,
+   "last_installed"     DATE,
+   "last_modified"      DATE                           default SYSDATE not null,
+   constraint PK_AX_MICROSITE primary key ("microsite_name")
+)
+pctfree 15
+storage
+(
+    initial 256K
+    next 128K
+    maxextents unlimited
+)
+tablespace "axyl_system";
+
+/*==============================================================*/
+/* Table: "ax_microsite_media"                                  */
+/*==============================================================*/
+create table "ax_microsite_media"  (
+   "microsite_name"     VARCHAR2(64)                    not null,
+   "cat_id"             LONG                            not null,
+   constraint PK_AX_MICROSITE_MEDIA primary key ("microsite_name", "cat_id")
+)
+pctfree 15
+pctused 75
+storage
+(
+    initial 128K
+    next 50K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system"
+pctfree 15
+pctused 75
+storage
+(
+    initial 512K
+    next 256K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system";
+
+/*==============================================================*/
+/* Table: "ax_microsite_page"                                   */
+/*==============================================================*/
+create table "ax_microsite_page"  (
+   "microsite_page_id"  LONG                            not null,
+   "microsite_name"     VARCHAR2(64)                    not null,
+   "page_id"            LONG,
+   "menuoption_id"      LONG,
+   "microsite_template_id" LONG,
+   "page_title"         VARCHAR2(64)                    not null,
+   "corepage"           SMALLINT                       default 0 not null,
+   "microsite_homepage" SMALLINT                       default 0 not null,
+   "menuoption_label"   VARCHAR2(64)                    not null,
+   "display_order"      INTEGER                        default 0 not null,
+   "cache_seconds"      INTEGER                        default 0 not null,
+   "enabled"            SMALLINT                       default 1 not null,
+   constraint PK_AX_MICROSITE_PAGE primary key ("microsite_page_id")
+)
+pctfree 15
+pctused 75
+storage
+(
+    initial 128K
+    next 50K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system"
+pctfree 15
+pctused 75
+storage
+(
+    initial 512K
+    next 256K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system";
+
+/*==============================================================*/
+/* Table: "ax_microsite_page_plugin"                            */
+/*==============================================================*/
+create table "ax_microsite_page_plugin"  (
+   "plugin_id"          LONG                            not null,
+   "microsite_page_id"  LONG                            not null,
+   "plugin_pattern"     VARCHAR2(64)                    not null,
+   "plugin_content"     VARCHAR2(64)                    not null,
+   constraint PK_AX_MICROSITE_PAGE_PLUGIN primary key ("plugin_id")
+);
+
+/*==============================================================*/
+/* Table: "ax_microsite_template"                               */
+/*==============================================================*/
+create table "ax_microsite_template"  (
+   "microsite_template_id" LONG                            not null,
+   "microsite_name"     VARCHAR2(64)                    not null,
+   "template_name"      VARCHAR2(64)                    not null,
+   "template_type"      VARCHAR2(64)                   default 'html' not null
+      constraint CKC_TEMPLATE_TYPE_AX_MICRO check ("template_type" in ('html','wml')),
+   "template_content"   VARCHAR2(64),
+   constraint PK_AX_MICROSITE_TEMPLATE primary key ("microsite_template_id")
+)
+pctfree 15
+pctused 75
+storage
+(
+    initial 128K
+    next 50K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system"
+pctfree 15
+pctused 75
+storage
+(
+    initial 512K
+    next 256K
+    maxextents unlimited
+    pctincrease 0
+)
+tablespace "axyl_system";
+
 /*==============================================================*/
 /* Table: "ax_organisation"                                     */
 /*==============================================================*/
@@ -921,6 +1123,28 @@ create index "ax_org_contactinfo_FK" on "ax_organisation" (
    "contactinfo_id" ASC
 );
 
+/*==============================================================*/
+/* Table: "ax_plugin_area"                                      */
+/*==============================================================*/
+create table "ax_plugin_area"  (
+   "plugin_pattern"     VARCHAR2(64)                    not null,
+   "plugin_desc"        VARCHAR2(64),
+   constraint PK_AX_PLUGIN_AREA primary key ("plugin_pattern")
+);
+
+/*==============================================================*/
+/* Table: "ax_plugin_content"                                   */
+/*==============================================================*/
+create table "ax_plugin_content"  (
+   "plugin_content"     VARCHAR2(64)                    not null,
+   "plugin_content_desc" VARCHAR2(64)                    not null,
+   "generator"          VARCHAR2(64)                    not null,
+   "generator_type"     TEXT                           default 'defer' not null
+      constraint CKC_GENERATOR_TYPE_AX_PLUGI check ("generator_type" in ('cm','func','defer','lit','file')),
+   "replace_content"    SMALLINT                       default 0 not null,
+   constraint PK_AX_PLUGIN_CONTENT primary key ("plugin_content")
+);
+
 /*==============================================================*/
 /* Table: "ax_query_resource"                                   */
 /*==============================================================*/
@@ -1164,6 +1388,14 @@ tablespace "axyl_system";
 comment on table "ax_story_media" is
 'Media items associated with the story.';
 
+/*==============================================================*/
+/* Table: "ax_story_microsite"                                  */
+/*==============================================================*/
+create table "ax_story_microsite"  (
+   "microsite_name"     VARCHAR2(64)                    not null,
+   "story_id"           LONG                            not null
+);
+
 /*==============================================================*/
 /* Table: "ax_story_translation"                                */
 /*==============================================================*/
@@ -1420,6 +1652,16 @@ alter table "ax_layout_set"
       references "ax_sitepage" ("page_id")
       on delete set null;
 
+alter table "ax_layout_set_group"
+   add constraint "fk_group_layout_set" foreign key ("layout_name")
+      references "ax_layout_set" ("layout_name")
+      on delete cascade;
+
+alter table "ax_layout_set_group"
+   add constraint "fk_layout_set_group" foreign key ("group_id")
+      references "ax_group" ("group_id")
+      on delete cascade;
+
 alter table "ax_menu"
    add constraint "fk_ax_menu_language" foreign key ("lang_id")
       references "ax_language" ("lang_id");
@@ -1452,6 +1694,58 @@ alter table "ax_meta_element_set"
    add constraint "fk_ax_pref_enc_scheme" foreign key ("preferred_enc_scheme")
       references "ax_enc_scheme" ("enc_scheme_id");
 
+alter table "ax_microsite"
+   add constraint "fk_ax_microsite_menu" foreign key ("menu_id")
+      references "ax_menu" ("menu_id")
+      on delete set null;
+
+alter table "ax_microsite_media"
+   add constraint "fk_ax_microsite_media" foreign key ("cat_id")
+      references "ax_catalog" ("cat_id")
+      on delete cascade;
+
+alter table "ax_microsite_media"
+   add constraint "fk_ax_microsite_media_page" foreign key ("microsite_name")
+      references "ax_microsite" ("microsite_name");
+
+alter table "ax_microsite_page"
+   add constraint "fk_ax_microsite_page" foreign key ("microsite_name")
+      references "ax_microsite" ("microsite_name");
+
+alter table "ax_microsite_page"
+   add constraint "fk_ax_microsite_page_template" foreign key ("microsite_template_id")
+      references "ax_microsite_template" ("microsite_template_id")
+      on delete set null;
+
+alter table "ax_microsite_page"
+   add constraint "fk_ax_microsite_sitepage" foreign key ("page_id")
+      references "ax_sitepage" ("page_id")
+      on delete set null;
+
+alter table "ax_microsite_page"
+   add constraint "fk_microsite_page_menuoption" foreign key ("menuoption_id")
+      references "ax_menuoption" ("menuoption_id")
+      on delete set null;
+
+alter table "ax_microsite_page_plugin"
+   add constraint "fk_microsite_page_plugin" foreign key ("microsite_page_id")
+      references "ax_microsite_page" ("microsite_page_id")
+      on delete cascade;
+
+alter table "ax_microsite_page_plugin"
+   add constraint "fk_plugin_area" foreign key ("plugin_pattern")
+      references "ax_plugin_area" ("plugin_pattern")
+      on delete cascade;
+
+alter table "ax_microsite_page_plugin"
+   add constraint "fk_plugin_content" foreign key ("plugin_content")
+      references "ax_plugin_content" ("plugin_content")
+      on delete cascade;
+
+alter table "ax_microsite_template"
+   add constraint "fk_ax_microsite_template" foreign key ("microsite_name")
+      references "ax_microsite" ("microsite_name");
+
 alter table "ax_organisation"
    add constraint "ax_org_contactinfo" foreign key ("contactinfo_id")
       references "ax_contactinfo" ("contactinfo_id");
@@ -1517,6 +1811,16 @@ alter table "ax_story_media"
       references "ax_story" ("story_id")
       on delete cascade;
 
+alter table "ax_story_microsite"
+   add constraint "fk_microsite_story" foreign key ("story_id")
+      references "ax_story" ("story_id")
+      on delete cascade;
+
+alter table "ax_story_microsite"
+   add constraint "fk_story_microsite" foreign key ("microsite_name")
+      references "ax_microsite" ("microsite_name")
+      on delete cascade;
+
 alter table "ax_story_translation"
    add constraint "fk_ax_original_story" foreign key ("story_id")
       references "ax_story" ("story_id")
