@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      PostgreSQL 7                                 */
-/* Created on:     6/12/2004 5:26:59 p.m.                       */
+/* Created on:     28/02/2005 8:12:28 p.m.                      */
 /*==============================================================*/
 
 
@@ -103,6 +103,20 @@ maxvalue 2147483647
 start 1
 cache 1;
 
+create sequence seq_microsite_page_id
+increment 1
+minvalue 1
+maxvalue 2147483647
+start 1
+cache 1;
+
+create sequence seq_microsite_template_id
+increment 1
+minvalue 1
+maxvalue 2147483647
+start 1
+cache 1;
+
 create sequence seq_msg_id
 increment 1
 minvalue 1
@@ -124,6 +138,13 @@ maxvalue 2147483647
 start 1
 cache 1;
 
+create sequence seq_plugin_id
+increment 1
+minvalue 1
+maxvalue 2147483647
+start 1
+cache 1;
+
 create sequence seq_query_resource_id
 increment 1
 minvalue 1
@@ -316,6 +337,27 @@ comment on table ax_content_location is
 comment on column ax_content_location.enabled is
 'If true, then items in this location can be displayed in an order determined by the user, else display by default method (usually reverse date order)';
 
+/*==============================================================*/
+/* Table: ax_control                                            */
+/*==============================================================*/
+create table ax_control (
+app_prefix           TEXT                 null,
+site_axyl_version    TEXT                 null,
+site_docroot         TEXT                 null
+);
+
+comment on table ax_control is
+'Details which are registered for any Axyl website, on first access, or on upgrade.';
+
+comment on column ax_control.app_prefix is
+'The code name of this website - often used as a prefix for messaging etc.';
+
+comment on column ax_control.site_axyl_version is
+'The version of Axyl that this website was installed under';
+
+comment on column ax_control.site_docroot is
+'The full physical path to this website when installed';
+
 /*==============================================================*/
 /* Table: ax_element_set_enc                                    */
 /*==============================================================*/
@@ -548,6 +590,17 @@ create  index ax_layout_set_sitepage_FK on ax_layout_set (
 page_id
 );
 
+/*==============================================================*/
+/* Table: ax_layout_set_group                                   */
+/*==============================================================*/
+create table ax_layout_set_group (
+layout_name          TEXT                 not null,
+cm_privilege         TEXT                 not null 
+      constraint CKC_CM_PRIVILEGE_AX_LAYOU check (cm_privilege in ('editor','author','entry')),
+group_id             INT4                 not null,
+constraint PK_AX_LAYOUT_SET_GROUP primary key (layout_name, cm_privilege, group_id)
+);
+
 /*==============================================================*/
 /* Table: ax_menu                                               */
 /*==============================================================*/
@@ -588,10 +641,11 @@ sitepage             TEXT                 null,
 sitepage_parms       TEXT                 null,
 auth_code            BOOL                 not null default false,
 active               BOOL                 not null default true,
-last_modified        TIMESTAMP WITH TIME ZONE not null default CURRENT_TIMESTAMP,
 width                INT4                 not null default 80,
 height               INT4                 not null default 20,
 is_parent            BOOL                 not null default false,
+target               TEXT                 null,
+last_modified        TIMESTAMP WITH TIME ZONE not null default CURRENT_TIMESTAMP,
 constraint ax_menuoption_pkey primary key (menuoption_id)
 );
 
@@ -653,6 +707,84 @@ constraint PK_AX_META_SCHEMA primary key (schema_name)
 comment on table ax_meta_schema is
 'A meta schema is simply an umbrella entity which describes a metadata element set. Examples would be ''Dublin Core'', ''AGLS'', or ''NZGLS''.';
 
+/*==============================================================*/
+/* Table: ax_microsite                                          */
+/*==============================================================*/
+create table ax_microsite (
+microsite_name       TEXT                 not null,
+menu_id              INT4                 null,
+microsite_desc       TEXT                 null,
+microsite_domain     TEXT                 null,
+css                  TEXT                 null,
+css_ie               TEXT                 null,
+css_ns               TEXT                 null,
+req_microsite_publish BOOL                 not null default false,
+req_microsite_remove BOOL                 not null default false,
+currently_installed  BOOL                 not null default false,
+last_installed       TIMESTAMP            null,
+last_modified        TIMESTAMP WITH TIME ZONE not null default CURRENT_TIMESTAMP,
+constraint PK_AX_MICROSITE primary key (microsite_name)
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_media                                    */
+/*==============================================================*/
+create table ax_microsite_media (
+microsite_name       TEXT                 not null,
+cat_id               INT4                 not null,
+constraint PK_AX_MICROSITE_MEDIA primary key (microsite_name, cat_id)
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_page                                     */
+/*==============================================================*/
+create table ax_microsite_page (
+microsite_page_id    INT4                 not null,
+microsite_name       TEXT                 not null,
+page_id              INT4                 null,
+menuoption_id        INT4                 null,
+microsite_template_id INT4                 null,
+page_title           TEXT                 not null,
+corepage             BOOL                 not null default false,
+microsite_homepage   BOOL                 not null default false,
+menuoption_label     TEXT                 not null,
+display_order        INT4                 not null default 999,
+cache_seconds        INT4                 not null default 0,
+enabled              BOOL                 not null default true,
+constraint PK_AX_MICROSITE_PAGE primary key (microsite_page_id)
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_page_plugin                              */
+/*==============================================================*/
+create table ax_microsite_page_plugin (
+plugin_id            INT4                 not null,
+microsite_page_id    INT4                 not null,
+plugin_pattern       TEXT                 not null,
+plugin_content       TEXT                 not null,
+constraint PK_AX_MICROSITE_PAGE_PLUGIN primary key (plugin_id)
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_story                                    */
+/*==============================================================*/
+create table ax_microsite_story (
+microsite_name       TEXT                 not null,
+story_id             INT4                 not null
+);
+
+/*==============================================================*/
+/* Table: ax_microsite_template                                 */
+/*==============================================================*/
+create table ax_microsite_template (
+microsite_template_id INT4                 not null,
+microsite_name       TEXT                 not null,
+template_name        TEXT                 not null,
+template_type        TEXT                 not null,
+template_content     TEXT                 null,
+constraint PK_AX_MICROSITE_TEMPLATE primary key (microsite_template_id)
+);
+
 /*==============================================================*/
 /* Table: ax_organisation                                       */
 /*==============================================================*/
@@ -673,6 +805,28 @@ create  index ax_org_contactinfo_FK on ax_organisation (
 contactinfo_id
 );
 
+/*==============================================================*/
+/* Table: ax_plugin_area                                        */
+/*==============================================================*/
+create table ax_plugin_area (
+plugin_pattern       TEXT                 not null,
+plugin_desc          TEXT                 null,
+constraint PK_AX_PLUGIN_AREA primary key (plugin_pattern)
+);
+
+/*==============================================================*/
+/* Table: ax_plugin_content                                     */
+/*==============================================================*/
+create table ax_plugin_content (
+plugin_content       TEXT                 not null,
+plugin_content_desc  TEXT                 not null,
+generator            TEXT                 not null,
+generator_type       TEXT                 not null default 'defer' 
+      constraint CKC_GENERATOR_TYPE_AX_PLUGI check (generator_type in ('cm','func','defer','lit','file')),
+replace_content      BOOL                 not null default false,
+constraint PK_AX_PLUGIN_CONTENT primary key (plugin_content)
+);
+
 /*==============================================================*/
 /* Table: ax_query_resource                                     */
 /*==============================================================*/
@@ -1059,6 +1213,18 @@ alter table ax_layout_set
       on delete set null on update restrict
       deferrable initially deferred;
 
+alter table ax_layout_set_group
+   add constraint fk_group_layout_set foreign key (layout_name)
+      references ax_layout_set (layout_name)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_layout_set_group
+   add constraint fk_layout_set_group foreign key (group_id)
+      references ax_group (group_id)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
 alter table ax_menu
    add constraint fk_ax_menu_language foreign key (lang_id)
       references ax_language (lang_id)
@@ -1100,6 +1266,84 @@ alter table ax_meta_element_set
       references ax_enc_scheme (enc_scheme_id)
       on delete restrict on update restrict;
 
+alter table ax_microsite
+   add constraint fk_ax_microsite_menu foreign key (menu_id)
+      references ax_menu (menu_id)
+      on delete set null on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_media
+   add constraint fk_ax_microsite_media foreign key (cat_id)
+      references ax_catalog (cat_id)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_media
+   add constraint fk_ax_microsite_media_page foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_page foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_page_template foreign key (microsite_template_id)
+      references ax_microsite_template (microsite_template_id)
+      on delete restrict on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page
+   add constraint fk_ax_microsite_sitepage foreign key (page_id)
+      references ax_sitepage (page_id)
+      on delete set null on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page
+   add constraint fk_microsite_page_menuoption foreign key (menuoption_id)
+      references ax_menuoption (menuoption_id)
+      on delete set null on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page_plugin
+   add constraint fk_microsite_page_plugin foreign key (microsite_page_id)
+      references ax_microsite_page (microsite_page_id)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page_plugin
+   add constraint fk_plugin_area foreign key (plugin_pattern)
+      references ax_plugin_area (plugin_pattern)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_page_plugin
+   add constraint fk_plugin_content foreign key (plugin_content)
+      references ax_plugin_content (plugin_content)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_story
+   add constraint fk_microsite_story foreign key (story_id)
+      references ax_story (story_id)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_story
+   add constraint fk_story_microsite foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
+alter table ax_microsite_template
+   add constraint fk_ax_microsite_template foreign key (microsite_name)
+      references ax_microsite (microsite_name)
+      on delete cascade on update restrict
+      deferrable initially deferred;
+
 alter table ax_organisation
    add constraint ax_org_contactinfo foreign key (contactinfo_id)
       references ax_contactinfo (contactinfo_id)
@@ -1193,7 +1437,7 @@ alter table ax_story_translation
 alter table ax_story_translation
    add constraint fk_ax_translated_story foreign key (translated_story_id)
       references ax_story (story_id)
-      on delete restrict on update restrict
+      on delete cascade on update restrict
       deferrable initially deferred;
 
 alter table ax_user
