@@ -1,7 +1,7 @@
 /*==============================================================*/
 /* Database name:  axyl                                         */
 /* DBMS name:      PostgreSQL 7                                 */
-/* Created on:     27/11/2004 11:36:52 a.m.                     */
+/* Created on:     9/02/2005 4:53:22 p.m.                       */
 /*==============================================================*/
 
 
@@ -30,6 +30,10 @@ create trigger ax_menuoption_modstamp before update on ax_menuoption
    for each row execute procedure modstamp();
 
 
+create trigger ax_microsite_modstamp before update on ax_microsite
+   for each row execute procedure modstamp();
+
+
 create trigger ax_story_modstamp before update on ax_story
    for each row execute procedure modstamp();
 
