@@ -7,24 +7,30 @@
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 set -e
 
-# Get common funcs and config vars etc..
-if [ -f ./axyl-common.sh ]
+# Get common funcs and config vars etc.
+# Acquire the local configuration..
+CONFDIR=/etc/axyl
+CONF=${CONFDIR}/axyl.conf
+if [ ! -f $CONF ]
 then
-  . ./axyl-common.sh
+  echo "Axyl configuration file $CONF not found!"
+  exit 2
 else
-  echo "ERROR: axyl-common.sh not found. You must execute this"
-  echo "script from within the Axyl 'install' directory."
-  exit 1
+  . $CONF
+  if [ ! -d $AXYL_HOME ] ; then
+    echo "FATAL: the Axyl root directory '$AXYL_HOME' does not exist."
+    exit 6
+  fi
+  . ${AXYL_HOME}/install/axyl-common.sh
 fi
 
 # This script requires that Axyl is properly installed. If it isn't
 # then the following vars will not be defined, which is an error.
-
-if [ "$AXUSER" = "" -o "$AXYL_HOME" = "" -o "$AXYL_DATA" = "" ]
+if [ "$AXUSER" = "" -o "$AXYL_DATA" = "" ]
 then
-  echo "ERROR: Axyl is not configured properly and AXUSER, AXYL_HOME"
-  echo "and AXYL_DATA are undefined. Check $CONF exists"
-  echo "and contains these settings. Otherwise, do you need to run"
+  echo "ERROR: Axyl is not configured properly and one of AXUSER, and/or"
+  echo "AXYL_DATA are undefined. Check /etc/axyl/axyl.conf exists and"
+  echo "contains these settings. Otherwise, do you need to run script"
   echo "./setup-axyl.sh first?"
   exit 1
 fi
@@ -55,11 +61,16 @@ then
 fi
 
 echo ""
+echo -n "AXYL "
+if [ "$AXYL_VERSION" != "unknown" ]
+then
+  echo -n "$AXYL_VERSION "
+fi
 if [ "$INSTALLTYPE" = "empty" ]
 then
-  echo "NEW AXYL WEBSITE CREATION"
+  echo "- NEW WEBSITE CREATION"
 else
-  echo "AXYL DEMO INSTALLATION"
+  echo "- DEMO WEBSITE INSTALLATION"
 fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -268,9 +279,34 @@ then
   [ "$ANS" != "" ] && DBPORT=$ANS
 fi
 
-# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
-# INSTALL DATABASE
-${AXYL_HOME}/install/install-db.sh $INSTALLTYPE $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT
+# Axyl Metadata Extension
+META=n
+if [ "$INSTALLTYPE" = "empty" ]
+then
+  echo ""
+  echo "Axyl can be created with fully-defined Meta Data Schemas, namely"
+  echo "the Dublin Core, AGLS, and NZGLS definitions. This is appropriate if"
+  echo "you are going to be creating a website which requires meta data"
+  echo "content categorisation to any of these standards (eg. a Government"
+  echo "website). If you want this to be installed, say so now."
+  echo -n "Install Axyl Metadata Extension (y/n) [${META}] :"
+  read ANS
+  [ "$ANS" = "y" -o "$ANS" = "Y" ] && META=y
+fi
+
+# Axyl Microsites Extension
+MICRO=n
+if [ "$INSTALLTYPE" = "empty" ]
+then
+  echo ""
+  echo "Axyl can be created with the ability to create and manage 'microsites'"
+  echo "which make use of Axyl themeing. You can create simple content-managed"
+  echo "sub-sites within your single Axyl website via a web-interface if you"
+  echo "enable this extension. If you want this to be installed, say so now."
+  echo -n "Install Axyl Microsite Extension (y/n) [${MICRO}] :"
+  read ANS
+  [ "$ANS" = "y" -o "$ANS" = "Y" ] && MICRO=y
+fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # CREATE THE AXYL WEBSITE ROOT
@@ -329,6 +365,11 @@ find ${WWW_PATH} -type d -exec chmod a+x {} \;
 # Except var directory is writeable to webserver too..
 chgrp -R ${WWWUSER} ${WWW_PATH}/var
 
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# INSTALL DATABASE
+# At this point we have everything we need for this task..
+${AXYL_HOME}/install/install-db.sh $INSTALLTYPE $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT $META $MICRO $AXYL_VERSION $INST_NAME $WWW_PATH
+
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # APACHE CONFIGURATION
 echo ""
@@ -345,7 +386,7 @@ then
 
   # Virtual host
   VHOST=localhost
-  A=`perl -n -e "m;^[\s]*NameVirtualHost;i && print;" $CONF`
+  A=`perl -n -e "m;^[\s]*NameVirtualHost;i && s;\*;ASTERISK; && print;" $CONF`
   if [ "$A" != "" ]
   then
     for bit in $A
@@ -353,11 +394,11 @@ then
       VHOST=$bit
     done
   fi
-  echo -n "Enter IP or hostname for this virtual host [${VHOST}] :"
+  DISP=$VHOST
+  [ "$DISP" = "ASTERISK" ] && DISP="*"
+  echo -n "Enter IP or hostname for this virtual host [${DISP}] :"
   read ANS
   [ "$ANS" != "" ] && VHOST=$ANS
-  # Prevent command-line expansion of '*' later on..
-  VHOST=`echo $VHOST | sed -e "s;\*;ASTERISK;g"`
 
   # Server name
   SERVERNAME=
@@ -400,6 +441,9 @@ then
   [ "$ANS" != "" ] && DOCROOT=$ANS
 else
   CONFIG_APACHE=no
+  VHOST=none
+  VSERVERNAME=none
+  ADMIN_EMAIL=none
 fi
 
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -451,7 +495,7 @@ fi
 # AXYL APPLICATION CONFIGURATION
 echo ""
 echo "setting up website application config file (application.xml).."
-${AXYL_HOME}/install/config-app-db.pl $INST_NAME $WWW_PATH $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT
+${AXYL_HOME}/install/config-app-db.pl $INST_NAME $WWW_PATH $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT $META $MICRO
 # Fix up perms..
 chown ${AXUSER}:${WWWADMIN} ${WWW_PATH}/application.xml*
 chmod 0664 ${WWW_PATH}/application.xml*
@@ -464,6 +508,12 @@ then
   ${AXYL_HOME}/install/config-apache.sh $VHOST $VSERVERNAME $ADMIN_EMAIL $DOCROOT $AXYL_HOME $AXYL_LOGS
 fi
 
+# +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
+# Update Axyl websites database
+echo ""
+echo "updating Axyl website database.."
+${AXYL_HOME}/install/register-axyl-website.sh $INST_NAME $DBTYPE $DBNAME $DBUSER $DBPASSWD $DBHOST $DBPORT $DOCROOT $VHOST $VSERVERNAME $ADMIN_EMAIL
+
 # +++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
 # PERMISSIONS
 # We have already set these above, but just to ensure consistency we
@@ -521,4 +571,4 @@ echo "kept as non-writeable to the web-server."
 echo ""
 echo "The Axyl Team"
 
-# END
\ No newline at end of file
+# END
