@@ -68,7 +68,7 @@ class parameter {
     if ($this->type == "array") {
       $this->value[$ename] = $value;
     }
-    elseif ($this->type == "boolean") {
+    elseif ($this->type == "boolean"||$this->type == "bool") {
       $this->value = (($value === "true"||$value === "t"||$value === true) ? true : false);
     }
     else {
@@ -154,11 +154,25 @@ class setting {
   // .....................................................................
   /**
   * Add the given parameter to this setting.
-  * @param string $name Name of the parameter to add
+  * @param string $pname Name of the parameter to add
   * @param object $parm Parameter object to add to this setting
   */
-  function addparameter($name, $parm) {
-    $this->parameters[$name] = $parm;
+  function addparameter($pname, $parm) {
+    $this->parameters[$pname] = $parm;
+  }
+  // .....................................................................
+  /**
+  * Add a new parameter to this setting, with given value and type. For
+  * arrays we also specify the name of the array value.
+  * @param string $pname Name of the new parameter to add
+  * @param mixed  $value Value to assign to this parameter
+  * @param string $type Parameter type eg: 'array', 'string' etc.
+  * @param string $ename Name of this value (arrayed parameters only)
+  */
+  function newparameter($pname, $value, $type, $ename="") {
+    $parm = new parameter($pname, $type);
+    $parm->setvalue($value, $ename);
+    $this->addparameter($pname, $parm);
   }
   // .....................................................................
   /**
@@ -176,13 +190,13 @@ class setting {
   // .....................................................................
   /**
   * Get the value of a named parameter.
-  * @param string $name Name of the parameter to get value of
+  * @param string $pname Name of the parameter to get value of
   * @param string $ename Name of element (arrayed parameters only)
   */
-  function getparameter($name, $ename="") {
+  function getparameter($pname, $ename="") {
     $val = false;
-    if (isset($this->parameters) && isset($this->parameters[$name])) {
-      $parm = $this->parameters[$name];
+    if (isset($this->parameters) && isset($this->parameters[$pname])) {
+      $parm = $this->parameters[$pname];
       $val = $parm->getvalue($ename);
     }
     return $val;
@@ -416,7 +430,7 @@ class application extends xmlparser  {
   * the whole file as fresh XML, and writes it out.
   */
   function save() {
-    if ($this->valid) {
+    if ($this->valid && is_writeable($this->configpath)) {
       $xmlfile = new outputfile($this->configpath);
       if ($xmlfile->opened) {
         $xml = new xmltag("application");
