@@ -63,6 +63,13 @@ define("WYSIWYG_EDITOR", "w");
 @access private */
 define("PLAIN_CELL", "p");
 
+/** Default Editor group membership */
+define("DEFAULT_EDITOR_GROUPS", "Editor");
+/** Default Author group membership */
+define("DEFAULT_AUTHOR_GROUPS", "Author");
+/** Default Entry group membership */
+define("DEFAULT_ENTRY_GROUPS", "Entry");
+
 // ......................................................................
 /**
 * Block
@@ -89,7 +96,7 @@ class block extends RenderableObject {
   /** The id of the current block */
   var $blockid = 0;
   /** The description of the current block */
-  var $block_desc;
+  var $block_desc = "";
   /** The language of the block (0 = default) */
   var $language = 0;
   /** The language encoding code */
@@ -141,6 +148,15 @@ class block extends RenderableObject {
   var $blockfm = "";
   /** Mode of operation, 'viewing', 'editing', 'saving' @access private */
   var $mode = "viewing";
+  /** The group membership for Editor privilege
+      @access private */
+  var $editor_groups = array(DEFAULT_EDITOR_GROUPS);
+  /** The group membership for Authoring privilege
+      @access private */
+  var $author_groups = array(DEFAULT_AUTHOR_GROUPS);
+  /** The group membership for Entry privilege
+      @access private */
+  var $entry_groups = array(DEFAULT_ENTRY_GROUPS);
   // ....................................................................
   /**
   * Constructor
@@ -198,12 +214,24 @@ class block extends RenderableObject {
   * @param string $lang_dir The language direction of the layout
   * @access private
   */
-  function set_layout_info($ver=VERSION_UNDEFINED, $vercount=0, $lang=0, $lang_enc="", $lang_dir="") {
+  function set_layout_info(
+        $ver=VERSION_UNDEFINED,
+        $vercount=0,
+        $lang=0,
+        $lang_enc="",
+        $lang_dir="",
+        $editor_groups=DEFAULT_EDITOR_GROUPS,
+        $author_groups=DEFAULT_AUTHOR_GROUPS,
+        $entry_groups=DEFAULT_ENTRY_GROUPS
+        ) {
     $this->layout_version = $ver;
     $this->layout_version_count = $vercount;
     $this->layout_language = $lang;
     $this->layout_lang_encoding = $lang_enc;
     $this->layout_lang_direction = $lang_dir;
+    $this->editor_groups = $editor_groups;
+    $this->author_groups = $author_groups;
+    $this->entry_groups = $entry_groups;
   } // set_layout_info
   // ....................................................................
   /**
@@ -223,13 +251,13 @@ class block extends RenderableObject {
       // Pending version
       if ($this->layout_version == VERSION_PENDING ||
           $this->layout_version_count == 1) {
-        if ($RESPONSE->ismemberof_group_in("Editor,Author")) {
+        if ($RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) )) {
           $perm = true;
         }
       }
       // Live version
       elseif ($this->layout_version == VERSION_LIVE) {
-        if ($RESPONSE->ismemberof_group_in("Editor")) {
+        if ($RESPONSE->ismemberof_group_in( $this->editor_groups )) {
           $perm = true;
         }
       }
@@ -473,17 +501,22 @@ class block extends RenderableObject {
     if ( isset($CONTEXT) && $CONTEXT->configvalue("Lucene Site Indexing") ) {
       include_once("lucene-defs.php");
       // Read content from DB since it may have just been saved..
-      $q  = "SELECT b.heading, b.content";
+      $q  = "SELECT b.heading, b.content, b.blocklet_desc";
       $q .= "  FROM ax_block_blocklet bb, ax_blocklet b";
       $q .= " WHERE bb.block_id=$this->blockid";
       $q .= "   AND b.blocklet_id=bb.blocklet_id";
       $bQ = dbrecordset($q);
       $allcontent = array();
       $allcontent[] = $RESPONSE->head->title;
+      $allcontent[] = $this->block_desc;
       if ($bQ->hasdata) {
         do {
           $allcontent[] = $bQ->field("heading");
           $allcontent[] = $bQ->field("content");
+          $bkt_desc = $bQ->field("blocklet_desc");
+          if ($bkt_desc != "(enter a blocklet description)") {
+            $allcontent[] = $bkt_desc;
+          }
         } while ($bQ->get_next());
       }
       $I = new lucene_indexmsg();
@@ -588,7 +621,7 @@ class block extends RenderableObject {
       $Tvw->setstyle($bdrstyle);
     }
 
-    if ($this->mode != "previewing" && $RESPONSE->ismemberof_group_in("Editor,Author")) {
+    if ($this->mode != "previewing" && $RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) )) {
       $editor = true;
       if ($bdrstyle == "") {
         $Tvw->setstyle("border-width:1px;border-style:dotted;border-color:#ff0000;");
@@ -602,7 +635,8 @@ class block extends RenderableObject {
       // Toolbar table
       $Tbar = new table("toolbar");
       $Tbar->tr("axtitle");
-      $Tbar->th("[B$this->blockid]", "axtitle");
+      $Tbar->th("[Block]", "axtitle");
+      $Tbar->th_alignment("", "top");
       $tools = "";
       foreach ($toolbar as $tool) {
         $tools .= $tool->render();
@@ -765,7 +799,7 @@ class block extends RenderableObject {
 
     $s = "";
     // Start form for editing..
-    if ($this->exportable || $RESPONSE->ismemberof_group_in("Editor,Author")) {
+    if ($this->exportable || $RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) )) {
       $s .= "<form name=\"$this->blockfm\" method=\"post\" enctype=\"multipart/form-data\">";
     }
 
@@ -804,7 +838,7 @@ class block extends RenderableObject {
     } // switch
 
     // Finish the form..
-    if ($this->exportable || $RESPONSE->ismemberof_group_in("Editor,Author")) {
+    if ($this->exportable || $RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) )) {
       // Include action hidden field, and block ID
       $mode  = new form_hiddenfield("blockmode", $this->mode);
       $blid  = new form_hiddenfield("edit_blockid", $this->blockid);
@@ -1039,6 +1073,7 @@ class block extends RenderableObject {
                     $layout_version == VERSION_LIVE ||
                     $layout_version_count == 1) {
                   debugbr("indexing saved block. Layout ver=$layout_version", DBG_DEBUG);
+                  $this->get();
                   $this->index($RESPONSE->requested, $RESPONSE->head->title);
                 }
 
@@ -1075,6 +1110,16 @@ class block extends RenderableObject {
               $bu->set("border_colour",     $block_border_colour);
               $bu->set("block_style",       $block_style);
               $bu->execute();
+
+              // Index the block with current webpage path and title..
+              global $layout_version, $layout_version_count;
+              if (!isset($layout_version) ||
+                  $layout_version == VERSION_LIVE ||
+                  $layout_version_count == 1) {
+                debugbr("indexing saved wysiwyg block. Layout ver=$layout_version", DBG_DEBUG);
+                $this->get();
+                $this->index($RESPONSE->requested, $RESPONSE->head->title);
+              }
             }
           }
           break;
@@ -1452,9 +1497,11 @@ class blocklet extends RenderableObject {
   * $access private
   */
   function expanded_content() {
-    // Pre-process content for datasources..
     $content = $this->content;
     $matches = array();
+    // NB: the original scheme for embedding Axyl content used object tags, however
+    // browsers didn't render these very well, so the current scheme uses img tags
+    // instead, whilst retaining a backward compatibility for existing websites.
     $datapat = "/<object .*?axyl\/embedded-media.*?>|<img .*?axyl\/embedded-media.*?>/i";
     while ( preg_match($datapat, $content, $matches) ) {
       $datatag = $matches[0];
