@@ -58,7 +58,7 @@ $bigwidth = $threeqwidth . "px";
 
 // Generic add button..
 global $gen_addbtn;
-$gen_addbtn = new form_imagebutton("_add_link", "", "", $src="$LIBDIR/img/_add.gif", "Add link to content", 57, 15);
+$gen_addbtn = new form_imagebutton("_add_link", "", "", "$LIBDIR/img/_add.gif", "Add link to content", 57, 15);
 $gen_addbtn->setalt("Add");
 
 global $gen_blocklettype;
@@ -194,12 +194,12 @@ function insert_block_jscript() {
         . "  var remoFld = eval('document.forms.'+fm+'.link_remote');\n"
         . "  var contFld = eval('document.forms.'+fm+'.content');\n"
         . "  if (hrefFld != null && descFld != null && contFld != null && hrefFld.value != '') {\n"
-        . "    var linkHtml = '<A HREF=\"' + hrefFld.value + '\"';\n"
-        . "    if (remoFld.checked) linkHtml += ' target=_blank';\n"
+        . "    var linkHtml = '<a href=\"' + hrefFld.value + '\"';\n"
+        . "    if (remoFld.checked) linkHtml += ' target=\"_blank\"';\n"
         . "    linkHtml += '>';\n"
         . "    if (descFld.value == '') linkHtml += hrefFld.value;\n"
         . "    else linkHtml += descFld.value;\n"
-        . "    linkHtml += '</A>';\n"
+        . "    linkHtml += '</a>';\n"
         . "    contFld.value += ' ' + linkHtml;\n"
         . "    contFld.onchange();\n"
         . "  }\n"
