@@ -613,6 +613,7 @@ if (!$error) {
     $app->setparameter($cp_lifetime,                      "lifetime", "lifetime");
     $app->setparameter(isset($cp_guest_browser_lifetime), "guest_browser_lifetime", "guest_browser_lifetime");
     $app->setparameter($cp_expiry,                        "expiry", "expiry");
+    $app->setparameter(isset($cp_microsites_enabled),     "microsites_enabled", "microsites_enabled");
     $app->setparameter(isset($cp_metadata_enabled),       "metadata_enabled", "metadata_enabled");
     $app->setparameter(isset($cp_buffered_output),        "buffered_output", "buffered_output");
     $app->setparameter($cp_compression_type,              "compression_type", "compression_type");
@@ -1118,10 +1119,11 @@ if (!$error) {
   $Tin = new table("dbsettings");
   $Tin->setpadding(2);
 
-  $chkbox->checked = $app->getparameter("database_backed", "database_backed");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("database_backed", "database_backed");
   $Tin->tr("axbgdark");
   $Tin->td( "Website uses a Database:", "axfg" );
-  $Tin->td( $chkbox->render("cp_database_backed") );
+  $Tin->td( $mychkbox->render("cp_database_backed") );
 
   $Tin->tr("axbglite");
   $Tin->td( "Hosts for persistent DB connection:", "axfg" );
@@ -1341,10 +1343,11 @@ if (!$error) {
   $Fexpiry->setvalue($app->getparameter("expiry", "expiry"));
   $Tin->td( $Fexpiry->render("cp_expiry") );
 
-  $chkbox->checked = $app->getparameter("guest_browser_lifetime", "guest_browser_lifetime");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("guest_browser_lifetime", "guest_browser_lifetime");
   $Tin->tr("axbglite");
   $Tin->td( "Guest cookies browser lifetime:", "axfg" );
-  $Tin->td( $chkbox->render("cp_guest_browser_lifetime") );
+  $Tin->td( $mychkbox->render("cp_guest_browser_lifetime") );
 
   $Tin->set_width_profile("50%,50%");
   $Tapp->tr();
@@ -1358,15 +1361,32 @@ if (!$error) {
   $Tin = new table("content");
   $Tin->setpadding(2);
 
-  $chkbox->checked = $app->getparameter("metadata_enabled", "metadata_enabled");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("metadata_enabled", "metadata_enabled");
   $Tin->tr("axbglite");
   $Tin->td( "Enable metadata edit/generation:", "axfg" );
-  $Tin->td( $chkbox->render("cp_metadata_enabled") );
+  $Tin->td( $mychkbox->render("cp_metadata_enabled") );
 
-  $chkbox->checked = $app->getparameter("buffered_output", "buffered_output");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("microsites_enabled", "microsites_enabled");
+  $mychkbox->set_onchange(
+            "if(this.checked) "
+          . "alert("
+          . "'NOTICE:\\n\\n"
+          . "For microsite creation to work you must be running \'pg-microsites-installer.php\' from cron.\\n"
+          . "The crontab for this can be found in the \'scripts/cron\' sub-directory of your Axyl installation,\\n"
+          . "and should have been automatically installed into /etc/cron.d by your Debian package.\\n\\n"
+          . "')"
+            );
+  $Tin->tr("axbglite");
+  $Tin->td( "Enable microsite(s) creation:", "axfg" );
+  $Tin->td( $mychkbox->render("cp_microsites_enabled") );
+
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("buffered_output", "buffered_output");
   $Tin->tr("axbgdark");
   $Tin->td( "Buffered output (recommended):", "axfg" );
-  $Tin->td( $chkbox->render("cp_buffered_output") );
+  $Tin->td( $mychkbox->render("cp_buffered_output") );
 
   $Tin->tr("axbglite");
   $Tin->td( "Compression type:", "axfg" );
@@ -1407,15 +1427,17 @@ if (!$error) {
   $Tin = new table("getpost");
   $Tin->setpadding(2);
 
-  $chkbox->checked = $app->getparameter("keep", "keep");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("keep", "keep");
   $Tin->tr("axbgdark");
   $Tin->td( "Enable Axyl KEEP feature:", "axfg" );
-  $Tin->td( $chkbox->render("cp_keep") );
+  $Tin->td( $mychkbox->render("cp_keep") );
 
-  $chkbox->checked = $app->getparameter("globalise", "globalise");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("globalise", "globalise");
   $Tin->tr("axbglite");
   $Tin->td( "Auto-globalise all GET/POST vars:", "axfg" );
-  $Tin->td( $chkbox->render("cp_globalise") );
+  $Tin->td( $mychkbox->render("cp_globalise") );
 
   $Tin->set_width_profile("50%,50%");
   $Tapp->tr();
@@ -1429,10 +1451,11 @@ if (!$error) {
   $Tin = new table("authentication");
   $Tin->setpadding(2);
 
-  $chkbox->checked = $app->getparameter("encrypted_passwords", "encrypted_passwords");
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $app->getparameter("encrypted_passwords", "encrypted_passwords");
   $Tin->tr("axbgdark");
   $Tin->td( "Encrypted passwords:", "axfg" );
-  $Tin->td( $chkbox->render("cp_encrypted_passwords") );
+  $Tin->td( $mychkbox->render("cp_encrypted_passwords") );
 
   $Tin->tr("axbglite");
   $Tin->td( "Authentication type:", "axfg" );
@@ -1517,10 +1540,11 @@ if (!$error) {
   $Tin->setpadding(2);
 
   $debugging = $app->getparameter("debug_on", "debug_on");
-  $chkbox->checked = $debugging;
+  $mychkbox = $chkbox;
+  $mychkbox->checked = $debugging;
   $Tin->tr("axbgdark");
   $Tin->td( "Enable debugging:", "axfg" );
-  $Tin->td( $chkbox->render("cp_debug_on") );
+  $Tin->td( $mychkbox->render("cp_debug_on") );
 
   $Tin->tr("axbglite");
   $Tin->td( "Classes of output to show:", "axfg");
