@@ -643,8 +643,8 @@ class database {
       // Log excessive query execution times to syslog..
       if (isset($SQL_EXEC_THRESHOLD) && $SQL_EXEC_THRESHOLD > 0) {
         if ($this->timer->millisecs() > $SQL_EXEC_THRESHOLD) {
-          $errstr  = APP_NAME . ": " . $timer->formatted_millisecs() . "mS ";
-          $errstr .= "Exceeds Threshold ($SQL_EXEC_THRESHOLD): $executed_sql";
+          $errstr  = APP_NAME . ": " . $this->timer->formatted_millisecs() . "mS ";
+          $errstr .= "Exceeds Threshold ($SQL_EXEC_THRESHOLD): $this->executable_sql";
           error_log($errstr);
         }
       }
