@@ -127,7 +127,7 @@ function get_dirlist($path, $recurse=false, $regex="") {
     while (false !== ($filename = readdir($dirH))) {
       if ($filename != "." && $filename != "..") {
         $filetype = filetype("$path/$filename");
-        $valid = ($regex == "" || $filetype == "dir" ? true : preg_match($regex, $filename));
+        $valid = (($regex == "" || $filetype == "dir") ? true : preg_match($regex, $filename));
         if ($valid) {
           if ($filetype == "dir") {
             if ($recurse) {
@@ -463,10 +463,10 @@ class outputfile {
       $this->name = basename($name);
     }
 
-    // Make sure directory is there..
+    // Make sure directory (full path) is there..
     if ($this->dir != "") {
       if (!file_exists($this->dir)) {
-        mkdir($this->dir, 0755);
+        mkpath($this->dir, 0755);
         if (!file_exists($this->dir)) {
           die("");
         }
