@@ -1388,7 +1388,7 @@ class form_combofield extends form_textfield {
           }
         }
         // Render the select option..
-        $html .= "<option " . $selected . "value=\"$key\">$displayvalue";
+        $html .= "<option " . $selected . "value=\"$key\">$displayvalue</option>";
 
         // Remember selected values..
         if ($selected != "") {
@@ -1519,12 +1519,13 @@ class form_jumpmenu extends form_combofield {
         }
         else {
           // Do normal equality test..
-          if ($displayvalue == $this->value) $html .= " selected";
+          if ($displayvalue == $this->value) $html .= " selected=\"selected\"";
         }
         $html .= " value=\"$displayvalue\"";
         $html .= " onclick=\"javascript:document.location.href='$jumpurl'\"";
         $html .= ">";
         $html .= $displayvalue;
+        $html .= '</option>';
       }
     }
     $html .= "</select>";
@@ -1817,26 +1818,26 @@ class form_radiogroup extends form_combofield {
 * @package form
 */
 class form_imagefield extends form_textfield {
-  /** Prefix to image URL/path. This will be prefixed to the value. */
-  var $prefix;
+  /** Base path to image. This will be prefixed to the value field. */
+  var $base_path;
   // ....................................................................
   /**
   * Constructor
   * Create a field object. Sets basic field attributes.
-  * @param string  $name     The name of the field
-  * @param string  $label    The label which can be displayed alongside the field
-  * @param string  $value    The value of the field
-  * @param boolean $editable Editability: EDITABLE or DISPLAY_ONLY (true or false)
-  * @param string  $css      CSS class or style to apply to the button
-  * @param integer $width    Width of element in characters
-  * @param string  $prefix   Directory path prefix to apply to image file path
+  * @param string  $name       The name of the field
+  * @param string  $label      The label which can be displayed alongside the field
+  * @param string  $value      The value of the field
+  * @param boolean $editable   Editability: EDITABLE or DISPLAY_ONLY (true or false)
+  * @param string  $css        CSS class or style to apply to the button
+  * @param integer $width      Width of element in characters
+  * @param string  $base_path  Directory path prefix for the image file path
   */
-  function form_imagefield($name="", $label="", $value="", $editable=EDITABLE, $css="", $width=STD_WIDTH, $prefix="") {
+  function form_imagefield($name="", $label="", $value="", $editable=EDITABLE, $css="", $width=STD_WIDTH, $base_path="") {
     $this->form_textfield($name, $label, $value, $editable, $css, $width);
-    if ($prefix != "" && substr($prefix, -1) != "/") {
-      $prefix .= "/";
+    if ($base_path != "" && substr($base_path, -1) != "/") {
+      $base_path .= "/";
     }
-    $this->prefix = $prefix;
+    $this->base_path = $base_path;
   } // form_imagefield
   // ....................................................................
   /**
@@ -1844,41 +1845,156 @@ class form_imagefield extends form_textfield {
   * @return string The field as HTML.
   */
   function html($name="") {
-    $s  = "<table border=0 cellpadding=1 cellspacing=0>";
-    $s .= "<tr><td colspan=2 valign=top>" . form_textfield::html() . "</td></tr>";
-    $s .= "<tr><td valign=top>";
+    $s  = "<table border=\"0\" cellpadding=\"1\" cellspacing=\"0\">";
+    $s .= "<tr><td valign=\"top\">" . form_textfield::html() . "</td></tr>";
+    $s .= "<tr><td valign=\"top\">";
     if ($this->value != "") {
-      $imgurl = $this->prefix . $this->value;
-      $img = new image("img_" . $this->name, $imgurl, "Image at $imgurl");
+      $imgurl = $this->base_path . $this->value;
+      $img = new img($imgurl, "img_$this->name", "Image at $imgurl");
       $s .= $img->html();
     }
-    $s .= "</td>";
-    $s .= "<td>";
-    if ($imgurl != "") {
-      if ($this->prefix != "") {
-        $s .= "Path: $this->prefix<br>";
-      }
-      $siz = getimagesize($imgurl);
-      if (isset($siz[0])) {
-        $s .= "Size: " . $siz[0] . " x " . $siz[1] . "<br>";
-        switch ($siz[2]) {
-          case 1: $type = "GIF"; break;
-          case 2: $type = "JPG"; break;
-          case 3: $type = "PNG"; break;
-          case 4: $type = "SWF"; break;
-          case 5: $type = "PSD"; break;
-          case 6: $type = "BMP"; break;
-          default: "??";
-        }
-        $s .= "Type: $type";
-      }
-    }
     $s .= "</td></tr>";
     $s .= "</table>\n";
     return $s;
   } // html
 } // form_imagefield class
 
+// ----------------------------------------------------------------------
+/**
+* Image Combo class
+* This is a hybrid field. It is basically a single-line combo field where
+* the list of values are unique IDs of an image (eg. Axyl catalog ID). A
+* preview of the selected image is displayed below the combo, in fixed
+* size (configurable).
+* @package form
+*/
+class form_imagecombo extends form_combofield {
+  /** Array of image IDs we have in our combo */
+  var $image_keys = array();
+  /** Array of image URLS, one per ID above */
+  var $image_urls = array();
+  /** Width of preview in px */
+  var $preview_img_width = 125;
+  /** Height of preview in px */
+  var $preview_img_height = 125;
+  /** The form this widget is to be displayed in */
+  var $formname = "";
+  // ....................................................................
+  /**
+  * Constructor
+  * Create a field object. Sets basic field attributes.
+  * @param string  $name       The name of the field
+  * @param string  $label      The label which can be displayed alongside the field
+  * @param string  $value      The value of the field
+  * @param boolean $editable   Editability: EDITABLE or DISPLAY_ONLY (true or false)
+  * @param string  $css        CSS class or style to apply to the button
+  * @param integer $width      Width of element in characters
+  */
+  function form_imagecombo($name="", $label="", $value="", $editable=EDITABLE, $css="", $formname="") {
+    $this->form_combofield($name, $label, $value, $editable, $css);
+    $this->formname = $formname;
+  } // form_imagecombo
+  // ....................................................................
+  /** Set the width and height of the preview image. The default
+  * setting is 125 x 125 pixels.
+  * @param integer $prev_width The width of the preview image (px)
+  * @param integer $prev_height The height of the preview image (px)
+  */
+  function set_preview_metrics($prev_width=125, $prev_height=125) {
+    $this->preview_img_width  = $prev_width;
+    $this->preview_img_height = $prev_height;
+  } // set_preview_metrics
+  // ....................................................................
+  /** Set the name of the form this will be displayed in.
+  * @param string $formname The name of the form hosting this field
+  */
+  function set_formname($formname) {
+    $this->formname = $formname;
+  } // set_form_name
+  // ....................................................................
+  /** Add an image item to preview. We override the combofield additem()
+  * so we can store the image URL against the key value nin our arrays.
+  * These get rendered as hidden fields for the preview javascript.
+  * @param string $imgkey The key or unique ID of this image
+  * @param string $imgdesc The description or name of this image
+  * @param string $imgurl The URl of this image, to display it
+  */
+  function additem($imgkey, $imgdesc, $imgurl="") {
+    form_combofield::additem($imgkey, $imgdesc);
+    $this->image_keys[] = $imgkey;
+    $this->image_urls[] = $imgurl;
+  } // additem
+  // ....................................................................
+  /**
+  * This renders the field as HTML. Note that because of the special
+  * nature of this widget, we need to know the name of the form it is
+  * in to do the previewing. Without it, no preview image is displayed.
+  * @param string $formname Name of the form this widget is placed in.
+  * @return string The field as HTML.
+  */
+  function html($name="") {
+    global $RESPONSE;
+    if ($name != "") $this->setname($name);
+
+    // Derived set of names..
+    $previewname = $this->name . "_preview";
+    $preview_func = $previewname . "_func";
+    $preview_keys = $previewname . "_keys";
+    $preview_urls = $previewname . "_urls";
+    $preview_img  = $previewname . "_img";
+
+    $Timg = new table($this->name);
+    $Timg->tr();
+    if ($this->formname != "") {
+      // Set onclick event to preview image..
+      $this->set_onchange("$preview_func(this.options[this.selectedIndex].value)", SCRIPT_PREFIX);
+      $Timg->td( form_combofield::html() );
+      // Create a preview image, and lookup fields..
+      $imgFld = new img("", $preview_img, "Preview", $this->preview_img_width, $this->preview_img_height);
+      $hid1 = new form_hiddenfield($preview_keys, implode(",", $this->image_keys));
+      $hid2 = new form_hiddenfield($preview_urls, implode(",", $this->image_urls));
+
+      $Timg->tr();
+      $Timg->td( $imgFld->render() . $hid1->render() . $hid2->render() );
+      $Timg->td_alignment("", "top");
+
+      // Display post-processing function. Called just before the field
+      // is displayed, with the field content passed in. Here we are taking
+      // the image key value, and making the javascript preview call, so
+      // that it is primed with the original picture.
+      if ($this->value != "" && $this->value != NULLVALUE) {
+        $RESPONSE->foot->add_script( "$preview_func($this->value);" );
+      }
+
+      // This allows us to preview images without page refresh. The input parm
+      // is the image key value. We use that to look up the image URL.
+      $RESPONSE->head->add_script(
+          "function $preview_func(key) {\n"
+        . " var imgids=eval('document.forms.$this->formname.$preview_keys.value');\n"
+        . " var imgurls=eval('document.forms.$this->formname.$preview_urls.value');\n"
+        . " if (imgids!=null && imgurls!=null) {\n"
+        . "  var ids=imgids.split(',');\n"
+        . "  var urls=imgurls.split(',');\n"
+        . "  for(i=0; i<ids.length; i++) {\n"
+        . "   if(ids[i] == key) {\n"
+        . "    imgurl=urls[i];\n"
+        . "    if (imgurls!='') {\n"
+        . "      document.forms.$this->formname.$preview_img.src=imgurl;\n"
+        . "    }\n"
+        . "    break;\n"
+        . "   }\n"
+        . "  }\n"
+        . " }\n"
+        . "}\n"
+      );
+    }
+    else {
+      // Just render the combo alone..
+      $Timg->td( form_combofield::html() );
+    }
+    return $Timg->render();
+  } // html
+} // class form_imagecombo
 // ----------------------------------------------------------------------
 /**
 * Tandem Field class
