@@ -253,7 +253,7 @@ class htmlarea_config {
           "fontsize", "space",
           "formatblock", "space",
           "bold", "italic", "underline", "separator",
-          "undo", "redo", "space", "removeformat"
+          "undo", "redo", "space", "removeformat", "htmlmode"
           ),
         array("space")
         );
@@ -265,17 +265,18 @@ class htmlarea_config {
           "fontname", "space",
           "fontsize", "space",
           "formatblock", "space",
-          "bold", "italic", "underline", "strikethrough", "separator",
-          "copy", "cut", "paste", "space", "undo", "redo", "space", "removeformat"
+          "bold", "italic", "underline", "strikethrough"
           ),
         array(
           "justifyleft", "justifycenter", "justifyright", "justifyfull", "separator",
-          "orderedlist", "unorderedlist", "outdent", "indent", "separator",
+          "orderedlist", "separator", "unorderedlist", "outdent", "indent"
+          ),
+        array(
+          "copy", "cut", "paste", "separator", "undo", "redo", "space", "removeformat",
           "forecolor", "hilitecolor", "separator",
           "inserthorizontalrule", "createlink", "htmlmode", "separator",
           "popupeditor", "separator", "showhelp", "about"
-          ),
-
+          )
         );
   /** A fully-populated toolbar definition for power users
       @access private */
@@ -285,8 +286,7 @@ class htmlarea_config {
           "fontsize", "space",
           "formatblock", "space",
           "bold", "italic", "underline", "strikethrough", "separator",
-          "subscript", "superscript", "separator",
-          "copy", "cut", "paste"
+          "subscript", "superscript", "separator"
           ),
         array(
           "justifyleft", "justifycenter", "justifyright", "justifyfull", "separator",
@@ -294,7 +294,8 @@ class htmlarea_config {
           "orderedlist", "unorderedlist", "outdent", "indent"
           ),
         array(
-           "undo", "redo", "space", "removeformat", "forecolor", "hilitecolor", "separator",
+          "copy", "cut", "paste", "undo", "redo", "space", "removeformat",
+          "forecolor", "hilitecolor", "separator",
           "inserthorizontalrule", "createlink", "insertimage", "inserttable", "htmlmode", "separator",
           "popupeditor", "killword", "separator", "showhelp", "about"
           )
