@@ -117,6 +117,23 @@ class layout extends RenderableObject {
   /** The name of the layout form
       @access private */
   var $layoutfm = "layoutform";
+  /** The group privilege settings for this layout, as
+      read from the database.
+      @access private */
+  var $privileges = array();
+  /** The groups which have privilege settings for this layout, as
+      read from the database.
+      @access private */
+  var $privilege_groups = array();
+  /** The group membership for Editor privilege
+      @access private */
+  var $editor_groups = array(DEFAULT_EDITOR_GROUPS);
+  /** The group membership for Authoring privilege
+      @access private */
+  var $author_groups = array(DEFAULT_AUTHOR_GROUPS);
+  /** The group membership for Entry privilege
+      @access private */
+  var $entry_groups = array(DEFAULT_ENTRY_GROUPS);
   /** The layout blocks, keyed on 'row|col'
       @access private */
   var $layout_blocks = array();
@@ -226,9 +243,72 @@ class layout extends RenderableObject {
       $q  = "SELECT * FROM ax_layout";
       $q .= " WHERE ax_layout.layout_id=$id";
     }
+    // Privilege settings
+    $this->privileges = array();
+    $this->privilege_groups = array();
     $Lq = dbrecordset($q);
     if ($Lq->hasdata) {
       $this->layoutid = $id;
+      // Check for editor & author groups overrides..
+      $q  = "SELECT * FROM ax_layout_set_group lg, ax_group g";
+      $q .= " WHERE g.group_id=lg.group_id";
+      $Lsec = dbrecordset($q);
+      if ($Lsec->hasdata) {
+        $editor = array();
+        $author = array();
+        $entry = array();
+        do {
+          $group_id   = $Lsec->field("group_id");
+          $group_desc = $Lsec->field("group_desc");
+          $group_priv = $Lsec->field("cm_privilege");
+          $this->privileges["$group_priv|$group_id"] = $group_desc;
+          $this->privilege_groups[$group_id] = $group_desc;
+          switch ($group_priv) {
+            case "editor":
+              $editor[] = $group_desc;
+              break;
+            case "author":
+              $author[] = $group_desc;
+              break;
+            case "entry":
+              $entry[] = $group_desc;
+              break;
+          } // switch
+        } while ($Lsec->get_next());
+        debugbr("layout privileges override:", DBG_DEBUG);
+        if (count($editor) > 0) {
+          $this->editor_groups = $editor;
+          debugbr(" --> editor privilege: " . implode(",", $editor), DBG_DEBUG);
+        }
+        if (count($author) > 0) {
+          $this->author_groups = $author;
+          debugbr(" --> author privilege: " . implode(",", $author), DBG_DEBUG);
+        }
+        if (count($entry) > 0) {
+          $this->entry_groups = $entry;
+          debugbr(" --> entry privilege: " . implode(",", $entry), DBG_DEBUG);
+        }
+      }
+      else {
+        debugbr("default privilege settings apply");
+      }
+      // Back-fill with all non-privileged groups
+      $Gp = dbrecordset("SELECT * FROM ax_group");
+      if ($Gp->hasdata) {
+        $unprivileged = array();
+        do {
+          $group_id = $Gp->field("group_id");
+          $group_desc = $Gp->field("group_desc");
+          if (!isset($this->privilege_groups[$group_id])) {
+            $this->privileges["none|$group_id"] = $group_desc;
+            $unprivileged[$group_id] = $group_desc;
+          }
+        } while ($Gp->get_next());
+        foreach($unprivileged as $gid => $gdesc) {
+          $this->privilege_groups[$gid] = $gdesc;
+        }
+      }
+      // Continue populating layout data..
       $this->layout_name = $Lq->field("layout_name");
       if ($RESPONSE->multilang) {
         $this->language = $Lq->field("lang_id");
@@ -307,8 +387,8 @@ class layout extends RenderableObject {
                 case WYSIWYG_EDITOR: $this->tot_wysiwyg += 1; break;
               }
               if (isset($cell->access) && isset($RESPONSE)) {
-                if ($RESPONSE->ismemberof_group_in("Editor,Author") ||
-                   ($RESPONSE->ismemberof_group("Entry") && $this->is_pendingver())
+                if ($RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) ) ||
+                   ($RESPONSE->ismemberof_group_in( $this->entry_groups ) && $this->is_pendingver())
                 ) {
                   if ($cell->access->anypermitted($RESPONSE->group_names_list(), PERM_UPDATE)) {
                     $this->tot_editable += 1;
@@ -461,13 +541,13 @@ class layout extends RenderableObject {
         $required_version == $this->version) {
       // Pending version
       if ($this->is_pendingver()) {
-        if ($RESPONSE->ismemberof_group_in("Editor,Author")) {
+        if ($RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups) )) {
           $perm = true;
         }
       }
       // Live version
       elseif ($this->version == VERSION_LIVE) {
-        if ($RESPONSE->ismemberof_group_in("Editor")) {
+        if ($RESPONSE->ismemberof_group_in( $this->editor_groups )) {
           $perm = true;
         }
       }
@@ -546,7 +626,10 @@ class layout extends RenderableObject {
                   $this->version_count,
                   $this->language,
                   $this->lang_encoding,
-                  $this->lang_direction
+                  $this->lang_direction,
+                  $this->editor_groups,
+                  $this->author_groups,
+                  $this->entry_groups
                   );
             $cell = $Tlay->get_cell($r, $c);
             $cell->setcontent($block->render());
@@ -606,7 +689,7 @@ class layout extends RenderableObject {
     // Add in editing tools if authorised..
     debugbr("layoutcontent: mode is $this->mode", DBG_DEBUG);
     if ($this->mode != "previewing") {
-      $layedit = ($RESPONSE->ismemberof_group_in("Editor,Author,Entry"));
+      $layedit = ($RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups, $this->entry_groups) ));
       $Tvw->td_content("<form name=\"$this->layoutfm\" method=\"post\">\n");
       $formcontent = "";
 
@@ -676,7 +759,9 @@ class layout extends RenderableObject {
         $Tbar = new table("toolbar");
         $Tbar->tr("axtitle");
         if ($this->user_can_edit()) {
-          $Tbar->th("[$this->layout_name]", "axtitle");
+          //$Tbar->th("[$this->layout_name]", "axtitle");
+          $Tbar->th("[Layout]", "axtitle");
+          $Tbar->th_alignment("", "top");
         }
         else {
           $Tbar->th("&nbsp;", "axtitle");
@@ -979,6 +1064,161 @@ class layout extends RenderableObject {
               }
               break;
 
+              // Save button clicked..
+            case "save":
+              global $index_category, $layout_rows, $layout_cols, $layout_padding;
+              global $background_colour, $width_profile, $layout_newcell;
+              global $show_last_modified, $format_last_modified;
+              global $prefix_last_modified, $table_style, $table_width;
+              global $table_autojustify, $table_rowstripes, $layout_style;
+              global $language;
+              global $privs_recmaintpost_data, $privs_recmaintpost_flds, $privs_recmaintpost_form;
+
+              // Get layout table, so we can alter it..
+              $this->get($edit_layoutid);
+
+              // Updated layout parameters..
+              if ($this->index_category != $index_category) {
+                $this->index_category = $index_category;
+                $this->index();
+              }
+              $this->language = $language;
+              $this->show_last_modified = isset($show_last_modified);
+              $this->format_last_modified = $format_last_modified;
+              $this->prefix_last_modified = $prefix_last_modified;
+              $this->layout_style = $layout_style;
+
+              // Table size changed flag..
+              $sizechanged = false;
+
+              // Set layout table parameters..
+              $this->layout_table->setcss("");
+              $this->layout_table->setclass($table_style);
+              $this->layout_table->setwidth($table_width);
+              if (isset($table_rowstripes)) {
+                $this->layout_table->rowstripes("axyl_rowstripe_lite,axyl_rowstripe_dark");
+              }
+              else {
+                $this->layout_table->rowstripes("");
+              }
+              $this->layout_table->autojustify(isset($table_autojustify));
+              $this->layout_table->setpadding($layout_padding);
+              $this->layout_table->setbgcolor($background_colour);
+              if (isset($width_profile)) {
+                $this->layout_table->set_width_profile($width_profile);
+              }
+              // Adjust row changes..
+              $Trows = $this->layout_table->rowcount();
+              if ($layout_rows != $Trows) {
+                $sizechanged = true;
+                if ($layout_rows < $Trows) {
+                  $last = $Trows - 1;
+                  for ($i = 0; $i < $Trows - $layout_rows; $i++) {
+                    $this->layout_table->delete_row($last);
+                    $last -= 1;
+                  }
+                }
+                else {
+                  for ($i = 0; $i < $layout_rows - $Trows; $i++) {
+                    $this->layout_table->append_row( new tablecell("&nbsp;") );
+                  }
+                }
+              }
+              // Adjust for column changes..
+              $Tcols = $this->layout_table->cellcount();
+              if ($layout_cols != $Tcols) {
+                $sizechanged = true;
+                if ($layout_cols < $Tcols) {
+                  $last = $Tcols - 1;
+                  for ($i = 0; $i < $Tcols - $layout_cols; $i++) {
+                    $this->layout_table->delete_cols($last);
+                    $last -= 1;
+                  }
+                }
+                else {
+                  $this->layout_table->append_cols($layout_cols - $Tcols, new tablecell("&nbsp;"));
+                }
+              }
+              // Look for new layout cells..
+              if (isset($layout_newcell)) {
+                foreach ($layout_newcell as $request) {
+                  $bits = explode("|", $request);
+                  $celltype = $bits[0];
+                  $row = $bits[1];
+                  $col = $bits[2];
+                  // Get table cell to change it..
+                  if ($this->layout_table->cell_exists($row, $col)) {
+                    $cell = $this->layout_table->get_cell($row, $col);
+                    // Block cells get new block, plain cells don't..
+                    switch ($celltype) {
+                      // Content Block or Wysiwyg cell..
+                      case BLOCK_CONTENT:
+                      case WYSIWYG_EDITOR:
+                        $b = new block();
+                        $b->layoutid = $this->layoutid;
+                        $b->block_type = $celltype;
+                        $b->put();
+                        $cell->celltype = $celltype;
+                        $cell->blockid = $b->blockid;
+                        break;
+                      // Plain cell..
+                      case PLAIN_CELL:
+                        $cell->celltype = PLAIN_CELL;
+                        $cell->blockid = "";
+                        // Set default cell permissions..
+                        $cell->permit($this->editor_groups, PERM_ALL);
+                        $cell->permit($this->author_groups, PERM_READ|PERM_UPDATE);
+                        break;
+                    } // switch
+                    // Return cell to table..
+                    $this->layout_table->set_cell($row, $col, $cell);
+                  }
+                } // foreach
+              } // new layout cells
+              // Save the layout, stay in edit mode..
+              $this->assign_cellids();
+              $this->put();
+
+              // Privilege settings..
+              if (isset($privs_recmaintpost_form)) {
+                if (isset($privs_recmaintpost_data)
+                    && $privs_recmaintpost_data != "") {
+                  $recs = explode(RECORD_DELIM, $privs_recmaintpost_data);
+                  foreach ($recs as $rec) {
+                    $values = explode(FIELD_DELIM, $rec);
+                    $group_id = array_shift($values);
+                    $fields = explode(",", $privs_recmaintpost_flds);
+                    $pos = 0;
+                    foreach ($fields as $field) {
+                      $privilege = str_replace("priv_", "", $field);
+                      $priv_granted = $values[$pos];
+                      switch ($priv_granted) {
+                        case "t":
+                          if (!isset($this->privileges["$privilege|$group_id"])) {
+                            $pin = new dbinsert("ax_layout_set_group");
+                            $pin->set("layout_name", $this->layout_name);
+                            $pin->set("cm_privilege", "'" . $privilege . "'");
+                            $pin->set("group_id", $group_id);
+                            $pin->execute();
+                          }
+                          break;
+                        case "f":
+                          if (!isset($this->privileges["none|$group_id"])) {
+                            $pdel = new dbdelete("ax_layout_set_group");
+                            $pdel->where("group_id=$group_id");
+                            $pdel->where("AND cm_privilege='$privilege'");
+                            $pdel->execute();
+                          }
+                          break;
+                      } // switch
+                      $pos += 1;
+                    } // foreach
+                  } // foreach recs
+                }
+              }
+              $this->mode = "editing";
+              break;
+
             case "saving":
               // Get layout table, so we can alter it..
               $this->get($edit_layoutid);
@@ -994,7 +1234,13 @@ class layout extends RenderableObject {
               // Blow away whole layout, and start again..
               elseif (isset($_new_x)) {
                 start_transaction();
-                dbcommand("DELETE FROM ax_block WHERE layout_id=$this->layoutid");
+                $blocks = dbrecordset("SELECT block_id FROM ax_block WHERE layout_id=$this->layoutid");
+                if ($blocks->hasdata) {
+                  do {
+                    $b = new block($blocks->field("block_id"));
+                    $b->delete();
+                  } while ($blocks->get_next());
+                }
                 $Lup = new dbupdate("ax_layout");
                 $Lup->set("layout_table", NULLVALUE);
                 $Lup->where("layout_id=$this->layoutid");
@@ -1004,119 +1250,6 @@ class layout extends RenderableObject {
                 if (isset($this->layout_blocks)) unset($this->layout_blocks);
                 $this->mode = "editing";
               }
-              // Save button clicked..
-              elseif (isset($_save_x)) {
-                global $index_category, $layout_rows, $layout_cols, $layout_padding;
-                global $background_colour, $width_profile, $layout_newcell;
-                global $show_last_modified, $format_last_modified;
-                global $prefix_last_modified, $table_style, $table_width;
-                global $table_autojustify, $table_rowstripes, $layout_style;
-                global $language;
-
-                // Updated layout parameters..
-                if ($this->index_category != $index_category) {
-                  $this->index_category = $index_category;
-                  $this->index();
-                }
-                $this->language = $language;
-                $this->show_last_modified = isset($show_last_modified);
-                $this->format_last_modified = $format_last_modified;
-                $this->prefix_last_modified = $prefix_last_modified;
-                $this->layout_style = $layout_style;
-
-                // Table size changed flag..
-                $sizechanged = false;
-
-                // Set layout table parameters..
-                $this->layout_table->setcss("");
-                $this->layout_table->setclass($table_style);
-                $this->layout_table->setwidth($table_width);
-                if (isset($table_rowstripes)) {
-                  $this->layout_table->rowstripes("axyl_rowstripe_lite,axyl_rowstripe_dark");
-                }
-                else {
-                  $this->layout_table->rowstripes("");
-                }
-                $this->layout_table->autojustify(isset($table_autojustify));
-                $this->layout_table->setpadding($layout_padding);
-                $this->layout_table->setbgcolor($background_colour);
-                if (isset($width_profile)) {
-                  $this->layout_table->set_width_profile($width_profile);
-                }
-                // Adjust row changes..
-                $Trows = $this->layout_table->rowcount();
-                if ($layout_rows != $Trows) {
-                  $sizechanged = true;
-                  if ($layout_rows < $Trows) {
-                    $last = $Trows - 1;
-                    for ($i = 0; $i < $Trows - $layout_rows; $i++) {
-                      $this->layout_table->delete_row($last);
-                      $last -= 1;
-                    }
-                  }
-                  else {
-                    for ($i = 0; $i < $layout_rows - $Trows; $i++) {
-                      $this->layout_table->append_row( new tablecell("&nbsp;") );
-                    }
-                  }
-                }
-                // Adjust for column changes..
-                $Tcols = $this->layout_table->cellcount();
-                if ($layout_cols != $Tcols) {
-                  $sizechanged = true;
-                  if ($layout_cols < $Tcols) {
-                    $last = $Tcols - 1;
-                    for ($i = 0; $i < $Tcols - $layout_cols; $i++) {
-                      $this->layout_table->delete_cols($last);
-                      $last -= 1;
-                    }
-                  }
-                  else {
-                    $this->layout_table->append_cols($layout_cols - $Tcols, new tablecell("&nbsp;"));
-                  }
-                }
-                // Look for new layout cells..
-                if (isset($layout_newcell)) {
-                  foreach ($layout_newcell as $request) {
-                    $bits = explode("|", $request);
-                    $celltype = $bits[0];
-                    $row = $bits[1];
-                    $col = $bits[2];
-                    // Get table cell to change it..
-                    if ($this->layout_table->cell_exists($row, $col)) {
-                      $cell = $this->layout_table->get_cell($row, $col);
-                      // Block cells get new block, plain cells don't..
-                      switch ($celltype) {
-                        // Content Block or Wysiwyg cell..
-                        case BLOCK_CONTENT:
-                        case WYSIWYG_EDITOR:
-                          $b = new block();
-                          $b->layoutid = $this->layoutid;
-                          $b->block_type = $celltype;
-                          $b->put();
-                          $cell->celltype = $celltype;
-                          $cell->blockid = $b->blockid;
-                          break;
-                        // Plain cell..
-                        case PLAIN_CELL:
-                          $cell->celltype = PLAIN_CELL;
-                          $cell->blockid = "";
-                          // Set default cell permissions..
-                          $cell->permit("Editor", PERM_ALL);
-                          $cell->permit("Author", PERM_READ|PERM_UPDATE);
-                          break;
-                      } // switch
-                      // Return cell to table..
-                      $this->layout_table->set_cell($row, $col, $cell);
-                    }
-                  } // foreach
-                } // new layout cells
-
-                // Save the layout, stay in edit mode..
-                $this->assign_cellids();
-                $this->put();
-                $this->mode = "editing";
-              }
               // Permissions setting activity..
               elseif (isset($_perm_set_x) || isset($_perm_unset_x)) {
                 global $layout_cellsel, $perm_groups, $perm_perms;
@@ -1287,7 +1420,8 @@ class named_layout extends layout {
 
     // Fallback if required version still not defined..
     if ($this->version == VERSION_UNDEFINED) {
-      if ($this->mode != "previewing" && $RESPONSE->ismemberof_group_in("Editor,Author,Entry")) {
+      if ($this->mode != "previewing"
+       && $RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups, $this->entry_groups) )) {
         $this->version = VERSION_PENDING;
       }
       else {
@@ -1339,7 +1473,7 @@ class named_layout extends layout {
           }
           else {
             if ($this->mode != "previewing"
-              && $RESPONSE->ismemberof_group_in("Editor,Author,Entry")) {
+              && $RESPONSE->ismemberof_group_in( array_merge($this->editor_groups, $this->author_groups, $this->entry_groups) )) {
               $this->message = "Selected layout does not exist. Falling back to Pending.";
             }
           }
