@@ -25,6 +25,10 @@
 /* ******************************************************************** */
 /** @package cm */
 
+/** Record maintainer for perms settings */
+include_once("recmaint-defs.php");
+
+// ----------------------------------------------------------------------
 /**
 * Layouteditor
 * A layouteditor is a utility class. It contains all of the methods
@@ -48,6 +52,7 @@ class layouteditor extends RenderableObject {
   * @param reference $layout A reference to the layout being edited
   */
   function layouteditor(&$layout) {
+    // Find out if there is an Editor group(s) override..
     $this->layout = $layout;
   } // layouteditor
   // ....................................................................
@@ -191,6 +196,14 @@ class layouteditor extends RenderableObject {
 
     $pwidth = "150px";
 
+    // For button form submits with mode setting..
+    $RESPONSE->add_script(
+        "function layoutgo(mode) {\n"
+      . " document.forms." . $this->layout->layoutfm . ".layoutmode.value=mode;\n"
+      . " document.forms." . $this->layout->layoutfm . ".submit();\n"
+      . "}\n"
+      );
+
     // Layout table copy we will use..
     $Tlay = $this->layout->layout_table;
     $Tlay->setstyle("border-width:1px;border-style:dotted;border-color:#0000ff;padding:10px;");
@@ -231,6 +244,7 @@ class layouteditor extends RenderableObject {
     $bredx    = new form_imagebutton("_redx",     "", "", "$LIBDIR/img/_redx.gif",    "Delete",          9,  9);
 
     // Confirmation stuff
+    $bsave->set_onclick("layoutgo('save');");
     $bdelete->set_confirm_text("Delete this block?");
     $bnew->set_confirm_text("This will DELETE the whole layout. Are you sure?");
     $bpublish->set_confirm_text("This will make this pending layout LIVE. Are you sure?");
@@ -247,6 +261,23 @@ class layouteditor extends RenderableObject {
     $lver  = new form_hiddenfield("layout_version",  $this->layout->version);
     $merge = new form_hiddenfield("layout_action");
 
+    // ..................................................................
+    // KEYFIELD and RECORD MAINTAINER
+    // Privileges listbox
+    // Declared here so we can create the maintainer and register buttons
+    // before they are used in the form.
+    //
+    // This is the keyfield listbox which controls the maintainance
+    // process. It lists all records being maintained..
+    $privs_listbox = new form_combofield("priv_group_id");
+    $privs_listbox->setclass("axlistbox");
+    // Make a new privs record maintainer, and attach the buttons..
+    $privs_maintainer = new recmaintainer($this->layout->layoutfm, $privs_listbox, "privs_");
+    // Register privs maintainer buttons..
+    $privs_maintainer->register_button("save", $bsave); // Save button is common to all
+    $privs_listbox->setstyle("width:$pwidth");
+    $privs_listbox->size = 7;
+
     // Control table..
     $Ted = new table($this->layout->layoutfm);
 
@@ -469,7 +500,93 @@ class layouteditor extends RenderableObject {
     $Ted->td_alignment("", "top");
 
     // ..................................................................
-    // PERMISSIONS
+    // EDITING PRIVILEGES
+
+    foreach($this->layout->privilege_groups as $group_id => $group_desc) {
+      $privs_listbox->additem($group_id, $group_desc);
+      // Populate maintainer data. The maintainer add_record method
+      // requires an associative array keyed on listbox key id..
+      $rec = array(
+              "priv_group_id" => $group_id,
+              "priv_editor"   => (isset($this->layout->privileges["editor|$group_id"])) ? "t" : "f",
+              "priv_author"   => (isset($this->layout->privileges["author|$group_id"])) ? "t" : "f",
+              "priv_entry"    => (isset($this->layout->privileges["entry|$group_id"]))  ? "t" : "f",
+              );
+      $privs_maintainer->add_record($group_id, $rec);
+    }
+    // Now set the defaults for each of the fields. These are
+    // necessary for when a new record is created..
+    $defaults = array(
+              "priv_group_id" => 0,
+              "priv_editor"   => "f",
+              "priv_author"   => "f",
+              "priv_entry"    => "f"
+              );
+    $privs_maintainer->add_defaults($defaults);
+
+    $Tpriv = new table("layprivs");
+    $Tpriv->setpadding(2);
+    $Tpriv->setwidth("500");
+    $Tpriv->setcss("margin-left:100px");
+    $Tpriv->tr();
+    $blurb  = "To change the access privileges for layout and block content editing for ";
+    $blurb .= "this layout, highlight the group and select one or more privileges for it.";
+    $blurb .= "Repeat for each group as required, then click the save button.";
+    $Tpriv->td($blurb);
+    $Tpriv->td_colspan(2);
+    $Tpriv->tr();
+
+    // The listbox field..
+    $Tpriv->tr();
+    $Tpriv->td( $privs_listbox->render() );
+    $Tpriv->td_colspan(2);
+
+    $genchk = new form_checkbox("");
+    $genchk->setclass("axchkbox");
+    $genchk->setvalue("yes");
+
+    // Checkbox for each privilege
+    // Editor
+    $Fld = $genchk;
+    $Fld->setname("priv_editor");
+    $Fld->checked = isset($this->layout->privileges["editor|$group_id"]);
+    $privs_maintainer->register_field($Fld);
+    $Tpriv->tr("axbglite");
+    $Tpriv->td($Fld->render());
+    $Tpriv->td("Editor/Publisher");
+
+    // Author
+    $Fld = $genchk;
+    $Fld->setname("priv_author");
+    $Fld->checked = isset($this->layout->privileges["author|$group_id"]);
+    $privs_maintainer->register_field($Fld);
+    $Tpriv->tr("axbgdark");
+    $Tpriv->td($Fld->render());
+    $Tpriv->td("Author of content");
+
+    // Entry
+    $Fld = $genchk;
+    $Fld->setname("priv_entry");
+    $Fld->checked = isset($this->layout->privileges["entry|$group_id"]);
+    $privs_maintainer->register_field($Fld);
+    $Tpriv->tr("axbglite");
+    $Tpriv->td($Fld->render());
+    $Tpriv->td("Data entry");
+
+    $Tpriv->set_width_profile("5%,95%");
+
+    // Render privileges
+    $Ted->tr("axhdg");
+    $Ted->td("<b>LAYOUT PRIVILEGE SETTINGS</b>", "axhdg");
+    $Ted->td_css("text-align:center");
+    $Ted->td_colspan(2);
+    $Ted->tr("axbgdark");
+    $Ted->td( $Tpriv->render() . $privs_maintainer->render() );
+    $Ted->td_alignment("", "top");
+    $Ted->td_colspan(2);
+
+    // ..................................................................
+    // PLAIN-CELL PERMISSIONS
     if ($this->layout->tot_plain > 0) {
       $groups = new form_combofield("perm_groups", "", $perm_groups);
       $groups->multiselect = true;
@@ -499,7 +616,9 @@ class layouteditor extends RenderableObject {
       $btnunset->setimage("$LIBDIR/img/_unset.gif", "Unset permissions");
 
       $Tperm = new table("perms");
+      $Tperm->setpadding(2);
       $Tperm->setwidth("500");
+      $Tperm->setcss("margin-left:100px");
       $Tperm->tr();
       $blurb  = "To set permissions for plain cells which have been selected below, choose ";
       $blurb .= "one or more groups, and select one or more access methods then click ";
@@ -519,9 +638,14 @@ class layouteditor extends RenderableObject {
       $Tperm->td_alignment("right", "top");
 
       // Render perms
+      $Ted->tr("axhdg");
+      $Ted->td("<b>PLAIN-CELL PERMISSIONS</b>", "axhdg");
+      $Ted->td_css("text-align:center");
+      $Ted->td_colspan(2);
       $Ted->tr("axbgdark");
       $Ted->td( $Tperm->render() );
       $Ted->td_alignment("", "top");
+      $Ted->td_colspan(2);
     }
 
     // ..................................................................
@@ -552,6 +676,7 @@ class layouteditor extends RenderableObject {
       $Ted->tr("axbglite");
       $Ted->td( $Tprop->render() );
       $Ted->td_alignment("", "top");
+      $Ted->td_colspan(2);
     }
 
     // ..................................................................
