@@ -988,7 +988,6 @@ class lucene_querymsg extends lucene_message {
     if ($this->response->valid) {
       // Here we will unpack the returned search query hits
       // and store them locally for use by child classes.
-      $this->hitcount = (int)($this->response->count);
       if (isset($this->response->results)) {
         foreach ($this->response->results as $result) {
           $hit = array();
@@ -1037,10 +1036,17 @@ class lucene_indexmsg extends lucene_message {
   * @param string $port Port of Lucene server
   */
   function lucene_indexmsg($application="?", $host="", $port="") {
+    global $RESPONSE;
     $this->lucene_message("LuceneIndexRequest", $application, $host, $port);
     $this->serialno = md5(uniqid(""));
     $this->add_xmltag( new xmltag("Serial", $this->serialno) );
     $this->define_field(DEFAULT_FIELD, DEFAULT_FIELDTYPE, NOT_STORED);
+    // Partitioned indexing for microsites..
+    if (isset($RESPONSE) && $RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+      $site = (isset($RESPONSE->microsite_detected)) ? $RESPONSE->microsite_detected : APP_NAME;
+      $this->define_field("site", "text", STORED, INDEXED);
+      $this->index_field("site", $site);
+    }
   } // lucene_indexmsg
   // .....................................................................
   /**
@@ -1221,9 +1227,15 @@ class lucene_search extends lucene_querymsg {
   * @param string $port Port of Lucene server
   */
   function lucene_search($application="?", $host="", $port="") {
+    global $RESPONSE;
     $this->search();
     $this->lucene_querymsg($application, $host, $port);
     $this->initialise();
+    // Partitioned indexing for microsites..
+    if (isset($RESPONSE) && $RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+      $site = (isset($RESPONSE->microsite_detected)) ? $RESPONSE->microsite_detected : APP_NAME;
+      $this->must_match("site:$site");
+    }
   } // lucene_search
   // .....................................................................
   /**
