@@ -252,12 +252,17 @@ class email {
   * @access private
   */
   function add_array_or_list($addrs, &$addrvar) {
-    if (!is_array($addrs)) {
+    if (is_array($addrs)) {
+      $newads = $addrs;
+    }
+    else {
       $newads = explode(",", $addrs);
     }
-    foreach ($newads as $newad) {
-      if ($newad != "") {
-        $addrvar[] = $newad;
+    if (is_array($newads)) {
+      foreach ($newads as $newad) {
+        if ($newad != "") {
+          $addrvar[] = $newad;
+        }
       }
     }
   } // add_array_or_list
