@@ -71,6 +71,8 @@ define("MENU_ITEM_SUBMENU",   "(sub-menu only)");
 define("MENU_ITEM_SPACER",    "(menu spacer)");
 /** The menu item is a separator line */
 define("MENU_ITEM_SEPARATOR", "(menu separator)");
+/** The menu item is an ad-hoc URL */
+define("MENU_ITEM_URL", "(ad-hoc URL)");
 
 // ----------------------------------------------------------------------
 /**
@@ -899,6 +901,7 @@ class menuop_instance {
   var $label = "";
   var $desc = "";
   var $action = "";
+  var $target = "";
   var $authcode = false;
   var $parent = "";
   var $children = "";
@@ -912,16 +915,18 @@ class menuop_instance {
   * @param string  $label The menu option label
   * @param string  $desc The menu option long description
   * @param string  $act The menu option action (eg. path to webpage)
+  * @param string  $targ The menu option target frame (eg. '_new')
   * @param boolean $auth Whether to apply auth_code or not true or false
   * @param integer $parent The menu option ID of the parent of this menu option
   * @param boolean $is_parent Whether this option is parent of other options
   */
-  function menuop_instance($id, $menu_level, $label="", $desc="", $act="", $authcode=false, $parent="", $is_parent=false) {
+  function menuop_instance($id, $menu_level, $label="", $desc="", $act="", $targ="", $authcode=false, $parent="", $is_parent=false) {
     $this->id = $id;
     $this->menu_level = $menu_level;
     $this->label = $label;
     $this->desc = $desc;
     $this->action = $act;
+    $this->target = $targ;
     $this->authcode = $auth;
     $this->parent = $parent;
     $this->is_parent = $is_parent;
@@ -937,6 +942,7 @@ class menuop_instance {
          . "|$this->label"
          . "|$this->desc"
          . "|$this->action"
+         . "|$this->target"
          . "|" . ($this->authcode ? "t" : "f")
          ;
   } // details
@@ -1036,9 +1042,9 @@ class menu_instance {
   * @param integer $parent The menu option ID of the parent of this menu option
   * @param boolean $is_parent Whether this option is parent of other options
   */
-  function add_menuop($id, $menu_level, $label="", $desc="", $act="", $authcode=false, $parent="", $is_parent=false) {
+  function add_menuop($id, $menu_level, $label="", $desc="", $act="", $targ="", $authcode=false, $parent="", $is_parent=false) {
     $this->menu_ops[$id] =
-        new menuop_instance($id, $menu_level, $label, $desc, $act, $authcode, $parent, $is_parent);
+        new menuop_instance($id, $menu_level, $label, $desc, $act, $targ, $authcode, $parent, $is_parent);
   } // add_menuop
   // ....................................................................
   /** Return true if menu option exists.
@@ -1086,24 +1092,29 @@ class menu_instance {
   * @return boolean True if the menu was modified, and hence got.
   */
   function get_if_modified() {
-    // Now check last read time vs database mod times..
-    $modified = false;
-    $last_read = timestamp_to_datetime($this->last_readts);
-    $q  = "SELECT COUNT(*) AS tot FROM ax_menuoption";
-    $q .= " WHERE menu_id=$this->menu_id";
-    $q .= "   AND last_modified > '$last_read'";
-    $modQ = dbrecordset($q);
-    if ($modQ->field("tot") > 0) {
+    global $RESPONSE;
+    if ($RESPONSE->cachecontrol == "refresh") {
       $modified = true;
     }
-    if (!$modified) {
-      $q  = "SELECT COUNT(*) AS tot FROM ax_menu";
+    else {
+      $modified = false;
+      $last_read = timestamp_to_datetime($this->last_readts);
+      $q  = "SELECT COUNT(*) AS tot FROM ax_menuoption";
       $q .= " WHERE menu_id=$this->menu_id";
       $q .= "   AND last_modified > '$last_read'";
       $modQ = dbrecordset($q);
       if ($modQ->field("tot") > 0) {
         $modified = true;
       }
+      if (!$modified) {
+        $q  = "SELECT COUNT(*) AS tot FROM ax_menu";
+        $q .= " WHERE menu_id=$this->menu_id";
+        $q .= "   AND last_modified > '$last_read'";
+        $modQ = dbrecordset($q);
+        if ($modQ->field("tot") > 0) {
+          $modified = true;
+        }
+      }
     }
     if ($modified) {
       $this->get();
@@ -1179,6 +1190,7 @@ class menu_instance {
             $label      = $item->field("label");
             $desc       = $item->field("description");
             $action     = $item->field("action");
+            $target     = $item->field("target");
             $authcode   = $item->istrue("auth_code");
             $is_parent  = $item->istrue("is_parent");
             if ($menu_level == 0) {
@@ -1198,6 +1210,7 @@ class menu_instance {
                   $label,
                   $desc,
                   $action,
+                  $target,
                   $authcode,
                   $parent_id,
                   $is_parent
