@@ -237,6 +237,7 @@ class menumaintainer extends HTMLObject {
           $menuoption->description    = $mnuQ->field("description");
           $menuoption->display_order  = $mnuQ->field("display_order");
           $menuoption->action         = $mnuQ->field("action");
+          $menuoption->target         = $mnuQ->field("target");
           $menuoption->sitepage       = $mnuQ->field("sitepage");
           $menuoption->sitepage_parms = $mnuQ->field("sitepage_parms");
           $menuoption->auth_code      = $mnuQ->istrue("auth_code");
@@ -344,7 +345,7 @@ class menumaintainer extends HTMLObject {
     global $RESPONSE;
 
     // Width of large form elements..
-    $ewidth = "220px";
+    $ewidth = "300px";
     $pwidth = "110px";
 
     // Generic combo for user groups..
@@ -363,6 +364,7 @@ class menumaintainer extends HTMLObject {
     $cboWebPages->additem(MENU_ITEM_SUBMENU);
     $cboWebPages->additem(MENU_ITEM_SPACER);
     $cboWebPages->additem(MENU_ITEM_SEPARATOR);
+    $cboWebPages->additem(MENU_ITEM_URL);
     $gQ = dbrecordset("SELECT * FROM ax_sitepage WHERE enabled=TRUE ORDER BY page_title");
     if ($gQ->hasdata) {
       do {
@@ -521,12 +523,24 @@ class menumaintainer extends HTMLObject {
       // Populate listbox..
       $menuoption_listbox->additem($m->menuoptionid, $m->label);
 
+      // Set the displayed menu action..
+      $actionbits = explode("?", $m->action);
+      $menuaction = $actionbits[0];
+      if ($menuaction == "" || $menuaction == $m->sitepage) {
+        $menuaction = MENU_ITEM_URL;
+      }
+      else {
+        $menuaction = $m->sitepage;
+      }
+
       // Populate maintainer data. The maintainer add_record method
       // requires an associative array keyed on listbox key id..
       $rec = array(
               "parent_id"      => $m->parent_id,
               "label"          => $m->label,
               "description"    => $m->description,
+              "action"         => $menuaction,
+              "target"         => $m->target,
               "sitepage"       => $m->sitepage,
               "sitepage_parms" => $m->sitepage_parms,
               "is_parent"      => (($m->is_parent) ? "t" : "f"),
@@ -553,6 +567,8 @@ class menumaintainer extends HTMLObject {
               "parent_id"      => $default_parent_id,
               "label"          => MENU_ITEM_SUBMENU,
               "description"    => "",
+              "action"         => MENU_ITEM_URL,
+              "target"         => "",
               "sitepage"       => MENU_ITEM_SUBMENU,
               "sitepage_parms" => "",
               "is_parent"      => "f",
@@ -648,25 +664,58 @@ class menumaintainer extends HTMLObject {
     $Ted->td( "&nbsp;" );
 
     // ..................................................................
-    // Menuoption sitepage and sitepage parms fields..
+    // Menuoption sitepage and sitepage parms, action & target fields..
     $menuop_spage = $cboWebPages;
     $menuop_spage->name = "sitepage";
     $maintainer->register_field($menuop_spage);
     $menuop_spage->setvalue($m->sitepage);
     $menuop_spage->setstyle("width:$ewidth;");
 
+    $menuop_action = new form_textfield("action");
+    $maintainer->register_field($menuop_action);
+    $menuop_action->setstyle("width:$ewidth;");
+    $menuop_action->setclass("axtxtbox");
+    $menuop_action->set_onblur("setAdhocURL(this,'" . $this->formname . "','_')");
+
     $menuop_spage_parms = new form_textfield("sitepage_parms", "", $m->sitepage_parms);
     $maintainer->register_field($menuop_spage_parms);
     $menuop_spage_parms->setstyle("width:$ewidth;");
     $menuop_spage_parms->setclass("axtxtbox");
+
+    $menuop_target = new form_textfield("target");
+    $maintainer->register_field($menuop_target);
+    $menuop_target->setstyle("width:$pwidth;");
+    $menuop_target->setclass("axtxtbox");
+
     $Ted->tr("axbglite");
     $Ted->td( "Target webpage:", "axfg" );
     $Ted->td( $menuop_spage->render() );
     $Ted->td( "&nbsp;" );
-    $Ted->tr("axbgdark");
+    $Ted->tr("axbglite");
+    $Ted->td( "or:", "axfg" );
+    $Ted->td_alignment("right");
+    $Ted->td( $menuop_action->render() );
+    $Ted->td( "&nbsp;" );
+    $Ted->tr("axbglite");
     $Ted->td( "URL Parameters:", "axfg" );
     $Ted->td( $menuop_spage_parms->render() );
     $Ted->td( "&nbsp;" );
+    $Ted->tr("axbglite");
+    $Ted->td( "Target frame:", "axfg" );
+    $Ted->td( $menuop_target->render() );
+    $Ted->td( "&nbsp;" );
+
+    $RESPONSE->add_script(
+        "function setAdhocURL(elem, fm, pfx) {\n"
+      . " if(elem.value!='" . MENU_ITEM_URL . "') {\n"
+      . "  pgcombo=eval('document.forms.'+fm+'.sitepage');\n"
+      . "  if(pgcombo!=null) {\n"
+      . "   comboSet(pgcombo, '" . MENU_ITEM_URL . "');\n"
+      . "   changedValue(fm, pgcombo, pfx);\n"
+      . "  }\n"
+      . " }\n"
+      . "}\n"
+        );
 
     // ..................................................................
     // Menuoption user groups field..
@@ -749,6 +798,7 @@ class menumaintainer extends HTMLObject {
   * @access private
   */
   function menu_entry($rendermode, $prefix, $mopid, $mno_children, $mno_details) {
+    debug_trace($this);
     global $RESPONSE;
     $childcount = 0;
     $submnu = new table();
@@ -785,6 +835,7 @@ class menumaintainer extends HTMLObject {
         $pfxcount += 1;
       }
     }
+    debug_trace();
     return $submnu->render();
   } // menu_entry
   // ....................................................................
@@ -936,9 +987,7 @@ class menumaintainer extends HTMLObject {
   */
   function html() {
     debug_trace($this);
-    global $LIBDIR;
     global $RESPONSE;
-    global $edit_menu_id;
 
     $s = "";
 
@@ -970,6 +1019,7 @@ class menumaintainer extends HTMLObject {
       $s .= $mode->render() . $mid->render() . $pid->render() . $mlevel->render();
       $s .= "</form>\n";
     }
+    debug_trace();
     return $s;
   } // html
   // ....................................................................
@@ -1060,7 +1110,15 @@ class menumaintainer extends HTMLObject {
               if (isset($_recmaintpost_dels) && $_recmaintpost_dels != "") {
                 $menuoption_delids = explode(FIELD_DELIM, $_recmaintpost_dels);
                 foreach ($menuoption_delids as $delmenuoptionid) {
-                  dbcommand("DELETE FROM ax_menuoption WHERE menuoption_id=$delmenuoptionid");
+                  // First, clear out microsite references to this menu option..
+                  $mopnul = new dbupdate("ax_microsite_page");
+                  $mopnul->set("menuoption_id", NULLVALUE);
+                  $mopnul->where("menuoption_id=$delmenuoptionid");
+                  $mopnul->execute();
+                  // Remove menuoption..
+                  $mopdel = new dbdelete("ax_menuoption");
+                  $mopdel->where("menuoption_id=$delmenuoptionid");
+                  $mopdel->execute();
                 }
               }
               // Menu option adds and saves..
@@ -1095,13 +1153,8 @@ class menumaintainer extends HTMLObject {
                   $um->where("menuoption_id=$menuoptionid");
                   $pos = 0; $sitepage = ""; $sitepage_parms = "";
                   foreach ($menuoption_fields as $menuoption_field) {
-                    if ($menuoption_field == "sitepage") {
-                      $sitepage = $menuoption_values[$pos];
-                    }
-                    elseif ($menuoption_field == "sitepage_parms") {
-                      $sitepage_parms = $menuoption_values[$pos];
-                    }
-                    elseif ($menuoption_field == "parent_id") {
+                    // Set the menu level..
+                    if ($menuoption_field == "parent_id") {
                       $new_parid = $menuoption_values[$pos];
                       if ($new_parid != $this->edit_parent_id) {
                         if ($new_parid == 0) {
@@ -1118,8 +1171,22 @@ class menumaintainer extends HTMLObject {
                         $um->set("menu_level", $menulevel);
                       }
                     }
-                    // Set the current value assignment..
-                    $um->set($menuoption_field, $menuoption_values[$pos++]);
+                    // Record sitepage settings for later..
+                    if ($menuoption_field == "sitepage") {
+                      $sitepage = $menuoption_values[$pos];
+                    }
+                    elseif ($menuoption_field == "sitepage_parms") {
+                      $sitepage_parms = $menuoption_values[$pos];
+                    }
+
+                    if ($menuoption_field == "action") {
+                      // Defer action setting 'til later..
+                      $menuaction = $menuoption_values[$pos++];
+                    }
+                    else {
+                      // All other 'normal' field settings..
+                      $um->set($menuoption_field, $menuoption_values[$pos++]);
+                    }
                   } // foreach
 
                   // Post-processing for label and menu action etc..
@@ -1127,29 +1194,38 @@ class menumaintainer extends HTMLObject {
                     // Special-function menu items first..
                     case MENU_ITEM_SPACER:
                       $um->set("label", MENU_ITEM_SPACER);
-                      $um->set("action", "");
+                      $menuaction = "";
                       break;
                     case MENU_ITEM_SEPARATOR:
                       $um->set("label", MENU_ITEM_SEPARATOR);
-                      $um->set("action", "");
+                      $menuaction = "";
                       break;
                     case MENU_ITEM_SUBMENU:
-                      $um->set("action", "");
+                      $menuaction = "";
+                      break;
+                    case MENU_ITEM_URL:
+                      // Leave menuaction as-is..
                       break;
                     // Normal menu items last..
                     default:
                       $menuaction = $sitepage;
-                      if ($menuaction != "") {
-                        if (substr($menuaction, 0, 1) != "/") {
-                          $menuaction = "/$menuaction";
-                        }
-                        if ($sitepage_parms != "") {
-                          $menuaction .= "?" . $sitepage_parms;
-                        }
-                      }
-                      $um->set("action", $menuaction);
                   } // switch
 
+                  // Set the resulting menu action..
+                  if ($menuaction != "") {
+                    // Fix leading slash for action and sitepage if reqd..
+                    if (substr($menuaction, 0, 1) != "/" && !protocol_prefixed($menuaction)) {
+                      $menuaction = "/$menuaction";
+                      if ($sitepage != MENU_ITEM_URL) {
+                        $um->set("sitepage", $menuaction);
+                      }
+                    }
+                    if ($sitepage_parms != "") {
+                      $menuaction .= "?" . $sitepage_parms;
+                    }
+                  }
+                  $um->set("action", $menuaction);
+
                   // Set lastmodified, and fire it off..
                   $um->set("last_modified", 'now()');
                   $um->execute();
