@@ -185,27 +185,27 @@ class generic_monitor {
 /**
 * A monitor class to exec a script/program on the OS. This allows you
 * to hook up an external script or program to the monitoring system
-* with the flexibility to determine success/failure by return code,
+* with the flexibility to determine success/failure by return value
 * or by comparing output with an expected (regex) pattern. The default
-* test is to test the return code of the script/program and if it is
-* zero (0), then the check is deemed to be successful, otherwise not.
+* test is to test the output of the script/program and if it is nullstring
+* (''), then the check is deemed to be successful, otherwise not.
 * There is also a flag, in the constructor ($publish_output) which,
-* if true, directs the monitor to include any output lines returned
-* from the script in the email/SMS messages. This can sometimes be
-* useful for providing extra information in error reports.
+* if true, directs the monitor to include any script output in the email
+* or SMS messages. This can sometimes be useful for providing extra
+* information in error reports.
 * @package monitor
 */
 class exec_monitor extends generic_monitor {
   var $execpath = "";
   var $execparms = "";
-  var $success_code = 0;
+  var $success_value = "";
   var $success_regex = "";
   var $publish_output = false;
   // ....................................................................
   /**
   * Define a new exec check object.
   * @param string $exec Script/program to execute, including any parameters
-  * @param string $success_regex Regex to match on output of script/program
+  * @param string $success_regex Regex to match with the output of script/program
   * @param boolean $publish_output Publish script/program output in all messages
   */
   function exec_monitor($exec, $success_regex="", $publish_output=false) {
@@ -221,18 +221,15 @@ class exec_monitor extends generic_monitor {
   } // exec_monitor
   // ....................................................................
   /**
-  * Allows you to specify an integer code which, if returned by the
-  * called script/program, will designate success.
-  * NOTES:
-  * 1) The default code for success is already zero (0), so no need to
-  *    specify it in that particular case.
-  * 2) This code will be over-ridden if you specify a regular expression
-  *    with the set_success_pattern() method.
-  * @param integer $code Return code indicating success
+  * Allows you to specify a string value which, if returned as output by
+  * the called script/program, will indicate success.
+  * The default value for success is already nullstring, so no need to
+  * specify it in that particular case.
+  * @param integer $code Return value which indicates success
   */
-  function set_success_code($code=0) {
-    $this->success_code = $code;
-  } // set_success_code
+  function set_success_value($success="") {
+    $this->success_value = $success;
+  } // set_success_value
   // ....................................................................
   /**
   * Allows you to specify a regular expression which will be applied to
@@ -260,17 +257,17 @@ class exec_monitor extends generic_monitor {
           $prog .= " $this->execparms";
         }
         // Execute it..
-        exec($prog, $outputlines, $returnvar);
+        $output = shell_exec($prog);
 
         // Check for success or failure..
         if ($this->success_regex != "") {
           $success = (preg_match("/$this->success_regex/", $output, $matches) == 1);
         }
         else {
-          $success = ($this->success_code == $returnvar);
+          $success = ($this->success_value == $output);
         }
 
-        if (!$success) {
+        if ($success === false) {
           $this->set_condition($this->fail_condition);
           $this->set_default_messages(
               $this->fail_condition,
@@ -286,8 +283,8 @@ class exec_monitor extends generic_monitor {
               "$this->execpath OK"
               );
         }
-        if ($this->publish_output && count($outputlines) > 0) {
-          $this->all_messages_append( " " . implode(" ", $outputlines) );
+        if ($this->publish_output && $output != "") {
+          $this->all_messages_append( " " . $output);
         }
       }
       else {
@@ -572,21 +569,21 @@ class lucene_monitor extends generic_monitor {
       $this->lusearch->execute();
       // VALID LUCENE RESPONSE..
       if ($this->lusearch->response->valid) {
-        if ($this->lusearch->hitcount == $this->luhits) {
+        if ($this->lusearch->hitcount() == $this->luhits) {
           $res = true;
           $this->set_condition(COND_OK);
           $this->set_default_messages(
             COND_OK,
-            "Lucene ($this->luhost_abbrev:$this->luport) hits: " . $this->lusearch->hitcount . "/" . $this->luhits,
-            "LUCENE $this->luhost_abbrev HITS: " . $this->lusearch->hitcount . "/" . $this->luhits
+            "Lucene ($this->luhost_abbrev:$this->luport) hits: " . $this->lusearch->hitcount() . "/" . $this->luhits,
+            "LUCENE $this->luhost_abbrev HITS: " . $this->lusearch->hitcount() . "/" . $this->luhits
             );
         }
         else {
           $this->set_condition($this->fail_condition);
           $this->set_default_messages(
             $this->fail_condition,
-            "Lucene ($this->luhost_abbrev:$this->luport) hits: " . $this->lusearch->hitcount . "/" . $this->luhits,
-            "LUCENE $this->luhost_abbrev HITS: " . $this->lusearch->hitcount . "/" . $this->luhits
+            "Lucene ($this->luhost_abbrev:$this->luport) hits: " . $this->lusearch->hitcount() . "/" . $this->luhits,
+            "LUCENE $this->luhost_abbrev HITS: " . $this->lusearch->hitcount() . "/" . $this->luhits
             );
         }
       }
