@@ -427,15 +427,15 @@ class DB_dbfield extends dbfield {
   /** Whether this field is an array of values */
   var $isarray = false;
   // ....................................................................
-  function DB_dbfield(&$schema, $name, $num, $type, $default="", $notnull=false, $ispkey=false, $isarray=false) {
-    $this->dbfield($schema, $name, $num, $type, $default, $notnull, $ispkey);
+  function DB_dbfield(&$schema, $name, $num, $type, $defaultval="", $notnull=false, $ispkey=false, $isarray=false) {
+    $this->dbfield($schema, $name, $num, $type, $defaultval, $notnull, $ispkey);
     $this->isarray = $isarray;
   }
   // ....................................................................
   /** Dump field description to stdout. */
   function dump() {
     $s = "$this->name $this->type";
-    if ($this->default != "") $s .= " DEFAULT $this->default";
+    if ($this->defaultval != "") $s .= " DEFAULT $this->defaultval";
     if ($this->notnull) $s .= " NOT NULL";
     if ($this->isarray) $s .= " (array)";
     if ($this->ispkey) $s .= " (pk)";
@@ -839,7 +839,7 @@ class DB_dbtable extends dbtable {
   }
   // ....................................................................
   /** Create a new field in the table with given parameters. */
-  function newfield($name, $num, $type, $default="", $notnull=false, $isarray=false) {
+  function newfield($name, $num, $type, $defaultval="", $notnull=false, $isarray=false) {
     $ispkey = (in_array($num, $this->pkey));
     $this->fields[$name] =
       new DB_dbfield(
@@ -847,7 +847,7 @@ class DB_dbtable extends dbtable {
           $name,
           $num,
           $type,
-          $default,
+          $defaultval,
           $notnull,
           $ispkey,
           $isarray
@@ -891,7 +891,7 @@ class DB_dbtable extends dbtable {
   function addcolumn($column) {
     $s = "alter table $this->name\n";
     $s .= "  add column $column->name $column->type;\n";
-    if ($column->default != "") {
+    if ($column->defaultval != "") {
       $s .= $this->setdefault($column);
     }
     if ($column->notnull) {
