@@ -290,26 +290,27 @@ class pluginset {
   } // clear
   // .....................................................................
   /**
-  * Add a new plugin to the plugin set. The type of plugin is
-  * determined from the content passed as the second paramter.
-  * Allowed types: object (must inherit RenderableObject), a
-  * function definition, a file-path, or just literal content.
-  * @param string $pluginid  ID of this plugin. Used to find plugin location
-  * @param mixed  $content   The plugin content (literal, function, object...)
+  * Add a new plugin to the plugin set. The type of plugin is determined
+  * from the content passed as the second paramter. Allowed data-types
+  * for content: object (must inherit RenderableObject), a function
+  * definition, a file-path, or just literal content.
+  * @param string $pluginid ID of this plugin. Used to find plugin location
+  * @param mixed $content The plugin content (literal, function, object...)
   */
   function add_plugin($pluginid, $content="") {
     $pluginid = strtoupper($pluginid);
-    debugbr("adding plugin '$pluginid'");
+    debugbr("pluginset: defining new plugin '$pluginid'", DBG_DEBUG);
     $this->plugins[$pluginid] = new plugin($pluginid, $content);
     $this->hascontent = true;
     return $this;
   } // add_plugin
   // .....................................................................
   /**
-  * Adds content to the given plugin. If the plugin doesn't
-  * exist yet, then we create it first.
-  * @param string $pluginid  ID of this plugin. Used to find plugin location
-  * @param mixed  $content   Content to plug in. May be string, path, object or function def.
+  * Adds content to the given plugin. If the plugin doesn't exist yet,
+  * then we create it first. If it already exists, then we append the
+  * new content to it.
+  * @param string $pluginid ID of this plugin. Used to find plugin location
+  * @param mixed $content The plugin content (literal, function, object...)
   */
   function addto($pluginid, $content) {
     $pluginid = strtoupper($pluginid);
@@ -453,12 +454,15 @@ class plugin extends page_section {
 class plugin_content {
   /** The plugin content */
   var $content;
+  /** Whether the content is valid */
+  var $valid = false;
   /**
   * Constructor. Create a new literal plugin object.
   * @param string $content Literal content to be plugged in
   */
   function plugin_content($content="") {
     $this->content = $content;
+    $this->valid = true;
   } // plugin_content
   // .....................................................................
   /**
@@ -493,8 +497,9 @@ class file_plugin_content extends plugin_content {
         $this->path = $path;
         $plugfile = new inputfile($path);
         if ($plugfile->opened) {
-          $this->content = $plugfile->readall();
+          $this->content = trim($plugfile->readall());
           $plugfile->closefile();
+          $this->valid = true;
         }
       }
     }
@@ -527,6 +532,7 @@ class func_plugin_content extends plugin_content {
       $argstr = str_replace("\"", "", $argstr);
       $argstr = str_replace("'",  "", $argstr);
       $this->funcargs = explode(",", $argstr);
+      $this->valid = true;
     }
   } // func_plugin_content
   // .....................................................................
@@ -566,8 +572,12 @@ class object_plugin_content extends plugin_content {
   * @param object $obj Object to use for content
   */
   function object_plugin_content($obj) {
-    if (method_exists($obj, "html")) {
+    if (method_exists($obj, "html")
+     || method_exists($obj, "wml")
+     || method_exists($obj, "wmlup")
+    ) {
       $this->obj = $obj;
+      $this->valid = true;
     }
   } // object_plugin_content
   // .....................................................................
@@ -584,5 +594,43 @@ class object_plugin_content extends plugin_content {
   } //render
 } // object_plugin_content class
 
+// ----------------------------------------------------------------------
+/**
+* Cm Layout plugin content
+* Contains details of a Content-Managed Layout block which is to
+* be generated and plugged in. The ID of the layout is provided.
+* @package core
+* @access private
+*/
+class cm_plugin_content extends plugin_content {
+  /** The text identifier of the CM layout
+      which returns content */
+  var $layoutid;
+  // .....................................................................
+  /**
+  * Constructor
+  * Create a new CM layout plugin object.
+  * @param string $layoutid Unique string naming/identifying the layout.
+  */
+  function cm_plugin_content($layoutid="") {
+    if ($layoutid != "") {
+      $this->layoutid = $layoutid;
+      $this->valid = true;
+    }
+  } // cm_plugin_content
+  // .....................................................................
+  /**
+  * Generate CM Layout content. All that is required here is the
+  * specific format required to be plugged into the webpage.
+  * @return string Plugin content.
+  */
+  function render() {
+    if ($this->valid) {
+      $this->content = "\"<!--LAYOUTID=\\\"" . $this->layoutid . "\\\"-->\"";
+    }
+    return $this->content;
+  } //render
+} // cm_plugin_content class
+
 // ----------------------------------------------------------------------
 ?>
\ No newline at end of file
