@@ -70,6 +70,13 @@ define("METADATA_ENABLED",    true );
 /** Disable metadata editing and generation enhancements */
 define("METADATA_DISABLED",   false );
 
+// -----------------------------------------------------------------------
+// MICROSITE OPTIONS
+/** Enable microsites editing and generation enhancements */
+define("MICROSITES_ENABLED",    true );
+/** Disable microsites editing and generation enhancements */
+define("MICROSITES_DISABLED",   false );
+
 // -----------------------------------------------------------------------
 // MULIT-LANGUAGE OPTIONS
 /** Enable multi-language extensions */
@@ -144,7 +151,6 @@ if (file_exists("$DOCUMENT_ROOT/application.xml")) {
       define($defname, $defval);
     }
     foreach ($application->globals as $globname => $globval) {
-      global $globname;
       $$globname = $globval;
     }
   }
@@ -241,6 +247,10 @@ class response extends webpage {
   var $datasource;
   /** Metadata edit/generation mode we are in */
   var $metadata_mode = METADATA_DISABLED;
+  /** Microsites edit/generation mode we are in */
+  var $microsites_mode = MICROSITES_DISABLED;
+  /** Name of the microsite detected, or undefined */
+  var $microsite_detected;
   /** The URL of this website */
   var $site_url;
   /** The host of this website ie. 'foo.thingy.co.nz' */
@@ -286,6 +296,9 @@ class response extends webpage {
   /** Globals object. Manages the global vars in this response
       @access private */
   var $globals;
+  /** Cache control directive, usually passed on URL
+      @access private */
+  var $cachecontrol;
   /** Dynamic page expiry in seconds. Time to allow a dynamic page to
       'live' in user browser. Note this defaults to -1, which means
       'in the past', and which causes us to force the users browser
@@ -470,8 +483,16 @@ class response extends webpage {
         $this->site_docroot = $DOCUMENT_ROOT;
     } // switch
 
-    if (dirname($PHP_SELF) != "/")
-    $this->site_url .= dirname($PHP_SELF);
+    if (dirname($PHP_SELF) != "/") {
+      $this->site_url .= dirname($PHP_SELF);
+    }
+
+    // Possible cache control directive. This is usually
+    // passed in on the URL to force refresh or something..
+    global $cachecontrol;
+    if (isset($cachecontrol)) {
+      $this->cachecontrol = strtolower($cachecontrol);
+    }
 
     // The page being requested and the query string.
     // These are just our local copies..
@@ -613,6 +634,13 @@ class response extends webpage {
       $this->head->set_dtd($dtd);
     }
     $this->check_group_membership();
+    debug("page: template '$template' ", DBG_DEBUG);
+    if ($theme != "") {
+      debugbr("theme '$theme'", DBG_DEBUG);
+    }
+    else {
+      debugbr(" (default theme)", DBG_DEBUG);
+    }
   } // page
   // ...................................................................
   /**
@@ -1129,6 +1157,19 @@ class response extends webpage {
   } // set_metadata_mode
   // ...................................................................
   /**
+  * Set microsites mode
+  * This setting determines whether Axyl will implement the microsites
+  * enhancements that it has. If true, then users with content manager
+  * privileges will be able to create and maintain "microsites" within
+  * the current Axyl website framework. These are essentially simple
+  * themes, using Axyl themeing.
+  * @param bool $mode Microsites feature enable mode, true or false
+  */
+  function set_microsites_mode($mode=MICROSITES_ENABLED) {
+    $this->microsites_mode = $mode;
+  } // set_microsites_mode
+  // ...................................................................
+  /**
   * Set page expiry in seconds. This affects all of the pages returned by Axyl.
   * Normally this is left at -1, which causes the system to tell the user browser
   * to NOT cache the webpage, and revalidate every time. This is the usual case
@@ -1385,14 +1426,14 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
     }
   }
 
-  // UNICODE INCLUDE..
+  // UNICODE
   // If the above loop brought in the multilang setting as true
   // then we will be needing the Unicode functions..
   if ($RESPONSE->multilang) {
     include_once("unicode-defs.php");
   }
 
-  // Default webmaster, and webmaster email..
+  // WEBMASTER SETTINGS
   if ($WEBMASTER_PERSON == "") {
     $WEBMASTER_PERSON = "The " . ((APP_NAME != "") ? (APP_NAME . " ") : "") . "Webmaster";
   }
@@ -1400,19 +1441,21 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
     $WEBMASTER_EMAIL = "webmaster@" . $this->http_host;
   }
 
-  // Debugging control..
+  // DEBUGGING
   $debugging = $application->getparameter("debug_on", "debug_on");
   if ($debugging) {
     debug_on($application->getparameter("debug_classes", "debug_classes"));
     debug_output($application->getparameter("debug_output", "debug_output"));
   }
 
-  // Make some checks/adjustments..
+  // MOBILE PHONES
+  // No cookie-based 'keep' feature for these..
   if ($RESPONSE->browser == BROWSER_NONE
   ||  $RESPONSE->browser == BROWSER_PHONE) {
     $RESPONSE->set_keep(false);
   }
 
+  // ABSOLUTE REFERENCES
   // Turm relative references to web docroot absolute..
   if (isset($TEMPLATESDIR) && substr($TEMPLATESDIR,0,1) != "/") {
     $TEMPLATESDIR = "/$TEMPLATESDIR";
@@ -1430,10 +1473,64 @@ if (file_exists("$DOCUMENT_ROOT/application.xml") && isset($application) && $app
     $INCDIR = "/$INCDIR";
   }
 
+  // ACTIVATION
   // No longer required..
   unset($application);
   // Activate the response, determine user etc..
   $RESPONSE->activate();
+
+  // SET MICROSITE THEME
+  if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+    debugbr("microsite features are enabled", DBG_DEBUG);
+    // Get the hostname/URL of this request..
+    //$hostbits = explode(".", $HTTP_HOST);
+    $hostname = strtolower($HTTP_HOST);
+    $hostname = str_replace("-test", "", $hostname);
+    // Check this hostname against our microsite domains..
+    $q  = "SELECT mi.microsite_name,mi.microsite_domain,m.menu_name";
+    $q .= "  FROM ax_microsite mi, ax_menu m";
+    $q .= " WHERE mi.currently_installed=TRUE";
+    $q .= "   AND mi.req_microsite_remove=FALSE";
+    $q .= "   AND m.menu_id=mi.menu_id";
+    $microsites = dbrecordset($q);
+    if ($microsites->hasdata) {
+      do {
+        $microsite_domain = $microsites->field("microsite_domain");
+        if (stristr($hostname, $microsite_domain)) {
+          debugbr("microsite scan hit: [$microsite_domain]", DBG_DEBUG);
+          $RESPONSE->microsite_detected = $microsites->field("microsite_name");
+          $theme = $RESPONSE->microsite_detected;
+          $THEME_TITLE = $microsites->field("microsite_desc");
+          $THEME_MENU = $microsites->field("menu_name");
+          break;
+        }
+      } while ($microsites->get_next());
+      // Detect index page request..
+      if (isset($RESPONSE->microsite_detected)) {
+        switch ($RESPONSE->requested) {
+          case "":
+          case "/":
+          case "/index.php":
+            $q  = "SELECT * FROM ax_microsite_page mp, ax_sitepage p";
+            $q .= " WHERE mp.microsite_name='" . addslashes($RESPONSE->microsite_detected) . "'";
+            $q .= "   AND mp.microsite_homepage=TRUE";
+            $q .= "   AND p.page_id=mp.page_id";
+            $home = dbrecordset($q);
+            if ($home->hasdata) {
+              $homepath = $home->field("page_path");
+              if ($homepath != "") {
+                // Re-direct to the correct page and exit..
+                $redirect_url = $RESPONSE->site_url . $homepath;
+                $RESPONSE->discard();
+                header("Location: $redirect_url");
+                exit;
+              }
+            }
+            break;
+        } // switch
+      }
+    }
+  } // microsites enabled
 }
 
 // -----------------------------------------------------------------------
