@@ -571,16 +571,16 @@ class dbtrigger extends SchemaObject {
 class dbfield extends SchemaObject {
   var $num = 0;
   var $type = "";
-  var $default = "";
+  var $defaultval = "";
   var $notnull = false;
   var $ispkey = false;
   var $constraints = array();
   // ....................................................................
-  function dbfield(&$schema, $name, $num, $type, $default="", $notnull=false, $ispkey=false) {
+  function dbfield(&$schema, $name, $num, $type, $defaultval="", $notnull=false, $ispkey=false) {
     $this->SchemaObject($schema, $name);
     $this->num = $num;
     $this->type = $type;
-    $this->default = $default;
+    $this->defaultval = $defaultval;
     $this->notnull = $notnull;
     $this->ispkey = $ispkey;
   }
@@ -588,7 +588,7 @@ class dbfield extends SchemaObject {
   /** Dump field description to stdout. */
   function dump() {
     $s = "$this->name $this->type";
-    if ($this->default != "") $s .= " DEFAULT $this->default";
+    if ($this->defaultval != "") $s .= " DEFAULT $this->defaultval";
     if ($this->notnull) $s .= " NOT NULL";
     if ($this->ispkey) $s .= " (pk)";
     return "$s\n";
@@ -655,7 +655,7 @@ class dbfield extends SchemaObject {
     $s = "";
     $s .= "  \"$this->name\" $this->type";
     if ($this->notnull) $s .= " not null";
-    if ($this->default != "") $s .= " default $this->default";
+    if ($this->defaultval != "") $s .= " default $this->defaultval";
     $s .= $this->create_constraints();
     return $s;
   }
@@ -741,9 +741,9 @@ class dbtable extends SchemaObject {
   }
   // ....................................................................
   /** Create a new field in the table with given parameters. */
-  function newfield($name, $num, $type, $default="", $notnull=false) {
+  function newfield($name, $num, $type, $defaultval="", $notnull=false) {
     $ispkey = (in_array($num, $this->pkey));
-    $this->fields[$name] = new dbfield($this->schema, $name, $num, $type, $default, $notnull, $ispkey);
+    $this->fields[$name] = new dbfield($this->schema, $name, $num, $type, $defaultval, $notnull, $ispkey);
   } // newfield
   // ....................................................................
   /** Returns field object of given attnum (order number) */
@@ -872,7 +872,7 @@ class dbtable extends SchemaObject {
   function setdefault($column) {
     $s = "alter table \"$this->name\" alter column \"$column->name\"";
     if ($column->default == "") $s .= " drop default;\n";
-    else $s .= " set default $column->default;\n";
+    else $s .= " set default $column->defaultval;\n";
     return $s;
   }
   // ....................................................................
