@@ -20,7 +20,7 @@
 /*                                                                      */
 /* Filename:    story-defs.php                                          */
 /* Author:      Paul Waite                                              */
-/* Description: Definitions for managing and using stories/news         */
+/* Description: Definitions for managing and using Axyl stories/news    */
 /*                                                                      */
 /* ******************************************************************** */
 /** @package cm */
@@ -93,6 +93,7 @@ class story extends RenderableObject {
   var $formname = "";                // Name of the form we use
   var $bytesize = 0;                 // Size of article + media in bytes
   var $wordcount = 0;                // Number of words written
+  var $microsite_name;               // Microsite this story is for (if any)
   // .....................................................................
   /** Constructor
   * @param mixed $id Story ID, or false if not known
@@ -100,6 +101,7 @@ class story extends RenderableObject {
   * @param mixed $language Integer language code, or false if default
   */
   function story($id=false, $category=false, $language=false) {
+    global $RESPONSE;
     global $storymode;
     global $story_id, $cat, $lang;
 
@@ -150,17 +152,29 @@ class story extends RenderableObject {
       $this->story_date_ts = time();
       $this->story_date = timestamp_to_displaydate(DISPLAY_DATE_FORMAT, $this->story_date_ts);
       $this->newstory = true;
+      $this->valid = true;
       $this->get_author_info();
       $this->get_category_info();
       $this->get_default_locations();
-      $this->valid = true;
       $this->storymode = "adding";
+      // Also deal with possible microsite story creation..
+      if ($RESPONSE->microsites_mode == MICROSITES_ENABLED
+      && $RESPONSE->microsite_detected != "") {
+        $this->microsite_name = $RESPONSE->microsite_detected;
+        debugbr("setting microsite name for new story: $this->microsite_name");
+      }
     }
     // Further processing for existing stories..
     if (!$this->newstory) {
       if ($this->storymode == "adding") {
         $this->newstory = true;
         $this->valid = true;
+        // Also deal with possible microsite story creation..
+        if ($RESPONSE->microsites_mode == MICROSITES_ENABLED
+        && $RESPONSE->microsite_detected != "") {
+          $this->microsite_name = $RESPONSE->microsite_detected;
+          debugbr("setting microsite name for new story: $this->microsite_name");
+        }
       }
       else {
         // Attempt to get the story
@@ -208,6 +222,7 @@ class story extends RenderableObject {
   * @param mixed $id Story ID, or false if not known
   */
   function get_story($id=false) {
+    global $RESPONSE;
     $res = false;
     if ($id !== false) $this->story_id = $id;
     if ($this->story_id !== false) {
@@ -233,12 +248,12 @@ class story extends RenderableObject {
         // Dates and flags..
         $story_date = $storyQ->field("story_date");
         if ($story_date != "") {
-          $this->story_date = datetime_to_displaydate(NICE_FULLDATETIME, $story_date);
+          $this->story_date = datetime_to_displaydate(DISPLAY_DATE_FORMAT, $story_date);
           $this->story_date_ts = datetime_to_timestamp($story_date);
         }
         $expiry_date = $storyQ->field("expiry_date");
         if ($expiry_date != "") {
-          $this->expiry_date = datetime_to_displaydate(NICE_FULLDATETIME, $expiry_date);
+          $this->expiry_date = datetime_to_displaydate(DISPLAY_DATE_FORMAT, $expiry_date);
           $this->expiry_date_ts = datetime_to_timestamp($expiry_date);
         }
         $this->lastmodified = datetime_to_displaydate(NICE_FULLDATETIME, $storyQ->field("last_modified"));
@@ -255,6 +270,7 @@ class story extends RenderableObject {
         }
         $this->get_story_locations();
         $this->get_story_metrics();
+        $this->get_story_microsite();
       }
       else {
         $this->info_msg = "No record of story ID: $this->story_id";
@@ -355,6 +371,7 @@ class story extends RenderableObject {
         $media->width = $sm->field("width");
         $media->height = $sm->field("height");
         $this->story_media[$cat_id] = $media;
+        debugbr("adding story media: $cat_id " . $media->catalogitem->filepath, DBG_DEBUG);
       } while ($sm->get_next());
     }
   } // get_story_media
@@ -379,6 +396,26 @@ class story extends RenderableObject {
   } // get_story_locations
   // .....................................................................
   /**
+  * Get the microsite associated with this story, if any. If none, then
+  * we leave the 'microsite_name' local class variable unset.
+  * @access private
+  */
+  function get_story_microsite() {
+    global $RESPONSE;
+    if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+      if (isset($this->microsite_name)) {
+        unset($this->microsite_name);
+      }
+      $q  = "SELECT * FROM ax_microsite_story";
+      $q .= " WHERE story_id=$this->story_id";
+      $ms = dbrecordset($q);
+      if ($ms->hasdata) {
+        $this->microsite_name = $ms->field("microsite_name");
+      }
+    }
+  } // get_story_microsite
+  // .....................................................................
+  /**
   * Get the default locations for this story category. This method
   * is an internal one designed to be used to populate the initial
   * locations to publish a new story to.
@@ -406,7 +443,7 @@ class story extends RenderableObject {
   function get_story_metrics() {
     global $RESPONSE;
     $words = $this->story_headline . $this->story_precis . $this->story_content;
-    $bytesize = sizeof($words);
+    $bytesize = strlen($words);
     if (count($this->story_media) > 0) {
       foreach ($this->story_media as $media) {
         if (isset($media->catalogitem) && $media->catalogitem->filepath != "") {
@@ -549,7 +586,11 @@ class story extends RenderableObject {
       $sup->set("visible",        $this->visible);
       $sup->set("deleted",        $this->deleted);
       $sup->where("story_id=$this->story_id");
-      $sup->execute();
+      if ($sup->execute()) {
+        // Index to Lucene..
+        $this->index();
+        $this->newstory = false;
+      }
     }
   } // save_story
   // .....................................................................
@@ -557,14 +598,20 @@ class story extends RenderableObject {
   * deleted on the database, and keep the record.
   */
   function delete_story() {
-    global $CONTEXT;
+    global $RESPONSE, $CONTEXT;
     if ($this->valid && !$this->deleted) {
       $del = new dbupdate("ax_story");
       $del->set("deleted", true);
       $del->where("story_id=$this->story_id");
       $this->deleted = $del->execute();
       if ($this->deleted) {
+        if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+          $msdel = new dbdelete("ax_microsite_story");
+          $msdel->where("story_id=$this->story_id");
+          $msdel->execute();
+        }
         $this->unindex();
+        $this->info_msg = "Story has been marked as deleted";
       }
     }
   }  // delete_story
@@ -573,6 +620,7 @@ class story extends RenderableObject {
   * from the edit form.
   */
   function POSTprocess() {
+    global $RESPONSE;
     global $storysave_x;     // Clicked save
     global $storyedit_x;     // Clicked edit
     global $storycancel_x;   // Clicked cancel
@@ -597,6 +645,9 @@ class story extends RenderableObject {
     global $expiry_date;     // Expiry date setting
     global $visible;         // Visible flag
 
+    debugbr("POSTprocess: storymode initial: $this->storymode", DBG_DEBUG);
+    debugbr("story microsite: '$this->microsite_name'");
+
     // Save story
     if (isset($storysave_x)) {
       if (isset($story_headline)) $this->story_headline = $story_headline;
@@ -613,20 +664,20 @@ class story extends RenderableObject {
       if (isset($story_date)) {
         $this->story_date = $story_date;
         if ($story_date != "") {
-          $this->story_date_ts = strtotime($story_date);
-          debugbr("story_date=$story_date ts=$this->story_date_ts");
-          $this->story_date = timestamp_to_displaydate(NICE_FULLDATETIME, $this->story_date_ts);
-          debugbr("translated story date=$this->story_date");
+          // Convert user-supplied date-time..
+          $this->story_date_ts = displaydate_to_timestamp($story_date);
         }
         else {
-          $this->story_date_ts = 0;
+          // Supply default of 'now'. Story date must have a value..
+          $this->story_date_ts = time();
         }
+        $this->story_date = timestamp_to_displaydate(DISPLAY_DATE_FORMAT, $this->story_date_ts);
       }
       if ($this->has_expiry && isset($expiry_date)) {
         $this->expiry_date = $expiry_date;
         if ($expiry_date != "") {
-          $this->expiry_date_ts = strtotime($expiry_date);
-          $this->expiry_date = timestamp_to_displaydate(NICE_FULLDATETIME, $this->expiry_date_ts);
+          $this->expiry_date_ts = displaydate_to_timestamp($expiry_date);
+          $this->expiry_date = timestamp_to_displaydate(DISPLAY_DATE_FORMAT, $this->expiry_date_ts);
         }
         else {
           $this->expiry_date_ts = 0;
@@ -652,6 +703,14 @@ class story extends RenderableObject {
       // Save it if changed..
       $this->save_story();
 
+      // Microsite story link for new stories..
+      if ($this->storymode == "adding" && isset($this->microsite_name)) {
+        $mssin = new dbinsert("ax_microsite_story");
+        $mssin->set("microsite_name", $this->microsite_name);
+        $mssin->set("story_id", $this->story_id);
+        $mssin->execute();
+      }
+
       // Media data POSTings..
       if ($this->has_media) {
         // Some defaults..
@@ -776,6 +835,7 @@ class story extends RenderableObject {
       $this->delete_story();
       $this->storymode = "viewagain";
     } // remove
+    debugbr("POSTprocess: storymode final: $this->storymode", DBG_DEBUG);
   } // story POSTprocess
   // .....................................................................
   /**
@@ -961,6 +1021,15 @@ class story extends RenderableObject {
       $Tst->td_alignment("center");
     }
 
+    // MICROSITE
+    if (isset($this->microsite_name)) {
+      $Fld = new form_labelfield("story_microsite", $this->microsite_name);
+      $rowbg = ($rowbg == "axbglite") ? "axbgdark" : "axbglite";
+      $Tst->tr($rowbg);
+      $Tst->td("Microsite:", "axfg");
+      $Tst->td($Fld->render());
+    }
+
     // HEADLINE
     $Fld = new form_textfield("story_headline", "Headline", $this->story_headline);
     $Fld->setclass("axtxtbox");
@@ -1253,10 +1322,11 @@ class story extends RenderableObject {
     $Fld = new form_textfield("story_date", "Article date", $this->story_date);
     $Fld->setclass("axdatetime");
     $Fld->setstyle("width:$smlwidthpx;");
+    $Fld->set_onblur("isNonBlank(this, 'Please fill in a story date.');");
     $rowbg = ($rowbg == "axbglite") ? "axbgdark" : "axbglite";
     $Tst->tr($rowbg);
     $Tst->td("Article Date:", "axfg");
-    $Tst->td($Fld->render() . "&nbsp;<small><i>eg: Sep 3rd 2004 [hh:mm]</i></small>");
+    $Tst->td($Fld->render() . "&nbsp;<small><i>eg: dd/mm/yyyy [hh:mm]</i></small>");
 
     // EXPIRY DATE
     if ($this->has_expiry) {
@@ -1388,6 +1458,9 @@ class story extends RenderableObject {
 
     $Tst->set_width_profile("20%,80%");
 
+    // Add field validation scripts..
+    $RESPONSE->add_scriptsrc("$LIBDIR/js/fieldvalidation.js");
+
     return $Tst->render();
   } // editform
   // .....................................................................
@@ -1438,9 +1511,13 @@ class story extends RenderableObject {
     // EDITOR HEADER
     $Thd = new table("viewerhead");
     $Thd->tr($rowbg);
-    $Thd->td("<h3>$this->story_category_desc</h3>", "axfg");
+    $title = $this->story_category_desc;
+    if (isset($this->microsite_name)) {
+      $title .= "<br><small>(Microsite $this->microsite_name)</small>";
+    }
+    $Thd->td("<h3>$title</h3>", "axfg");
     $Thd->td($CONTROL_BUTTONS);
-    $Thd->td_alignment("right");
+    $Thd->td_alignment("right", "bottom");
 
     if ($this->language != 0) {
       $lq = dbrecordset("SELECT * FROM ax_language WHERE lang_id=$this->language");
@@ -1485,7 +1562,7 @@ class story extends RenderableObject {
     $Thd->td("<h6>$byline</h6>",
       "vertical-align:top;padding-bottom:5px;"
       );
-    $Thd->td($this->wordcount . " words (" . nicebytesize($this->bytesize,1) . ")");
+    $Thd->td($this->wordcount . " words (" . nicebytesize($this->bytesize) . ")");
     $Thd->td_alignment("right");
     if (isset($this->story_icon)) {
       $Thd->tr();
@@ -1553,8 +1630,8 @@ class story extends RenderableObject {
                   $media->catalogitem->filepath,
                   $caption,
                   $caption,
-                  $width,
-                  $height
+                  ($width  > 0 ? $width  : false),
+                  ($height > 0 ? $height : false)
                   );
           $pic->setalign(($media->justify != "") ? $media->justify : "right");
           $pic->setstyle("padding:2px");
@@ -1563,11 +1640,15 @@ class story extends RenderableObject {
       }
     }
     // Content..
-    $story_lead_in = str_replace("\r\n\r\n", "<p>", $this->story_precis);
-    $story_content = str_replace("\r\n\r\n", "<p>", $this->story_content);
-    $content = "<p>" . $story_lead_in . "</p>"
-            . $media_content
-            . "<p>" . $story_content . "</p>";
+    if (trim($this->story_precis) != "") {
+      $content .= str_replace("\r\n\r\n", "<p>", trim($this->story_precis));
+    }
+    if (trim($media_content) != "") {
+      $content .= $media_content;
+    }
+    if (trim($this->story_content) != "") {
+      $content .= str_replace("\r\n\r\n", "<p>", trim($this->story_content));
+    }
     $Tvw->td($content, "padding-top:20px;padding-bottom:50px;border-top:1px solid black");
     $Tvw->td_colspan(2);
 
