@@ -429,38 +429,51 @@ class user {
   } // assign_vars
   // ....................................................................
   /**
-  * Is user a member of a group
-  * Return true if the user is a member of the group.
-  * @param string $groupname   Group we are checking user membership of
+  * Is user a member of a named group. The argument passed in must be a
+  * single group name string (ie. not a numeric group id) which is defined
+  * in the database.
+  * Return true if the user is a member of the named group.
+  * @param string $groupname Name of the group we are checking user membership of
   * @return bool True if the user is a member of the group, else false
   */
   function ismemberof_group($groupname) {
-    $rc = false;
-    for ($i=0; $i<$this->user_groups_cnt; $i++) {
+    $found = false;
+    for ($i = 0; $i < $this->user_groups_cnt; $i++) {
       if (!strcasecmp(trim($this->group_names[$i]), trim($groupname))) {
-        $rc = true;
+        $found = true;
         break;
       }
     } // for
-    return $rc;
+    return $found;
   } // ismemberof_group
   // ....................................................................
   /**
   * Is user a member of one group of many
   * Check user against a list of groups, return true if member of at
-  * least one of them. The list in $groups should be comma-delimited.
-  * @param string $groupnames_list   Comma-delimited list of groups we are checking user membership of
-  * @return bool True if the user is a member of at least one of the groups, else false
+  * least one of them. The list in $groupnames can be either a comma-delimited
+  * string of group names, OR an array of group names.
+  * @param mixed $groupnames_list Comma-delimited list OR array of group names
+  * @return bool True if user is member of at least one of the groups, else false
   */
   function ismemberof_group_in($groupnames_list) {
-    if ($groupnames_list == "") return true;
-    $res = false;
-    $groups = explode(",", $groupnames_list);
-    foreach ($groups as $groupname) {
-      $res = $this->ismemberof_group($groupname);
-      if ($res) break;
+    if (is_string($groupnames_list)) {
+      if (trim($groupnames_list) == "") {
+        return true;
+      }
+      $groupnames = explode(",", $groupnames_list);
     }
-    return $res;
+    else {
+      $groupnames = $groupnames_list;
+    }
+    $found = false;
+    if (count($groupnames) == 0) {
+      return true;
+    }
+    foreach ($groupnames as $groupname) {
+      $found = $this->ismemberof_group($groupname);
+      if ($found) break;
+    }
+    return $found;
   } // ismemberof_group_in
   // ....................................................................
   /**
@@ -500,21 +513,19 @@ class user {
     if (!isset($this->group_info)) {
       $this->get_groups();
     }
-    $gplist = "";
+    $gplist = array();
     if (isset($this->group_info)) {
-      reset($this->group_info);
-      while (list($gid, $gdesc) = each($this->group_info)) {
-        if ($gplist != "") $gplist .= $delim;
-        $gplist .= $gid;
+      foreach ($this->group_info as $gid => $gdesc) {
+        $gplist[] = $gid;
       }
     }
-    return $gplist;
+    return implode($delim, $gplist);
   } // group_ids_list
   // ....................................................................
   /**
   * Get group names list
   * Return a string with the comma-delimited list of group names which this
-  * user belongs to in it.
+  * user belongs to in it. Eg. "Editor,Author,Admin"
   * @param string $delim Delimiter character (defaults to comma)
   * @return string List of group name's comma-delimited
   */
@@ -522,15 +533,13 @@ class user {
     if (!isset($this->group_info)) {
       $this->get_groups();
     }
-    $gplist = "";
+    $gplist = array();
     if (isset($this->group_info)) {
-      reset($this->group_info);
-      while (list($gid, $gdesc) = each($this->group_info)) {
-        if ($gplist != "") $gplist .= $delim;
-        $gplist .= $gdesc;
+      foreach ($this->group_info as $gid => $gdesc) {
+        $gplist[] = $gdesc;
       }
     }
-    return $gplist;
+    return implode($delim, $gplist);
   } // group_names_list
   // ....................................................................
   /**
