@@ -166,20 +166,21 @@ class webstream extends session {
   */
   function cache($expirysecs=0) {
     global $CACHEDIR;
-    global $cachecontrol;
     $this->cache_path = "$this->site_docroot/$CACHEDIR/" . $this->theme . "_" . basename($this->requested) . ".cached";
     $this->cache_expiry = $expirysecs;
     $this->cached = CACHED;
 
     // Obey any cache control directives..
-    if (isset($cachecontrol)) {
+    if (isset($this->cachecontrol)) {
       // Possible forced refresh..
-      if (strtolower($cachecontrol) == "refresh") {
+      if ($this->cachecontrol == "refresh" || $this->cachecontrol == "dynamic") {
         $this->cache_expiry = 0;
+        debugbr("cachecontrol: forced cache refresh", DBG_DEBUG);
       }
       // Possible forced expirytime..
       else {
-        $this->cache_expiry = (int) $cachecontrol;
+        $this->cache_expiry = (int)($this->cachecontrol);
+        debugbr("cachecontrol: cache expiry set to $this->cachecontrol", DBG_DEBUG);
       }
     }
     if (file_exists($this->cache_path)) {
@@ -191,6 +192,7 @@ class webstream extends session {
         // the chance of multiple rebuilds in the meantime..
         $this->cache_regen = true;
         touch($this->cache_path);
+        debugbr("cachecontrol: re-generating expired page '$this->cache_path'", DBG_DEBUG);
       }
       else {
         // This cached file has a current version out on
@@ -205,7 +207,7 @@ class webstream extends session {
           exit;
         }
         else {
-          log_sys("Failed to read cache file '$this->cache_path'");
+          log_sys("cachecontrol: failed to read cached page '$this->cache_path'");
         }
       }
     }
@@ -213,6 +215,7 @@ class webstream extends session {
       // Non-existant cache file. Make sure it gets built..
       $this->cache_regen = true;
       touch($this->cache_path);
+      debugbr("cachecontrol: generating cache for '$this->cache_path'", DBG_DEBUG);
     }
   } // cache
   // .....................................................................
@@ -597,31 +600,38 @@ class webpage extends webstream {
   * Plugins are regions of a webpage which you want to plug content into.
   * This is the method to call to add content to a named region or plugin.
   * The plugin ID (name) is related to a COMMENT TAG which appears in the
-  * template of the page. If the plugin doesn't exist then one is created.
+  * template of the page. If the plugin doesn't exist then one is created
+  * otherwise the content is simply appended to that already defined.
   * The 'content' can be any one of the following types:
-  *
   *  String   - A literal string of content to put in the plugin
   *  Path     - Path to a file containing content (can be relative)
   *  Function - A function definition, eg: "foo('xyx')" to return content
   *  Object   - An object. Must be a descendant of RenderableObject.
-  *
   * NB: This method can be called multiple times for the given plugin ID,
   *     and content will be accumulated each time.
-  *
   * NB: When you nominate an object or a function to provide content, the
   *     system assumes you want these generated "late" - ie. at the time
   *     the webpage is being sent back to the user agent. If you want
   *     content to be inserted early, then use literal strings.
-  *
-  * @param string $pluginid  ID of this plugin. Used to find plugin location
-  * @param mixed  $content   Content to plug in. May be string, path, object or function def.
+  * @param string $pluginid ID of this plugin. Used to find plugin location
+  * @param mixed $content The plugin content (literal, function, object...)
   */
   function plugin($pluginid, $content) {
     $this->pluginset->addto($pluginid, $content);
-    return $this;
   } // plugin
   // .....................................................................
   /**
+  * Define or redefine a plugin. This acts similarly to the above plugin()
+  * method, except that here we replace the existing content, if any is
+  * present, with this content.
+  * @param string $pluginid ID of this plugin. Used to find plugin location
+  * @param mixed $content The plugin content (literal, function, object...)
+  */
+  function plugin_replace($pluginid, $content) {
+    $this->pluginset->add_plugin($pluginid, $content);
+  } // plugin_replace
+  // .....................................................................
+  /**
   * Start/stop inline plugin content definition
   * This method allows plugin content to be taken from inline content
   * in the script page itself. At the start of the content call this
@@ -631,7 +641,6 @@ class webpage extends webstream {
   */
   function plugin_inline($pluginid="") {
     static $the_plugin_id = "";
-
     if ($the_plugin_id == "") {
       if ($pluginid != "") {
         $the_plugin_id = $pluginid;
@@ -698,6 +707,20 @@ class webpage extends webstream {
   // .....................................................................
   /**
   * Set the filenames for the main stylesheet and (optionally) the
+  * stylesheet for Internet Explorer compatible browsers.
+  * @param string $ss Name of normal stylesheet (others are derived)
+  */
+  function set_stylesheet($ss="") {
+    $sheets = $this->get_stylesheets($ss);
+    $this->head->set_stylesheet(
+        $sheets["ss"],
+        $sheets["ss_ie"],
+        $sheets["ss_ns"]
+        );
+  } // set_stylesheet
+  // .....................................................................
+  /**
+  * Get the filenames for the main stylesheet and (optionally) the
   * stylesheet for Internet Explorer compatible browsers. Note: this
   * should only be a filename, not a path. If a theme has been defined
   * then the stylesheet will be expected to be in the subdirectory of
@@ -708,29 +731,48 @@ class webpage extends webstream {
   * the appropriate directory with a name of APP_PREFIX.css. If that
   * isn't found we try looking for 'sitestyle.css'. Same applies for
   * the IE stylesheet, but with "_ie" appended to the filename part.
-  * @param string $ss     Name of normal stylesheet
-  * @param string $ss_ie  Name of stylesheet applicable to Internet Explorer
+  * We return the results in an associative array, with elements:
+  *     returned_array["css"] = standard stylsheet
+  *     returned_array["css_ie"] = IE stylsheet
+  *     returned_array["css_ns"] = Netscape 4.xx stylsheet
+  * @param string $ss Name of normal stylesheet (others are derived).
+  * @param string $theme The theme to retreive the stylesheets for.
+  * @return array Associative array of stylesheets as located.
   */
-  function set_stylesheet($ss="") {
+  function get_stylesheets($ss="", $theme="?") {
     global $TEMPLATESDIR;
-    if ($this->theme != "") {
-      $prefix = $this->site_docroot . "$TEMPLATESDIR/$this->theme/";
-      $wwwprefix = "$TEMPLATESDIR/$this->theme/";
+
+    // Initialise return var..
+    $stylesheets = array();
+    $stylesheets["ss"]    = "";
+    $stylesheets["ss_ie"] = "";
+    $stylesheets["ss_ns"] = "";
+
+    // Use current theme unless overriden..
+    if ($theme == "?") {
+      $theme = $this->theme;
+    }
+
+    // Set the path prefixes..
+    if ($theme != "") {
+      $prefix = $this->site_docroot . "$TEMPLATESDIR/$theme/";
+      $wwwprefix = "$TEMPLATESDIR/$theme/";
     }
     else {
       $prefix = $this->site_docroot . "/";
       $wwwprefix = "/";
     }
+
     // See if we can find defaults if null. We first try files
-    // with a stem of APP_PREFIX, and if that fails then we
-    // try the standard 'sitestyle.css' naming scheme..
+    // with the standard 'sitestyle.css' naming scheme. If that
+    // fails we try a stem of APP_PREFIX.
     if ($ss == "") {
-      $try = APP_PREFIX;
+      $try = "sitestyle";
       if (file_exists($prefix.$try.".css")) {
         $ss = $try.".css";
       }
       else {
-        $try = "sitestyle";
+        $try = APP_PREFIX;
         if (file_exists($prefix.$try.".css")) {
           $ss = $try.".css";
         }
@@ -753,11 +795,14 @@ class webpage extends webstream {
     }
 
     // Define any stylesheets found..
-    if ($ss    != "") $ss    = $wwwprefix.$ss;
-    if ($ss_ie != "") $ss_ie = $wwwprefix.$ss_ie;
-    if ($ss_ns != "") $ss_ns = $wwwprefix.$ss_ns;
-    $this->head->set_stylesheet($ss, $ss_ie, $ss_ns);
-  } // set_stylesheet
+    if ($ss    != "") $stylesheets["ss"]    = $wwwprefix.$ss;
+    if ($ss_ie != "") $stylesheets["ss_ie"] = $wwwprefix.$ss_ie;
+    if ($ss_ns != "") $stylesheets["ss_ns"] = $wwwprefix.$ss_ns;
+
+    // Return the results..
+    return $stylesheets;
+
+  } // get_stylesheets
   // .....................................................................
   /**
   * Define the script to execute after page has loaded
@@ -800,40 +845,53 @@ class webpage extends webstream {
   function set_template($templatename) {
     global $TEMPLATESDIR;
     if ($templatename != "") {
-      // Record it..
-      $this->template = $templatename;
       $this->templatefile = "";
-
       if ($templatename != "plain") {
         if (strtolower(substr($templatename, 5)) == ".html" ||
             strtolower(substr($templatename, 4)) == ".wml") {
           // Absolute path to template as it stands..
           $templatefile = $templatename;
+          $this->template = get_file_stem(basename($templatefile));
         }
         else {
-          $extn = "html";
-          if ($this->browser == BROWSER_PHONE) {
-            $extn = "wml";
-          }
-          // Build assumed path to correct template file..
-          $templatefile = "template_$templatename.$extn";
-          if ($this->theme != "") {
-            // Use a template from a theme sub-directory..
-            $templatefile = "$TEMPLATESDIR/$this->theme/$templatefile";
-          }
-          else {
-            // Use standard template..
-            $templatefile = "$TEMPLATESDIR/$templatefile";
+          // Try to find the template file - fallback to "main"..
+          $templatenames_to_try = array($templatename);
+          if ($templatename != "main") {
+            $templatenames_to_try[] = "main";
           }
+          foreach ($templatenames_to_try as $templatename) {
+            $this->template = $templatename;
+            $extn = "html";
+            if ($this->browser == BROWSER_PHONE) {
+              $extn = "wml";
+            }
+            // Build assumed path to correct template file..
+            $templatefile = "template_" . $templatename . "." . $extn;
+            if ($this->theme != "") {
+              // Use a template from a theme sub-directory..
+              $templatefile = "$TEMPLATESDIR/$this->theme/$templatefile";
+            }
+            else {
+              // Use standard template..
+              $templatefile = "$TEMPLATESDIR/$templatefile";
+            }
+            // Check it exists..
+            $this->templatefile = $this->site_docroot . $templatefile;
+            if (is_readable($this->templatefile)) {
+              break;
+            }
+          } // foreach
         }
-        $this->templatefile = $this->site_docroot . $templatefile;
       } // not plain
-
+      else {
+        $this->template = "plain";
+      }
       // Now we have the template content, use it..
+      debugbr("template name: $this->template", DBG_DEBUG);
+      debugbr("template file: $this->templatefile", DBG_DEBUG);
       $this->head->load_template($this->templatefile);
       $this->body->load_template($this->templatefile);
     }
-    return $this;
   } // set_template
   // .....................................................................
   /**
@@ -1287,7 +1345,12 @@ class body extends page_section {
   * @param string $parms  Misc other content for the body tag
   */
   function set_parms($parms) {
-    $this->parms .= $parms;
+    if ($parms != "") {
+      if ($this->parms != "") {
+        $this->parms .= " ";
+      }
+      $this->parms .= $parms;
+    }
   } // set_parms
   // .....................................................................
   /**
