@@ -75,11 +75,19 @@ $catalog = new catalog();
 // associated with it. Define these as you like, but always leave the
 // Nullstring option in the list since this is required to denote "Any"
 // or "All" categories.
-$catalog->set_categories(
-  array(
-    "" => ""     // Null specification - do not remove
-    )
-);
+$categories = array("" => ""); // always need this entry at least
+
+// Add microsites as categories, which allows filtering..
+if ($RESPONSE->microsite_detected != "") {
+  $msites = dbrecordset("SELECT microsite_name FROM ax_microsite ORDER BY microsite_name");
+  if ($msites->hasdata) {
+    do {
+      $msname = $msites->field("microsite_name");
+      $categories[$msname] = "Microsite $msname";
+    } while ($msites->get_next());
+  }
+}
+$catalog->set_categories($categories);
 
 // -----------------------------------------------------------------------
 // AUTHORISATION
@@ -120,6 +128,8 @@ switch ($mode) {
       $keywords = "";
       $category = "";
       $mime_category = "";
+      $width = 0;
+      $height = 0;
     }
     break;
 
@@ -148,7 +158,16 @@ switch ($mode) {
         $catalog_item->keywords = $keywords;
         $catalog_item->mime_category = $mime_category;
         $catalog_item->category = $category;
+        $catalog_item->width = $width;
+        $catalog_item->height = $height;
         $catalog_item->save();
+        $upload_name = "";
+        $upload_desc = "";
+        $keywords = "";
+        $category = "";
+        $mime_category = "";
+        $width = 0;
+        $height = 0;
       }
     }
     $mode = "view";
@@ -174,6 +193,8 @@ if ($mode == "edit" && isset($catid)) {
     $keywords      = $catalog_item->keywords;
     $mime_category = $catalog_item->mime_category;
     $category      = $catalog_item->category;
+    $width         = $catalog_item->width;
+    $height        = $catalog_item->height;
   }
 }
 
@@ -266,6 +287,22 @@ $uT->tr();
 $uT->td( "Category:", "axfmlbl" );
 $uT->td( $fld->render() );
 
+// Metrics
+$wfld = new form_textfield("width", "", $width);
+$wfld->setclass("axnumbox");
+$wfld->setstyle("width:60px;");
+$hfld = new form_textfield("height", "", $height);
+$hfld->setclass("axnumbox");
+$hfld->setstyle("width:60px;");
+$Tm = new table("metrics");
+$Tm->setwidth("");
+$Tm->td($wfld->render() . "&nbsp;x&nbsp;" . $hfld->render());
+$Tm->td("&nbsp;(Width x Height)");
+$uT->tr();
+$uT->td( "Size:", "axfmlbl" );
+$uT->td( $Tm->render() );
+
+
 // HIDDEN FIELDS
 $hid_auth  = new form_hiddenfield("auth_code", $auth_code);
 $hid_mode  = new form_hiddenfield("mode", $mode);
@@ -363,7 +400,7 @@ $fT->td_alignment("", "top");
 $fT->td( $fld->render() );
 
 // Refresh button..
-$btn = new form_imagebutton("_refresh", "Refresh", "", "$LIBDIR/img/_refresh.gif", "Refresh catalog list", 57, 15);
+$btn = new form_imagebutton("_refresh", "Refresh", "", "$LIBDIR/img/_refresh.gif", "Refresh catalog list", 77, 15);
 $fT->tr();
 $fT->td();
 $fT->td( $btn->render() );
@@ -399,7 +436,7 @@ if (!$firsttime) {
       $height=false,
       $left=120,
       $top=40,
-      $features="toolbar=no,status=yes,scrollbars=yes,resizable=yes"
+      $features="toolbar=no,status=no,scrollbars=no,resizable=yes"
       );
 
     // Buttons used for every catalog item line..
@@ -415,16 +452,19 @@ if (!$firsttime) {
     // List out the directory..
     $last = "";
     foreach ($catalog->catalogitems as $ci) {
+      // The reason we re-get is because the 'search' is usually conducted
+      // via Lucene, and this does not contains the media metrics. This
+      // re-get will retrieve ALL media information from the database..
+      $ci->get($ci->cat_id);
       $cat_id        = $ci->cat_id;
       $cat_name      = $ci->cat_name;
       $mime_category = $ci->mime_category;
       $category      = $ci->category;
       $path          = $ci->filepath;
-      $file          = basename($ci->filepath);
+      $file          = basename($path);
       $timestamp     = $ci->uploaded;
-      $width         = 0;
-      $height        = 0;
-
+      $width         = $ci->width;
+      $height        = $ci->width;
       // Groupings..
       switch ($filt_sortby) {
         case "mimecat":
@@ -476,18 +516,14 @@ if (!$firsttime) {
       $editBtn->set_onclick("go('edit','$cat_id')");
       $editBtn->settitle("Edit $file");
       $removeBtn->set_onclick("go('remove','$cat_id')");
-      if ($ci->mime_category == "image") {
-        if (extension_loaded("gd") && file_exists($path)) {
-          $szinfo = getimagesize($path);
-          if (!$width) $width = $szinfo[0];
-          if (!$height) $height = $szinfo[1];
-        }
-        $width  = (($width  != 0) ? $width  : 200);
-        $height = (($height != 0) ? $height : 180);
-        $showBtn->set_onclick("show('$path','" . ceil($width * 1.08) . "','" . ceil($height * 1.05) . "')");
-        $buttons .= $showBtn->render();
+
+      if (file_exists($RESPONSE->site_docroot . $path)) {
+        $href = "/axyl-media-viewer.php";
+        $href = href_addparm($href, "cat_id", $cat_id);
+        $showBtn->set_onclick("show('$href','" . ceil($width * 1.08) . "','" . ceil($height * 1.05) . "')");
+        $buttons .= $showBtn->render() . "&nbsp;";
       }
-      $buttons .= $editBtn->render() . $removeBtn->render();
+      $buttons .= $editBtn->render() . "&nbsp;" . $removeBtn->render();
       $Tcat->td( $buttons );
       $Tcat->td_alignment("right");
     }
@@ -551,6 +587,9 @@ $RESPONSE->plugin("HEADING",          $HEADING);
 $RESPONSE->plugin("UPLOAD_FIELDS",    $UPLOAD_FIELDS);
 $RESPONSE->plugin("FILTER_FIELDS",    $FILTER_FIELDS);
 $RESPONSE->plugin("CATALOG_CONTENTS", $CATALOG_CONTENTS);
+if ($RESPONSE->microsite_detected != "") {
+  $RESPONSE->plugin("MAIN_MENU", "main_menu()");
+}
 
 // -----------------------------------------------------------------------
 // DELIVER..
