@@ -63,8 +63,6 @@ $recvalid = false;
 //debug_on(DBG_SQL|DBG_DIAGNOSTIC);
 //debug_on(DBG_ALL);
 
-debugbr("SITEPAGE: [$INCDIR/cm-formats.inc]");
-
 // #######################################################################
 // POST PROCESSING
 if (!isset($CMDIR)) {
@@ -95,7 +93,8 @@ if (isset($save_x)) {
 
           // Make sure page path is prefixed to point where it should. We
           // forbid creating content anywhere except underneath $CMDIR..
-          $page_path = $CMDIR . "/" . basename($page_path);
+          $page_path = str_replace('../', '', $page_path);
+          $page_path = $CMDIR . "/" . $page_path;
 
           if (!file_exists($RESPONSE->site_docroot . $page_path)) {
             $nofile = true;
@@ -232,7 +231,9 @@ if (isset($save_x)) {
       // Update the page group perms..
       $chkQ = dbrecordset("SELECT * FROM ax_sitepage WHERE page_id=$page_id");
       if ($chkQ->hasdata) {
-        dbcommand("DELETE FROM ax_sitepage_group WHERE page_id=$page_id");
+        $pgdel = new dbdelete("ax_sitepage_group");
+        $pgdel->where("page_id=$page_id");
+        $pgdel->execute();
         if (isset($ugroup_restrict) && is_array($ugroup_restrict)) {
           if (count($ugroup_restrict) > 0) {
             if (!in_array("Any", $ugroup_restrict)) {
@@ -403,7 +404,18 @@ if ($mode != "add") {
   $Sel_F = new form_combofield("page_id", "Site Pages", $page_id, EDITABLE, "width: 250px");
   $Sel_F->additem("");
   $Sel_F->set_onchange("document.forms.main_fm.submit()");
-  $oQ = dbrecordset("SELECT * FROM ax_sitepage ORDER BY page_title");
+  $q = "SELECT * FROM ax_sitepage p";
+  // Omit pages which belong to microsites. These are maintained
+  // with the Microsite Admin screen..
+  if ($RESPONSE->microsites_mode == MICROSITES_ENABLED) {
+    $q .= " WHERE NOT EXISTS (";
+    $q .= "  SELECT * FROM ax_microsite_page mp";
+    $q .= "   WHERE mp.page_id=p.page_id";
+    $q .= "     AND mp.corepage=FALSE";
+    $q .= " )";
+  }
+  $q .= " ORDER BY page_title";
+  $oQ = dbrecordset($q);
   if ($oQ->rowcount > 0) {
     do {
       $pgid = $oQ->field("page_id");
